(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    192508,       6058]*)
(*NotebookOutlinePosition[    193535,       6090]*)
(*  CellTagsIndexPosition[    193491,       6086]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Eigenfunktionen der Dehnung des Stabes: A1.3", "Title",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
COPYRIGHT Prof. Dr. Oskar Wallrapp, Fachhochschule Muenchen. April \
2005\
\>", "Subsubtitle",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Probemstellung", "Subtitle",
  ImageRegion->{{-0, 1}, {0, 1}},
  Background->RGBColor[1, 0.999985, 0.780011]],

Cell[TextData[{
  "Der Ansatz  w(x,t) = W(x) q(t) der Bewegungsgleichung der Dehnung rho0 A \
d^2w / dt^2 + E A w'' = 0 liefert die ortsabhaengige Bewegungsgleichung \
W''(x) + beta^2 W(x) = 0  mit der allgemeinen Loesung \nW(x) = C1 sin(beta x) \
+ C2 cos(beta x) \nund die zeitabhaengige Bewegungsgleichung d^2q(t) / dt^2 + \
omega^2 q(t) = 0  mit der allgemeinen Loesung \nq(t) = B1 sin(omega t) + B2 \
cos(omega t).\nFreie Parameter sind die Eigenwerte beta und die \
Eigenkreisfrequenzen omega = 2 \[Pi] \[Florin] gemaess beta^2 = omega^2 rho0 \
A / (E A).\n",
  StyleBox["Aufgaben",
    FontWeight->"Bold"],
  ":\n1. Finde zu den Randbedingungen des gelagerten Stabes die \
charakteristische Gleichung fuer beta.\n2. Berechne beta f\[UDoubleDot]r i = \
1, ni.\n3. Bestimme die Eigenfunktionen der Dehnung f\[UDoubleDot]r ",
  StyleBox[" festeingespannt -- frei",
    FontWeight->"Bold"],
  "."
}], "Text",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontFamily->"Helvetica",
  Background->RGBColor[1, 0.999985, 0.780011]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Festlegung der Parameter", "Subtitle",
  ImageRegion->{{-0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[CellGroupData[{

Cell["\<\
ni        = 10;               (* Zahl der gewuenschten \
Eigenfunktionen                       *)
npi       = 4;               (* Zahl der Eigenfunktionen, die zu zeichnen \
sind              *)
len       = 12;              (* Laenge l des Balkens                          \
              *)
Randbg    = \"fest - frei\";   (* Benennung der Randbedingungen               \
            *)
Randx0    = {0};             (* Randbeg. fuer x=0: 0=(w=0), 1=(w'=0), \
2=(w''=0), 3=(w'''=0) *)
Randxl    = {1};             (* Randbeg. fuer x=l: 0=(w=0), 1=(w'=0), \
2=(w''=0), 3=(w'''=0) *)
Skalierg  = 2;               (* Skalierg. der Fkt: 0=keine, 1=(Wmax=1), \
2=(Int mue W^2 dx=1)*)
rhoD      = 8930;            (* Dichte in kg/m^3                              \
              *)
AQuer     = 0.002^2*Pi/4     (* Querschnittsflaeche in m^2                    \
              *)
massmy    = rhoD * AQuer     (* Massenbelegung in kg/m                        \
              *)\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[BoxData[
    \(3.141592653589793`*^-6\)], "Output"],

Cell[BoxData[
    \(0.028054422396556852`\)], "Output"]
}, Open  ]],

Cell["\<\
JFTMv  = non;          (* Flaechentraegheitsmoment in m^4           \
                  *)
Emodv  = 12*10^+10;   (* Elastizitaetsmodul in N/m^2                          \
       *)\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Loesung", "Subtitle",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
1. Charakteristische Gleichung der homogenen partiellen DGL: W''(x) \
+ beta^2 W(x) = 0 fuer gegebene Randbedingungen.\
\>", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["1.1 Allgemeine Eigenfunktion und deren Ableitungen", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["W = C1 Sin[beta x]+ C2 Cos[beta x]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(C2\ Cos[beta\ x] + C1\ Sin[beta\ x]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["d1W = D[W,x]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(beta\ C1\ Cos[beta\ x] - beta\ C2\ Sin[beta\ x]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2 Die Funktionswerte f\[UDoubleDot]r x = 0 und x = l", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["W0 = Table[0,{2}]; Wl = Table[0,{2}];", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["W0[[1]] = W /. x -> 0", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(C2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wl[[1]] = W /. x -> l", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(C2\ Cos[beta\ l] + C1\ Sin[beta\ l]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["W0[[2]] = d1W /. x -> 0", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(beta\ C1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wl[[2]] = d1W /. x -> l", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(beta\ C1\ Cos[beta\ l] - beta\ C2\ Sin[beta\ l]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
1.3 Finde die charakteristische Gleichung (Charglg = 0) f\
\[UDoubleDot]r die oben genannten Randbedingungen
aus Det(CMat ) = 0  von  CMat . Ck = 0, wo Ck = {C1, C2}.\
\>", \
"Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["eq1 bis eq2 beschreibt die 2 Randbedingungen.", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
eq1 = W0[[Randx0[[1]]+1]];
eq2 = Wl[[Randxl[[1]]+1]];
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
CMat = Table[0,{2},{2}];
CMat[[1,1]] = eq1 /. {C1->1,C2->0,C3->0,C4->0};
CMat[[1,2]] = eq1 /. {C1->0,C2->1,C3->0,C4->0};
 
CMat[[2,1]] = eq2 /. {C1->1,C2->0,C3->0,C4->0};
CMat[[2,2]] = eq2 /. {C1->0,C2->1,C3->0,C4->0};

MatrixForm[CMat]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "1"},
            {\(beta\ Cos[beta\ l]\), \(\(-beta\)\ Sin[beta\ l]\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Charglg = Simplify[Det[CMat]]/-beta    (* fuer fest - frei   \
*)\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(Cos[beta\ l]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Char = Charglg /. l \[Rule] 1\), "\n", 
    \(erg = FindRoot[Char \[Equal] 0, {beta, Pi/2}]\)}], "Input"],

Cell[BoxData[
    \({beta \[Rule] 1.5707963267948966`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4 Zeichne die charakteristische Gleichung fuer l = 1.", \
"Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Plot [{Charglg/.l->1}, {beta,-8,8},\t
      PlotLabel-> \"Charakt. Fkt. f\[UDoubleDot]r Randbdg.\"Randbg,
\t  Frame    -> True];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.309017 0.294302 [
[.05357 -0.0125 -12 -9 ]
[.05357 -0.0125 12 0 ]
[.20238 -0.0125 -6 -9 ]
[.20238 -0.0125 6 0 ]
[.35119 -0.0125 -12 -9 ]
[.35119 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64881 -0.0125 -9 -9 ]
[.64881 -0.0125 9 0 ]
[.79762 -0.0125 -3 -9 ]
[.79762 -0.0125 3 0 ]
[.94643 -0.0125 -9 -9 ]
[.94643 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -12 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -114.312 0 ]
[.5 .63053 114.312 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 0 m
.05357 .00625 L
s
[(-7.5)] .05357 -0.0125 0 1 Mshowa
.20238 0 m
.20238 .00625 L
s
[(-5)] .20238 -0.0125 0 1 Mshowa
.35119 0 m
.35119 .00625 L
s
[(-2.5)] .35119 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64881 0 m
.64881 .00625 L
s
[(2.5)] .64881 -0.0125 0 1 Mshowa
.79762 0 m
.79762 .00625 L
s
[(5)] .79762 -0.0125 0 1 Mshowa
.94643 0 m
.94643 .00625 L
s
[(7.5)] .94643 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76786 0 m
.76786 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(-1)] -0.0125 .01471 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.05357 .61178 m
.05357 .61803 L
s
.20238 .61178 m
.20238 .61803 L
s
.35119 .61178 m
.35119 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64881 .61178 m
.64881 .61803 L
s
.79762 .61178 m
.79762 .61803 L
s
.94643 .61178 m
.94643 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.1131 .61428 m
.1131 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.17262 .61428 m
.17262 .61803 L
s
.23214 .61428 m
.23214 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.41071 .61428 m
.41071 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.47024 .61428 m
.47024 .61803 L
s
.52976 .61428 m
.52976 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.58929 .61428 m
.58929 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76786 .61428 m
.76786 .61803 L
s
.82738 .61428 m
.82738 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.8869 .61428 m
.8869 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -175.312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Charakt) show
105.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fkt) show
135.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
147.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f\\237) show
(r) show
171.000 13.000 moveto
(Randbdg) show
213.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
219.000 13.000 moveto
0.000 0.000 rmoveto
221.625 13.000 moveto
0.000 0.000 rmoveto
221.625 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(fest) show
251.625 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
263.625 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(frei) show
287.625 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .2662 m
.04262 .35879 L
.06244 .4509 L
.08255 .52834 L
.09396 .56169 L
.09905 .57367 L
.10458 .58447 L
.11004 .5928 L
.11243 .59571 L
.11508 .59838 L
.11756 .60037 L
.11989 .60177 L
.12118 .60235 L
.12235 .60277 L
.123 .60294 L
.12371 .6031 L
.125 .60328 L
.12626 .60332 L
.12744 .60323 L
.12851 .60306 L
.12966 .60276 L
.13092 .60232 L
.13225 .6017 L
.13463 .60023 L
.13683 .59846 L
.13889 .59644 L
.14357 .59059 L
.14858 .5824 L
.15402 .5713 L
.16392 .54558 L
.18248 .48048 L
.22326 .29043 L
.24352 .19347 L
.26253 .11432 L
.27138 .08378 L
.2807 .057 L
.28558 .0454 L
.29091 .03474 L
.29541 .02748 L
.30028 .02141 L
.30303 .01883 L
.30557 .01701 L
.30799 .01576 L
.30921 .01531 L
.3099 .01511 L
.31056 .01496 L
.31177 .01478 L
.31288 .01472 L
.31408 .01476 L
.31538 .01495 L
Mistroke
.31651 .01523 L
.31772 .01564 L
.31989 .01668 L
.32261 .01855 L
.32556 .02124 L
.33089 .0279 L
.33607 .03655 L
.34084 .04632 L
.3597 .10075 L
.38038 .18398 L
.42086 .37932 L
.43953 .46408 L
.45982 .53877 L
.47088 .5688 L
.47574 .57921 L
.4811 .58861 L
.48614 .59538 L
.48844 .59779 L
.49087 .59986 L
.49211 .60074 L
.49347 .60155 L
.49472 .60216 L
.49586 .60261 L
.49651 .60281 L
.49721 .60299 L
.49795 .60314 L
.49864 .60324 L
.4993 .6033 L
.49999 .60332 L
.50123 .60326 L
.50245 .60307 L
.50313 .60291 L
.50377 .60273 L
.50494 .60231 L
.50618 .60173 L
.50832 .60045 L
.51069 .59858 L
.51593 .59285 L
.52085 .58546 L
.52966 .56753 L
.53917 .54186 L
.55919 .46943 L
.58028 .37385 L
.61835 .18967 L
.63958 .10326 L
.64962 .07086 L
.65888 .04694 L
.66346 .03742 L
.6685 .02881 L
.67357 .02217 L
Mistroke
.67635 .01942 L
.67894 .01741 L
.68011 .01668 L
.68139 .01602 L
.68252 .01555 L
.68371 .01516 L
.6849 .0149 L
.68598 .01476 L
.68706 .01472 L
.68808 .01476 L
.68927 .01493 L
.69053 .01523 L
.69161 .0156 L
.6928 .01611 L
.69543 .01766 L
.6979 .01963 L
.70291 .02516 L
.70836 .03346 L
.71826 .05439 L
.72791 .08152 L
.73683 .11194 L
.77611 .28734 L
.81388 .46555 L
.83324 .53699 L
.84413 .56703 L
.84895 .57765 L
.8541 .58703 L
.85925 .59433 L
.86392 .59911 L
.86617 .60078 L
.86736 .60149 L
.86861 .60211 L
.86971 .60256 L
.87092 .60292 L
.87202 .60316 L
.87304 .60328 L
.87432 .60331 L
.87505 .60327 L
.87572 .6032 L
.87695 .60296 L
.87826 .60256 L
.87955 .60204 L
.88076 .60142 L
.88303 .59994 L
.88572 .59764 L
.88818 .595 L
.89375 .58727 L
.89847 .5788 L
.90352 .56786 L
.91263 .5435 L
Mistroke
.93331 .46892 L
.97474 .27329 L
.97619 .2662 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{317.625, 196.312},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004m0000a1000`40O003h00Oogoo?Woo000^Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool3000POol3000NOol50003Ool00`00Oomoo`02Ool3000MOol2
000OOol50003Ool00`00Oomoo`02Ool3000OOol3000POol00`00Oomoo`03Ool00`00Oomoo`02Ool3
000BOol002ioo`03001oogoo00Moo`05001oogooOol0000NOol01@00Oomoogoo00007Woo00@007oo
Ool000Moo`05001oogooOol0000KOol01000Oomoo`007goo00@007ooOol000Moo`05001oogooOol0
000MOol01@00Oomoogoo00007goo00<007ooOol01goo00D007ooOomoo`00015oo`009Woo1@0017oo
00<007ooOol02Woo00<007ooOol05Woo1@001Goo00<007ooOol05Goo1@000goo00<007ooOol02goo
00<007ooOol06Goo00@007ooOol0021oo`03001oogoo00]oo`03001oogoo01moo`03001oogoo01io
o`03001oogoo00Yoo`03001oogoo00moo`00;goo00<007ooOol02Woo00<007ooOol087oo00<007oo
Ool07Woo00<007ooOol02Woo00<007ooOol06Goo00@007ooOol0025oo`03001oogoo00Yoo`03001o
ogoo01moo`03001oogoo01ioo`03001oogoo00Yoo`03001oogoo00moo`00<7oo00<007ooOol01Goo
10007goo10007Woo00D007ooOomoo`0000Moo`@001aoo`04001oogoo000NOol01@00Oomoogoo0000
1goo10007Woo10008Woo00<007ooOol01Goo10004Woo000/Ool01@00Oomoogoo00001goo00<007oo
Ool087oo00<007ooOol07goo00D007ooOomoo`0000Moo`03001oogoo01eoo`04001oogoo000NOol0
1@00Oomoogoo00001goo00<007ooOol07goo00<007ooOol07goo00D007ooOomoo`0000Moo`03001o
ogoo01=oo`00;7oo1@001goo1@007Woo1@007Woo0`0027oo1@0077oo0P0087oo0`0027oo1@007Goo
1@007Goo1@001goo1@004Goo003oOolnOol00?moocioo`00ogoo?Woo003oOolnOol00?moocioo`00
97ooo`004@002Goo000LOol30005Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool001eoo`03001oogoo00Aoo`03001oogoo08Aoo`03001oogoo
08Eoo`03001oogoo00Moo`005Goo1@000goo00<007ooOol017oo00<007ooOol0Q7oo00<007ooOol0
QGoo00<007ooOol01goo000MOol00`00Oomoo`04Ool3001@Ool5000_Ool00`00Oomoo`0^Ool5001@
Ool30009Ool001eoo`03001oogoo00Aoo`03001oogoo04ioo`8000Aoo`8002ioo`03001oogoo02eo
o`03001oogoo00=oo`03001oogoo04moo`03001oogoo00Moo`0077oo0P001Woo00<007ooOol0CWoo
00<007ooOol01Goo00<007ooOol0:goo00<007ooOol0;7oo00<007ooOol01Goo00<007ooOol0CWoo
00<007ooOol01goo000MOol00`00Oomoo`04Ool00`00Oomoo`1=Ool00`00Oomoo`07Ool00`00Oomo
o`0ZOol00`00Oomoo`0[Ool00`00Oomoo`06Ool00`00Oomoo`1>Ool00`00Oomoo`07Ool002Aoo`03
001oogoo04eoo`03001oogoo00Moo`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo00Moo`03
001oogoo04eoo`03001oogoo00Moo`0097oo00<007ooOol0C7oo00<007ooOol02Goo00<007ooOol0
:Goo00<007ooOol0:Woo00<007ooOol02Goo00<007ooOol0C7oo00<007ooOol01goo000TOol00`00
Oomoo`1<Ool00`00Oomoo`09Ool00`00Oomoo`0YOol00`00Oomoo`0ZOol00`00Oomoo`09Ool00`00
Oomoo`1<Ool00`00Oomoo`07Ool002Aoo`03001oogoo04]oo`03001oogoo00]oo`03001oogoo02Qo
o`03001oogoo02Yoo`03001oogoo00Yoo`03001oogoo04]oo`03001oogoo00Moo`0097oo0P00Bgoo
00<007ooOol037oo00<007ooOol0:7oo00<007ooOol0:Goo00<007ooOol037oo00<007ooOol0BGoo
0P002Goo000TOol00`00Oomoo`1:Ool00`00Oomoo`0<Ool00`00Oomoo`0XOol00`00Oomoo`0YOol0
0`00Oomoo`0<Ool00`00Oomoo`1:Ool00`00Oomoo`07Ool002Aoo`03001oogoo04Uoo`03001oogoo
00ioo`03001oogoo02Moo`03001oogoo02Qoo`03001oogoo00ioo`03001oogoo04Uoo`03001oogoo
00Moo`0097oo00<007ooOol0BGoo00<007ooOol03Woo00<007ooOol09goo00<007ooOol0:7oo00<0
07ooOol03Woo00<007ooOol0BGoo00<007ooOol01goo000TOol00`00Oomoo`19Ool00`00Oomoo`0>
Ool00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomoo`0?Ool00`00Oomoo`19Ool00`00Oomoo`07
Ool002Aoo`03001oogoo04Qoo`03001oogoo011oo`03001oogoo02Ioo`03001oogoo02Moo`03001o
ogoo011oo`03001oogoo04Qoo`03001oogoo00Moo`0097oo00<007ooOol0B7oo00<007ooOol047oo
00<007ooOol09Woo00<007ooOol09goo00<007ooOol047oo00<007ooOol0B7oo00<007ooOol01goo
000TOol00`00Oomoo`17Ool00`00Oomoo`0AOol00`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomo
o`0AOol00`00Oomoo`18Ool00`00Oomoo`07Ool002Aoo`8004Qoo`03001oogoo019oo`03001oogoo
02Eoo`03001oogoo02Ioo`03001oogoo015oo`03001oogoo04Moo`8000Uoo`0097oo00<007ooOol0
Agoo00<007ooOol04Woo00<007ooOol09Goo00<007ooOol09Goo00<007ooOol04goo00<007ooOol0
Agoo00<007ooOol01goo000TOol00`00Oomoo`16Ool00`00Oomoo`0COol00`00Oomoo`0UOol00`00
Oomoo`0UOol00`00Oomoo`0COol00`00Oomoo`17Ool00`00Oomoo`07Ool002Aoo`03001oogoo04Io
o`03001oogoo01Aoo`03001oogoo02Aoo`03001oogoo02Eoo`03001oogoo01=oo`03001oogoo04Mo
o`03001oogoo00Moo`0097oo00<007ooOol0AWoo00<007ooOol057oo00<007ooOol097oo00<007oo
Ool097oo00<007ooOol05Goo00<007ooOol0AWoo00<007ooOol01goo000TOol00`00Oomoo`15Ool0
0`00Oomoo`0EOol00`00Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0EOol00`00Oomoo`16Ool0
0`00Oomoo`07Ool002Aoo`03001oogoo04Eoo`03001oogoo01Ioo`03001oogoo02=oo`03001oogoo
02Aoo`03001oogoo01Eoo`03001oogoo04Ioo`03001oogoo00Moo`0097oo0P00AWoo00<007ooOol0
5Woo00<007ooOol08goo00<007ooOol08goo00<007ooOol05goo00<007ooOol0A7oo0P002Goo000T
Ool00`00Oomoo`15Ool00`00Oomoo`0FOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0G
Ool00`00Oomoo`15Ool00`00Oomoo`07Ool002Aoo`03001oogoo04Eoo`03001oogoo01Ioo`03001o
ogoo02=oo`03001oogoo02=oo`03001oogoo01Moo`03001oogoo04Eoo`03001oogoo00Moo`0097oo
00<007ooOol0A7oo00<007ooOol067oo00<007ooOol08Woo00<007ooOol08goo00<007ooOol067oo
00<007ooOol0A7oo00<007ooOol01goo000TOol00`00Oomoo`14Ool00`00Oomoo`0HOol00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`0IOol00`00Oomoo`14Ool00`00Oomoo`07Ool002Aoo`03
001oogoo04Aoo`03001oogoo01Qoo`03001oogoo029oo`03001oogoo029oo`03001oogoo01Uoo`03
001oogoo04Aoo`03001oogoo00Moo`0097oo00<007ooOol0A7oo00<007ooOol06Goo00<007ooOol0
8Goo00<007ooOol08Woo00<007ooOol06Woo00<007ooOol0@goo00<007ooOol01goo000TOol00`00
Oomoo`13Ool00`00Oomoo`0JOol00`00Oomoo`0QOol00`00Oomoo`0ROol00`00Oomoo`0JOol00`00
Oomoo`13Ool00`00Oomoo`07Ool002Aoo`8004Aoo`03001oogoo01Yoo`03001oogoo025oo`03001o
ogoo029oo`03001oogoo01Yoo`03001oogoo049oo`8000Uoo`0097oo00<007ooOol0@goo00<007oo
Ool06Woo00<007ooOol08Goo00<007ooOol08Goo00<007ooOol06goo00<007ooOol0@goo00<007oo
Ool01goo000TOol00`00Oomoo`13Ool00`00Oomoo`0KOol00`00Oomoo`0POol00`00Oomoo`0QOol0
0`00Oomoo`0KOol00`00Oomoo`13Ool00`00Oomoo`07Ool002Aoo`03001oogoo049oo`03001oogoo
01aoo`03001oogoo021oo`03001oogoo025oo`03001oogoo01aoo`03001oogoo049oo`03001oogoo
00Moo`0097oo00<007ooOol0@Woo00<007ooOol077oo00<007ooOol087oo00<007ooOol08Goo00<0
07ooOol077oo00<007ooOol0@Woo00<007ooOol01goo000TOol00`00Oomoo`12Ool00`00Oomoo`0L
Ool00`00Oomoo`0POol00`00Oomoo`0POol00`00Oomoo`0MOol00`00Oomoo`12Ool00`00Oomoo`07
Ool0015oo`8000Aoo`03001oogoo009oo`<000Eoo`03001oogoo049oo`03001oogoo01eoo`03001o
ogoo01moo`03001oogoo021oo`03001oogoo01eoo`03001oogoo049oo`03001oogoo00Moo`0047oo
00@007ooOol000Moo`05001oogooOol00004Ool00`00Oomoo`11Ool00`00Oomoo`0NOol00`00Oomo
o`0OOol00`00Oomoo`0POol00`00Oomoo`0MOol00`00Oomoo`12Ool00`00Oomoo`07Ool000Uoo`D0
009oo`04001oogoo000;Ool00`00Oomoo`02Ool30011Ool00`00Oomoo`0NOol00`00Oomoo`0OOol0
0`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0oOol30009Ool0011oo`04001oogoo000;Ool0
0`00Oomoo`02Ool00`00Oomoo`11Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol0
0`00Oomoo`0NOol00`00Oomoo`11Ool00`00Oomoo`07Ool0011oo`04001oogoo0007Ool40005Ool0
0`00Oomoo`11Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`11Ool00`00Oomoo`07Ool0011oo`04001oogoo0007Ool00`00Oomoo`06Ool00`00Oomo
o`11Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`11Ool00`00Oomoo`07Ool0015oo`8000Qoo`D000Aoo`03001oogoo041oo`03001oogoo021oo`03
001oogoo01ioo`03001oogoo01moo`03001oogoo021oo`03001oogoo041oo`03001oogoo00Moo`00
97oo00<007ooOol0@7oo00<007ooOol08Goo00<007ooOol07Goo00<007ooOol07goo00<007ooOol0
87oo00<007ooOol0@7oo00<007ooOol01goo000TOol00`00Oomoo`10Ool00`00Oomoo`0QOol00`00
Oomoo`0MOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`10Ool00`00Oomoo`07Ool002Ao
o`03001oogoo041oo`03001oogoo025oo`03001oogoo01eoo`03001oogoo01ioo`03001oogoo025o
o`03001oogoo041oo`03001oogoo00Moo`0097oo0P00@7oo00<007ooOol08Woo00<007ooOol07Goo
00<007ooOol07Woo00<007ooOol08Goo00<007ooOol0?goo0P002Goo000TOol00`00Oomoo`0oOol0
0`00Oomoo`0SOol00`00Oomoo`0LOol00`00Oomoo`0NOol00`00Oomoo`0ROol00`00Oomoo`0oOol0
0`00Oomoo`07Ool002Aoo`03001oogoo03moo`03001oogoo02=oo`03001oogoo01aoo`03001oogoo
01ioo`03001oogoo029oo`03001oogoo03moo`03001oogoo00Moo`0097oo00<007ooOol0?goo00<0
07ooOol08goo00<007ooOol077oo00<007ooOol07Goo00<007ooOol08goo00<007ooOol0?goo00<0
07ooOol01goo000TOol00`00Oomoo`0nOol00`00Oomoo`0TOol00`00Oomoo`0LOol00`00Oomoo`0M
Ool00`00Oomoo`0SOol00`00Oomoo`0oOol00`00Oomoo`07Ool002Aoo`03001oogoo03ioo`03001o
ogoo02Aoo`03001oogoo01aoo`03001oogoo01eoo`03001oogoo02=oo`03001oogoo03moo`03001o
ogoo00Moo`0097oo00<007ooOol0?Woo00<007ooOol09Goo00<007ooOol06goo00<007ooOol07Goo
00<007ooOol097oo00<007ooOol0?Woo00<007ooOol01goo000TOol00`00Oomoo`0nOol00`00Oomo
o`0UOol00`00Oomoo`0KOol00`00Oomoo`0MOol00`00Oomoo`0TOol00`00Oomoo`0nOol00`00Oomo
o`07Ool002Aoo`8003ioo`03001oogoo02Ioo`03001oogoo01]oo`03001oogoo01aoo`03001oogoo
02Eoo`03001oogoo03eoo`8000Uoo`0097oo00<007ooOol0?Goo00<007ooOol09Woo00<007ooOol0
6goo00<007ooOol077oo00<007ooOol09Goo00<007ooOol0?Woo00<007ooOol01goo000TOol00`00
Oomoo`0mOol00`00Oomoo`0VOol00`00Oomoo`0KOol00`00Oomoo`0LOol00`00Oomoo`0UOol00`00
Oomoo`0nOol00`00Oomoo`07Ool002Aoo`03001oogoo03eoo`03001oogoo02Moo`03001oogoo01Yo
o`03001oogoo01aoo`03001oogoo02Ioo`03001oogoo03eoo`03001oogoo00Moo`0097oo00<007oo
Ool0?Goo00<007ooOol09goo00<007ooOol06Woo00<007ooOol06goo00<007ooOol09goo00<007oo
Ool0?Goo00<007ooOol01goo000TOol00`00Oomoo`0lOol00`00Oomoo`0XOol00`00Oomoo`0JOol0
0`00Oomoo`0KOol00`00Oomoo`0WOol00`00Oomoo`0mOol00`00Oomoo`07Ool002Aoo`03001oogoo
03aoo`03001oogoo02Qoo`03001oogoo01Yoo`03001oogoo01]oo`03001oogoo02Moo`03001oogoo
03eoo`03001oogoo00Moo`0097oo00<007ooOol0?7oo00<007ooOol0:7oo00<007ooOol06Woo00<0
07ooOol06goo00<007ooOol0:7oo00<007ooOol0?7oo00<007ooOol01goo000TOol2000mOol00`00
Oomoo`0YOol00`00Oomoo`0IOol00`00Oomoo`0KOol00`00Oomoo`0XOol00`00Oomoo`0kOol20009
Ool002Aoo`03001oogoo03]oo`03001oogoo02Yoo`03001oogoo01Uoo`03001oogoo01Yoo`03001o
ogoo02Uoo`03001oogoo03aoo`03001oogoo00Moo`0097oo00<007ooOol0>goo00<007ooOol0:Woo
00<007ooOol06Goo00<007ooOol06Woo00<007ooOol0:Goo00<007ooOol0?7oo00<007ooOol01goo
000TOol00`00Oomoo`0kOol00`00Oomoo`0ZOol00`00Oomoo`0IOol00`00Oomoo`0JOol00`00Oomo
o`0YOol00`00Oomoo`0lOol00`00Oomoo`07Ool002Aoo`03001oogoo03]oo`03001oogoo02Yoo`03
001oogoo01Uoo`03001oogoo01Yoo`03001oogoo02Yoo`03001oogoo03]oo`03001oogoo00Moo`00
97oo00<007ooOol00goo00<007ooOol0=7oo00<007ooOol0;7oo00<007ooOol067oo00<007ooOol0
6Goo00<007ooOol0:goo00<007ooOol0=Goo00<007ooOol00goo00<007ooOol01goo000TOol00`00
Oomoo`03Ool00`00Oomoo`0dOol00`00Oomoo`0/Ool00`00Oomoo`0HOol00`00Oomoo`0IOol00`00
Oomoo`0[Ool00`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`07Ool002Aoo`03001oogoo00=o
o`03001oogoo03Aoo`03001oogoo02aoo`03001oogoo01Qoo`03001oogoo01Uoo`03001oogoo02]o
o`03001oogoo03Aoo`03001oogoo00Aoo`03001oogoo00Moo`0097oo0P001Goo00<007ooOol0<goo
00<007ooOol0;7oo00<007ooOol067oo00<007ooOol06Goo00<007ooOol0:goo00<007ooOol0=7oo
00<007ooOol00goo0P002Goo000TOol00`00Oomoo`04Ool00`00Oomoo`0cOol00`00Oomoo`0]Ool0
0`00Oomoo`0GOol00`00Oomoo`0IOol00`00Oomoo`0/Ool00`00Oomoo`0cOol00`00Oomoo`04Ool0
0`00Oomoo`07Ool002Aoo`03001oogoo00Aoo`03001oogoo039oo`03001oogoo02ioo`03001oogoo
01Moo`03001oogoo01Qoo`03001oogoo02eoo`03001oogoo039oo`03001oogoo00Eoo`03001oogoo
00Moo`0097oo00<007ooOol017oo00<007ooOol0<Woo00<007ooOol0;Woo00<007ooOol05goo00<0
07ooOol067oo00<007ooOol0;Goo00<007ooOol0<Woo00<007ooOol01Goo00<007ooOol01goo000T
Ool00`00Oomoo`04Ool00`00Oomoo`0bOol00`00Oomoo`0^Ool00`00Oomoo`0GOol00`00Oomoo`0H
Ool00`00Oomoo`0]Ool00`00Oomoo`0bOol00`00Oomoo`05Ool00`00Oomoo`07Ool002Aoo`03001o
ogoo00Eoo`03001oogoo035oo`03001oogoo02ioo`03001oogoo01Moo`03001oogoo01Qoo`03001o
ogoo02ioo`03001oogoo035oo`03001oogoo00Eoo`03001oogoo00Moo`007Goo0P001Goo00<007oo
Ool01Goo00<007ooOol0<7oo00<007ooOol0<7oo00<007ooOol05Woo00<007ooOol067oo00<007oo
Ool0;Woo00<007ooOol0<Goo00<007ooOol01Goo00<007ooOol01goo000LOol01000Oomoo`0017oo
00<007ooOol01Goo00<007ooOol0<7oo00<007ooOol0<7oo00<007ooOol05Woo00<007ooOol05goo
00<007ooOol0;goo00<007ooOol0<7oo00<007ooOol01Woo00<007ooOol01goo000LOol01000Oomo
o`0017ooo`004@002Goo000LOol01000Oomoo`0017oo00<007ooOol01Goo00<007ooOol0<7oo00<0
07ooOol0<7oo00<007ooOol05Woo00<007ooOol05goo00<007ooOol0;goo00<007ooOol0<7oo00<0
07ooOol01Woo00<007ooOol01goo000LOol01000Oomoo`0017oo00<007ooOol01Woo00<007ooOol0
;goo00<007ooOol0<7oo00<007ooOol05Woo00<007ooOol05goo00<007ooOol0<7oo00<007ooOol0
;goo00<007ooOol01Woo00<007ooOol01goo000LOol01000Oomoo`0017oo00<007ooOol01Woo00<0
07ooOol0;Woo00<007ooOol0<Woo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol0<Goo00<0
07ooOol0;goo00<007ooOol01Woo00<007ooOol01goo000MOol20005Ool00`00Oomoo`06Ool00`00
Oomoo`0^Ool00`00Oomoo`0bOol00`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`0aOol00`00
Oomoo`0^Ool00`00Oomoo`07Ool00`00Oomoo`07Ool002Aoo`03001oogoo00Ioo`03001oogoo02io
o`03001oogoo039oo`03001oogoo01Eoo`03001oogoo01Ioo`03001oogoo035oo`03001oogoo02io
o`03001oogoo00Moo`03001oogoo00Moo`0097oo00<007ooOol01Woo00<007ooOol0;Woo00<007oo
Ool0<Woo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol0<Woo00<007ooOol0;Goo00<007oo
Ool01goo00<007ooOol01goo000TOol00`00Oomoo`07Ool00`00Oomoo`0]Ool00`00Oomoo`0bOol0
0`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`0bOol00`00Oomoo`0]Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool002Aoo`8000Qoo`03001oogoo02aoo`03001oogoo03Aoo`03001oogoo01Aoo`03
001oogoo01Eoo`03001oogoo03=oo`03001oogoo02eoo`03001oogoo00Ioo`8000Uoo`0097oo00<0
07ooOol01goo00<007ooOol0;7oo00<007ooOol0=7oo00<007ooOol057oo00<007ooOol05Goo00<0
07ooOol0<goo00<007ooOol0;7oo00<007ooOol027oo00<007ooOol01goo000TOol00`00Oomoo`07
Ool00`00Oomoo`0/Ool00`00Oomoo`0dOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0c
Ool00`00Oomoo`0/Ool00`00Oomoo`08Ool00`00Oomoo`07Ool002Aoo`03001oogoo00Moo`03001o
ogoo02aoo`03001oogoo03Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo03Aoo`03001o
ogoo02]oo`03001oogoo00Qoo`03001oogoo00Moo`0097oo00<007ooOol027oo00<007ooOol0:goo
00<007ooOol0=7oo00<007ooOol057oo00<007ooOol057oo00<007ooOol0=Goo00<007ooOol0:goo
00<007ooOol027oo00<007ooOol01goo000TOol00`00Oomoo`08Ool00`00Oomoo`0ZOol00`00Oomo
o`0fOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomoo`0eOol00`00Oomoo`0[Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool002Aoo`03001oogoo00Qoo`03001oogoo02Yoo`03001oogoo03Ioo`03
001oogoo01=oo`03001oogoo01Aoo`03001oogoo03Eoo`03001oogoo02Yoo`03001oogoo00Uoo`03
001oogoo00Moo`0097oo00<007ooOol027oo00<007ooOol0:Woo00<007ooOol0=Woo00<007ooOol0
4goo00<007ooOol057oo00<007ooOol0=Woo00<007ooOol0:Goo00<007ooOol02Goo00<007ooOol0
1goo000TOol20009Ool00`00Oomoo`0ZOol00`00Oomoo`0fOol00`00Oomoo`0COol00`00Oomoo`0D
Ool00`00Oomoo`0fOol00`00Oomoo`0YOol00`00Oomoo`08Ool20009Ool002Aoo`03001oogoo00Uo
o`03001oogoo02Qoo`03001oogoo03Moo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo03Mo
o`03001oogoo02Uoo`03001oogoo00Uoo`03001oogoo00Moo`0097oo00<007ooOol02Goo00<007oo
Ool0:7oo00<007ooOol0>7oo00<007ooOol04Woo00<007ooOol04goo00<007ooOol0=goo00<007oo
Ool0:7oo00<007ooOol02Woo00<007ooOol01goo000TOol00`00Oomoo`09Ool00`00Oomoo`0XOol0
0`00Oomoo`0hOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0hOol00`00Oomoo`0WOol0
0`00Oomoo`0:Ool00`00Oomoo`07Ool002Aoo`03001oogoo00Uoo`03001oogoo02Qoo`03001oogoo
03Qoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo03Qoo`03001oogoo02Moo`03001oogoo
00Yoo`03001oogoo00Moo`0097oo00<007ooOol02Woo00<007ooOol09goo00<007ooOol0>7oo00<0
07ooOol04Woo00<007ooOol04Woo00<007ooOol0>Goo00<007ooOol09goo00<007ooOol02Woo00<0
07ooOol01goo000TOol00`00Oomoo`0:Ool00`00Oomoo`0VOol00`00Oomoo`0jOol00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`0iOol00`00Oomoo`0WOol00`00Oomoo`0:Ool00`00Oomoo`07
Ool002Aoo`03001oogoo00Yoo`03001oogoo02Ioo`03001oogoo03Yoo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo03Uoo`03001oogoo02Ioo`03001oogoo00]oo`03001oogoo00Moo`0097oo
0P002goo00<007ooOol09Woo00<007ooOol0>Woo00<007ooOol04Goo00<007ooOol04Woo00<007oo
Ool0>Woo00<007ooOol09Goo00<007ooOol02Woo0P002Goo000TOol00`00Oomoo`0;Ool00`00Oomo
o`0UOol00`00Oomoo`0jOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0kOol00`00Oomo
o`0UOol00`00Oomoo`0;Ool00`00Oomoo`07Ool002Aoo`03001oogoo00]oo`03001oogoo02Eoo`03
001oogoo03Yoo`03001oogoo015oo`03001oogoo015oo`03001oogoo03]oo`03001oogoo02Eoo`03
001oogoo00]oo`03001oogoo00Moo`0097oo00<007ooOol02goo00<007ooOol097oo00<007ooOol0
?7oo00<007ooOol047oo00<007ooOol04Goo00<007ooOol0>goo00<007ooOol09Goo00<007ooOol0
2goo00<007ooOol01goo000TOol00`00Oomoo`0;Ool00`00Oomoo`0TOol00`00Oomoo`0lOol00`00
Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0lOol00`00Oomoo`0SOol00`00Oomoo`0<Ool00`00
Oomoo`07Ool002Aoo`03001oogoo00]oo`03001oogoo02Aoo`03001oogoo03aoo`03001oogoo011o
o`03001oogoo015oo`03001oogoo03aoo`03001oogoo02=oo`03001oogoo00aoo`03001oogoo00Mo
o`0097oo00<007ooOol037oo00<007ooOol08goo00<007ooOol0?7oo00<007ooOol047oo00<007oo
Ool047oo00<007ooOol0?Goo00<007ooOol08goo00<007ooOol037oo00<007ooOol01goo000TOol0
0`00Oomoo`0<Ool00`00Oomoo`0ROol00`00Oomoo`0nOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool0
0`00Oomoo`0mOol00`00Oomoo`0SOol00`00Oomoo`0<Ool00`00Oomoo`07Ool002Aoo`8000eoo`03
001oogoo029oo`03001oogoo03ioo`03001oogoo00moo`03001oogoo011oo`03001oogoo03eoo`03
001oogoo02=oo`03001oogoo00]oo`8000Uoo`0097oo00<007ooOol037oo00<007ooOol08Woo00<0
07ooOol0?Woo00<007ooOol03goo00<007ooOol047oo00<007ooOol0?Woo00<007ooOol08Goo00<0
07ooOol03Goo00<007ooOol01goo000TOol00`00Oomoo`0=Ool00`00Oomoo`0QOol00`00Oomoo`0n
Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0oOol00`00Oomoo`0QOol00`00Oomoo`0=
Ool00`00Oomoo`07Ool002Aoo`03001oogoo00eoo`03001oogoo025oo`03001oogoo03ioo`03001o
ogoo00moo`03001oogoo00moo`03001oogoo03moo`03001oogoo025oo`03001oogoo00eoo`03001o
ogoo00Moo`0097oo00<007ooOol03Goo00<007ooOol087oo00<007ooOol0@7oo00<007ooOol03Woo
00<007ooOol03goo00<007ooOol0?goo00<007ooOol08Goo00<007ooOol03Goo00<007ooOol01goo
000TOol00`00Oomoo`0=Ool00`00Oomoo`0POol00`00Oomoo`10Ool00`00Oomoo`0>Ool00`00Oomo
o`0?Ool00`00Oomoo`10Ool00`00Oomoo`0POol00`00Oomoo`0=Ool00`00Oomoo`07Ool0015oo`80
00Aoo`03001oogoo009oo`<000Eoo`03001oogoo00ioo`03001oogoo01moo`03001oogoo041oo`03
001oogoo00ioo`03001oogoo00ioo`03001oogoo045oo`03001oogoo01moo`03001oogoo00ioo`03
001oogoo00Moo`0047oo00@007ooOol000Moo`05001oogooOol00004Ool00`00Oomoo`0>Ool00`00
Oomoo`0OOol00`00Oomoo`10Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`11Ool00`00
Oomoo`0OOol00`00Oomoo`0>Ool00`00Oomoo`07Ool0011oo`04001oogoo000;Ool00`00Oomoo`02
Ool3000>Ool00`00Oomoo`0OOol00`00Oomoo`10Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00
Oomoo`11Ool00`00Oomoo`0OOol00`00Oomoo`0<Ool30009Ool0011oo`04001oogoo000;Ool00`00
Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`0NOol00`00Oomoo`12Ool00`00Oomoo`0=Ool00`00
Oomoo`0>Ool00`00Oomoo`11Ool00`00Oomoo`0OOol00`00Oomoo`0>Ool00`00Oomoo`07Ool0011o
o`04001oogoo0007Ool40005Ool00`00Oomoo`0?Ool00`00Oomoo`0MOol00`00Oomoo`12Ool00`00
Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`12Ool00`00Oomoo`0NOol00`00Oomoo`0>Ool00`00
Oomoo`07Ool0011oo`04001oogoo0007Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`0M
Ool00`00Oomoo`12Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`13Ool00`00Oomoo`0M
Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool0015oo`8000Qoo`D000Aoo`03001oogoo00moo`03001o
ogoo01eoo`03001oogoo049oo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo04=oo`03001o
ogoo01eoo`03001oogoo00moo`03001oogoo00Moo`0097oo00<007ooOol03goo00<007ooOol07Goo
00<007ooOol0@goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol0@goo00<007ooOol07Goo
00<007ooOol03goo00<007ooOol01goo000TOol00`00Oomoo`0@Ool00`00Oomoo`0KOol00`00Oomo
o`14Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`14Ool00`00Oomoo`0LOol00`00Oomo
o`0?Ool00`00Oomoo`07Ool002Aoo`03001oogoo011oo`03001oogoo01]oo`03001oogoo04Aoo`03
001oogoo00aoo`03001oogoo00aoo`03001oogoo04Eoo`03001oogoo01]oo`03001oogoo011oo`03
001oogoo00Moo`0097oo0P004Goo00<007ooOol06goo00<007ooOol0AGoo00<007ooOol02goo00<0
07ooOol037oo00<007ooOol0AGoo00<007ooOol06goo00<007ooOol03goo0P002Goo000TOol00`00
Oomoo`0@Ool00`00Oomoo`0KOol00`00Oomoo`15Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00
Oomoo`15Ool00`00Oomoo`0KOol00`00Oomoo`0@Ool00`00Oomoo`07Ool002Aoo`03001oogoo015o
o`03001oogoo01Uoo`03001oogoo04Ioo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo04Io
o`03001oogoo01Uoo`03001oogoo015oo`03001oogoo00Moo`0097oo00<007ooOol04Goo00<007oo
Ool06Goo00<007ooOol0AWoo00<007ooOol02goo00<007ooOol02goo00<007ooOol0Agoo00<007oo
Ool06Goo00<007ooOol04Goo00<007ooOol01goo000TOol00`00Oomoo`0AOol00`00Oomoo`0IOol0
0`00Oomoo`17Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`17Ool00`00Oomoo`0IOol0
0`00Oomoo`0AOol00`00Oomoo`07Ool002Aoo`03001oogoo015oo`03001oogoo01Qoo`03001oogoo
04Qoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo04Qoo`03001oogoo01Moo`03001oogoo
019oo`03001oogoo00Moo`0097oo00<007ooOol04Goo00<007ooOol067oo00<007ooOol0B7oo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol0BGoo00<007ooOol05goo00<007ooOol04Woo00<0
07ooOol01goo000TOol00`00Oomoo`0BOol00`00Oomoo`0GOol00`00Oomoo`19Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`19Ool00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`07
Ool002Aoo`8001=oo`03001oogoo01Ioo`03001oogoo04Yoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo04Uoo`03001oogoo01Moo`03001oogoo015oo`8000Uoo`0097oo00<007ooOol04Woo
00<007ooOol05Woo00<007ooOol0BWoo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0BWoo
00<007ooOol05Goo00<007ooOol04goo00<007ooOol01goo000TOol00`00Oomoo`0BOol00`00Oomo
o`0FOol00`00Oomoo`1:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`1;Ool00`00Oomo
o`0EOol00`00Oomoo`0COol00`00Oomoo`07Ool002Aoo`03001oogoo01=oo`03001oogoo01Eoo`03
001oogoo04]oo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo04]oo`03001oogoo01Eoo`03
001oogoo01=oo`03001oogoo00Moo`0097oo00<007ooOol04goo00<007ooOol057oo00<007ooOol0
C7oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0Bgoo00<007ooOol057oo00<007ooOol0
57oo00<007ooOol01goo000TOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomoo`1<Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`1<Ool00`00Oomoo`0COol00`00Oomoo`0DOol00`00
Oomoo`07Ool002Aoo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo04eoo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo04eoo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo00Mo
o`0097oo00<007ooOol057oo00<007ooOol04Woo00<007ooOol0CWoo00<007ooOol01goo00<007oo
Ool027oo00<007ooOol0CGoo00<007ooOol04Woo00<007ooOol05Goo00<007ooOol01goo000TOol2
000EOol00`00Oomoo`0BOol00`00Oomoo`1>Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`1>Ool00`00Oomoo`0AOol00`00Oomoo`0DOol20009Ool002Aoo`03001oogoo01Eoo`03001oogoo
015oo`03001oogoo04moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo04moo`03001oogoo
015oo`03001oogoo01Eoo`03001oogoo00Moo`0097oo00<007ooOol05Goo00<007ooOol04Goo00<0
07ooOol0Cgoo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0Cgoo00<007ooOol04Goo00<0
07ooOol05Goo00<007ooOol01goo000TOol00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`1@
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`1AOol00`00Oomoo`0?Ool00`00Oomoo`0F
Ool00`00Oomoo`07Ool002Aoo`03001oogoo01Ioo`03001oogoo00moo`03001oogoo055oo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo055oo`03001oogoo00moo`03001oogoo01Ioo`03001o
ogoo00Moo`0097oo00<007ooOol05Woo00<007ooOol03goo00<007ooOol0DGoo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol0DGoo00<007ooOol03goo00<007ooOol05Woo00<007ooOol01goo
000TOol00`00Oomoo`0FOol00`00Oomoo`0>Ool00`00Oomoo`1BOol00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`1COol00`00Oomoo`0=Ool00`00Oomoo`0GOol00`00Oomoo`07Ool002Aoo`03
001oogoo01Moo`03001oogoo00eoo`03001oogoo05=oo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo05=oo`03001oogoo00eoo`03001oogoo01Moo`03001oogoo00Moo`0097oo0P006Goo00<0
07ooOol037oo00<007ooOol0Dgoo00<007ooOol017oo00<007ooOol017oo00<007ooOol0EGoo00<0
07ooOol02goo00<007ooOol05goo0P002Goo000TOol00`00Oomoo`0HOol00`00Oomoo`0;Ool00`00
Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`1EOol00`00Oomoo`0:Ool00`00
Oomoo`0IOol00`00Oomoo`07Ool002Aoo`03001oogoo01Uoo`03001oogoo00Uoo`03001oogoo05Io
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo05Eoo`03001oogoo00Yoo`03001oogoo01Uo
o`03001oogoo00Moo`0097oo00<007ooOol06Goo00<007ooOol02Goo00<007ooOol0EWoo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol0Egoo00<007ooOol027oo00<007ooOol06Woo00<007oo
Ool01goo000TOol00`00Oomoo`0JOol00`00Oomoo`07Ool00`00Oomoo`1HOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`1GOol00`00Oomoo`08Ool00`00Oomoo`0JOol00`00Oomoo`07Ool0
02Aoo`03001oogoo01]oo`03001oogoo00Ioo`03001oogoo05Uoo`05001oogooOol00004Ool00`00
Oomoo`1IOol00`00Oomoo`07Ool00`00Oomoo`0JOol00`00Oomoo`07Ool001aoo`<000Eoo`03001o
ogoo01]oo`03001oogoo00Eoo`03001oogoo05]oo`04001oogoo0003Ool00`00Oomoo`1KOol00`00
Oomoo`05Ool00`00Oomoo`0KOol00`00Oomoo`07Ool001eoo`03001oogoo00Aoo`03001oogoo01ao
o`8000=oo`8005ioo`800005Ool007ooOol0001OOol20003Ool2000NOol00`00Oomoo`07Ool001eo
o`03001oogoo00Aoo`<001eoo`D0065oo`@0065oo`D001eoo`<000Uoo`007Goo00<007ooOol017oo
00<007ooOol0Q7oo00<007ooOol0QGoo00<007ooOol01goo000MOol00`00Oomoo`04Ool00`00Oomo
o`0;Ool00`00Oomoo`0VOol00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`0VOol00`00Oomo
o`0UOol00`00Oomoo`0UOol00`00Oomoo`0<Ool00`00Oomoo`07Ool001aoo`8000Ioo`03001oogoo
00=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`007Goo00<0
07ooOol017ooo`004@002Goo003oOolnOol00?moocioo`00ogoo?Woo003oOolnOol00<aoo`<006io
o`00cgoo00<007ooOol0Jgoo000mOol20002Ool600000goo00000002000017oo0000000017oo1000
00Aoo`00001oo`8000=oo`8000Aoo`03001oogoo00Moo`<000=oo`800003Ool0000000=oo`8000Ao
o`03001oogoo00Moo`D000=oo`800003Ool007oo00<000Qoo`<0009oo`03001oo`0000<00005Ool0
0000001oo`0200000goo0000000200000goo000000020003Ool40002Ool40003Ool00`00Oomoo`04
Ool50002Ool30002Ool40004Ool2000DOol5000017oo0000000017oo0`000Woo1@008Woo000lOol0
1000Oomoo`000Woo00H007ooOol007oo0002Ool01@00Oomoogoo000017oo00@007ooOol000=oo`03
001oo`0000=oo`04001oogoo000>Ool00`00Oomoo`03Ool00`00Ool00003Ool01000Oomoo`003goo
00<007ooOol00Woo00@007ooOol000=oo`03001oogoo00Qoo`06001oogoo001oo`000Woo00D007oo
Oomoo`00009oo`03001oo`00009oo`05001oogooOol00002Ool00`00Ool00002Ool01000Oomoo`00
0goo00<007ooOol02Woo00D007ooOomoo`0000Uoo`04001oogoo0002Ool00`00Oomoo`0COol00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0ROol003]oo`03001oogoo00Ao
o`04001oogoo0002Ool30003Ool00`00Oomoo`03Ool30003Ool20004Ool00`00Oomoo`0?Ool00`00
Oomoo`03Ool20004Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol0
27oo00<007oo00000goo0`000goo00H007ooOol007oo0002Ool01@00Oomoogoo00000Woo00<007oo
00000Woo00@007ooOol000=oo`03001oogoo00Yoo`04001oogooOol50002Ool30003Ool00`00Oomo
o`09Ool40009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool50003Ool00`00Oomoo`0ROol003]oo`03
001oogoo00Aoo`06001oogoo001oo`000Woo00@007ooOomoo`8000=oo`04001oogoo0003Ool00`00
Ool00003Ool00`00Oomoo`0?Ool30003Ool00`00Ool00003Ool00`00Oomoo`0@Ool00`00Oomoo`02
Ool01000Oomoo`000goo0P002Goo0`000Woo00@007ooOol000=oo`06001oogoo001oo`000Woo00D0
07ooOomoo`00009oo`03001oo`00009oo`04001oogoo0003Ool00`00Oomoo`0:Ool01@00Oomoogoo
00000goo00<007oo00001Woo00<007ooOol05Woo00<007ooOol00Woo0P000goo00D007ooOomoo`00
00=oo`03001oogoo029oo`00>goo00<007ooOol017oo0`000goo0P000goo0P0000=oo`0000000Woo
0P0017oo00D007oo000007oo00@000moo`03001oogoo00=oo`05001oo`00001oo`04000?Ool40000
17oo000007oo0P000Woo0P0000=oo`0000001goo00@007ooOol0009oo`8000=oo`@000=oo`<000=o
o`<000=oo`<000=oo`D000Yoo`@0009oo`<000=oo`@00003Ool00000008001Eoo`@00004Ool00000
Ool20002Ool30002Ool3000TOol003aoo`04001oogoo0002Ool00`00Oomoo`0EOol00`00Oomoo`03
Ool00`00Oomoo`0?Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol047oo00<007ooOol0
57oo00@007ooOol0011oo`05001oogooOol00007Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00
Oomoo`0FOol00`00Oomoo`0dOol003eoo`<00003Ool0000001Ioo`8000Eoo`03001oogoo00ioo`D0
0003Ool0000000Eoo`03001oogoo015oo`80009oo`03001oo`0000ioo`@0011oo`80009oo`8000Io
o`8001Aoo`8000ioo`03001oogoo01Moo`8000moo`03001oogoo029oo`00ogoo?Woo003oOolnOol0
0001\
\>"],
  ImageRangeCache->{{{0, 316.625}, {195.312, 0}} -> {-10.6562, -1.2053, \
0.061975, 0.0125347}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Berechne die Nullstellen der charakteristischen Gleichung, d.h. \
berechne beta*l fuer i = 1, ni\
\>", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Char  = Charglg/.l->1;
betal = Table[0,{ni}];
Print[\"  l |     betal * l       | betal  fuer l = \",len];
Print[\"------------------------------------------------\"];
Do [
\terg = FindRoot[Char == 0, {beta,(i1*2-1)*Pi/2}];
\tbli = beta/.erg[[1]];
\tbetal[[i1]] = bli;
\tPrint[ PaddedForm [i1,        2],\" | \",
\t       PaddedForm [bli,{17,15}],\" | \",PaddedForm [bli/len,{17,15}]];
,{i1,ni}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("  l |     betal * l       | betal  fuer l = "\
\[InvisibleSpace]12\),
      SequenceForm[ "  l |     betal * l       | betal  fuer l = ", 12],
      Editable->False]], "Print"],

Cell[BoxData[
    \("------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  1\"\>",
            1,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.570796326794897\"\>",
            1.5707963267948966,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  0.130899693899575\"\>",
            0.1308996938995747,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)]}],
      SequenceForm[ 
        PaddedForm[ 1, 2], " | ", 
        PaddedForm[ 1.5707963267948966, {17, 15}], " | ", 
        PaddedForm[ 0.1308996938995747, {17, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  2\"\>",
            2,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  4.712388980384690\"\>",
            4.7123889803846897,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  0.392699081698724\"\>",
            0.39269908169872414,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)]}],
      SequenceForm[ 
        PaddedForm[ 2, 2], " | ", 
        PaddedForm[ 4.7123889803846897, {17, 15}], " | ", 
        PaddedForm[ 0.39269908169872414, {17, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  3\"\>",
            3,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  7.853981633974483\"\>",
            7.8539816339744828,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  0.654498469497874\"\>",
            0.6544984694978736,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)]}],
      SequenceForm[ 
        PaddedForm[ 3, 2], " | ", 
        PaddedForm[ 7.8539816339744828, {17, 15}], " | ", 
        PaddedForm[ 0.6544984694978736, {17, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  4\"\>",
            4,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 10.995574287564280\"\>",
            10.995574287564276,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  0.916297857297023\"\>",
            0.91629785729702296,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)]}],
      SequenceForm[ 
        PaddedForm[ 4, 2], " | ", 
        PaddedForm[ 10.995574287564276, {17, 15}], " | ", 
        PaddedForm[ 0.91629785729702296, {17, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  5\"\>",
            5,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 14.137166941154070\"\>",
            14.137166941154069,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.178097245096172\"\>",
            1.1780972450961724,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)]}],
      SequenceForm[ 
        PaddedForm[ 5, 2], " | ", 
        PaddedForm[ 14.137166941154069, {17, 15}], " | ", 
        PaddedForm[ 1.1780972450961724, {17, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  6\"\>",
            6,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 17.278759594743860\"\>",
            17.27875959474386,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.439896632895322\"\>",
            1.4398966328953218,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)]}],
      SequenceForm[ 
        PaddedForm[ 6, 2], " | ", 
        PaddedForm[ 17.27875959474386, {17, 15}], " | ", 
        PaddedForm[ 1.4398966328953218, {17, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  7\"\>",
            7,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 20.420352248333660\"\>",
            20.420352248333657,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.701696020694471\"\>",
            1.7016960206944713,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)]}],
      SequenceForm[ 
        PaddedForm[ 7, 2], " | ", 
        PaddedForm[ 20.420352248333657, {17, 15}], " | ", 
        PaddedForm[ 1.7016960206944713, {17, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  8\"\>",
            8,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 23.561944901923450\"\>",
            23.561944901923447,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.963495408493620\"\>",
            1.9634954084936205,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)]}],
      SequenceForm[ 
        PaddedForm[ 8, 2], " | ", 
        PaddedForm[ 23.561944901923447, {17, 15}], " | ", 
        PaddedForm[ 1.9634954084936205, {17, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  9\"\>",
            9,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 26.703537555513240\"\>",
            26.703537555513243,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  2.225294796292770\"\>",
            2.2252947962927703,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)]}],
      SequenceForm[ 
        PaddedForm[ 9, 2], " | ", 
        PaddedForm[ 26.703537555513243, {17, 15}], " | ", 
        PaddedForm[ 2.2252947962927703, {17, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\" 10\"\>",
            10,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 29.845130209103030\"\>",
            29.845130209103033,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  2.487094184091919\"\>",
            2.4870941840919194,
            AutoDelete->True],
          (PaddedForm[ #, {17, 15}]&)]}],
      SequenceForm[ 
        PaddedForm[ 10, 2], " | ", 
        PaddedForm[ 29.845130209103033, {17, 15}], " | ", 
        PaddedForm[ 2.4870941840919194, {17, 15}]],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.\tBestimme die Eigenfunktionen des Balkens fuer die genannten \
Randbedingungen.\
\>", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
3.1 Berechne die Konstanten Ck = {C1, C2} der Glg. CMat . C = 0 \
fuer Werte von beta*l und l = len. 
Bestimme hieraus die Eigenfunktionen Wi(x). Skaliere die Funktionen gemaess \
Skalierg.\
\>", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Wi  = Table[0,{ni}];
Mi = Table[0,{ni}]; 
Ki = Table[0,{ni}]; 
Qi = Table[0,{ni}]; 
 
Print[\"  i |    Ai           Bi   fuer l = \",len,\"  | Freq[Hz]   Mi       \
Ki           Qi      Wi(L) \"];
Print[\"----------------------------------------------------------------------\
------------------------\"];
Do [ 
    Ck      = NullSpace[CMat /.{beta->betal[[i1]]/len,l->len}];
    Wih     = W /.{C1->Ck[[1,1]], C2->Chop[Ck[[1,2]]],beta->betal[[i1]]/len};
    If[Skalierg===1,xmax = 1.0; Skal = Wih/.x->xmax; ];             
    If[Skalierg===2,Skal = Sqrt[massmy*NIntegrate[Wih^2,{x,0,len}]] ];
    Wi [[i1]] = Chop[Expand[Wih / Skal]];              
    Mi[[i1]] = NIntegrate[massmy*Wi[[i1]]^2,{x,0,len}];                  
        dWi  = D[Wi[[i1]],{x,1}];
    Ki[[i1]] = NIntegrate[Emodv*AQuer*dWi^2,{x,0,len}];
    Qi[[i1]] = NIntegrate[Wi[[i1]],{x,0,len}];
     
    Frequi  = Sqrt[Ki[[i1]]/Mi[[i1]]] / (2 * Pi)//N;
\tPrint[ PaddedForm [i1,     2],\" | \",
\t       PaddedForm [Ck[[1,1]]/Skal ,{13,12}],
\t       PaddedForm [Chop[Ck[[1,2]]/Skal] ,{15,12}],\"  |\",
\t       PaddedForm [Frequi//N      ,{8,3}],
\t       PaddedForm [Mi[[i1]]      ,{6 ,4}],
\t       PaddedForm [Ki[[i1]]      ,{9,4}],
\t       PaddedForm [Qi[[i1]]      ,{9,4}],
\t       PaddedForm [Wi[[i1]]/.x->len      ,{9,4}]
\t       ];
,{i1,ni}]; \
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("  i |    Ai           Bi   fuer l = "\
\[InvisibleSpace]12\[InvisibleSpace]"  | Freq[Hz]   Mi       Ki           Qi  \
    Wi(L) "\),
      SequenceForm[ 
      "  i |    Ai           Bi   fuer l = ", 12, 
        "  | Freq[Hz]   Mi       Ki           Qi      Wi(L) "],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------------\
-----------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  1\"\>",
            1,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 2.437382614334\"\>",
            2.437382614333671,
            AutoDelete->True],
          (PaddedForm[ #, {13, 12}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.000000000000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {15, 12}]&)], "\[InvisibleSpace]", "\<\"  |\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    76.370\"\>",
            76.370152214785094,
            AutoDelete->True],
          (PaddedForm[ #, {8, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.0000\"\>",
            1.0,
            AutoDelete->True],
          (PaddedForm[ #, {6, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 230253.9290\"\>",
            230253.92873015485,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    18.6202\"\>",
            18.620231581317626,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     2.4374\"\>",
            2.437382614333671,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)]}],
      SequenceForm[ 
        PaddedForm[ 1, 2], " | ", 
        PaddedForm[ 2.437382614333671, {13, 12}], 
        PaddedForm[ 0, {15, 12}], "  |", 
        PaddedForm[ 76.370152214785094, {8, 3}], 
        PaddedForm[ 1.0, {6, 4}], 
        PaddedForm[ 230253.92873015485, {9, 4}], 
        PaddedForm[ 18.620231581317626, {9, 4}], 
        PaddedForm[ 2.437382614333671, {9, 4}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  2\"\>",
            2,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"-2.437382614334\"\>",
            -2.4373826143336705,
            AutoDelete->True],
          (PaddedForm[ #, {13, 12}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.000000000000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {15, 12}]&)], "\[InvisibleSpace]", "\<\"  |\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   229.110\"\>",
            229.11045664435525,
            AutoDelete->True],
          (PaddedForm[ #, {8, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.0000\"\>",
            0.99999999999999978,
            AutoDelete->True],
          (PaddedForm[ #, {6, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     2.0723"\[Times]10\^"6"\),
            2072285.3585713929,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -6.2067\"\>",
            -6.2067438604392073,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     2.4374\"\>",
            2.4373826143336705,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)]}],
      SequenceForm[ 
        PaddedForm[ 2, 2], " | ", 
        PaddedForm[ -2.4373826143336705, {13, 12}], 
        PaddedForm[ 0, {15, 12}], "  |", 
        PaddedForm[ 229.11045664435525, {8, 3}], 
        PaddedForm[ 0.99999999999999978, {6, 4}], 
        PaddedForm[ 2072285.3585713929, {9, 4}], 
        PaddedForm[ -6.2067438604392073, {9, 4}], 
        PaddedForm[ 2.4373826143336705, {9, 4}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  3\"\>",
            3,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"-2.437382614334\"\>",
            -2.437382614333671,
            AutoDelete->True],
          (PaddedForm[ #, {13, 12}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.000000000000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {15, 12}]&)], "\[InvisibleSpace]", "\<\"  |\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   381.851\"\>",
            381.85076107392541,
            AutoDelete->True],
          (PaddedForm[ #, {8, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.0000\"\>",
            1.0,
            AutoDelete->True],
          (PaddedForm[ #, {6, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     5.7563"\[Times]10\^"6"\),
            5756348.2182538705,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -3.7240\"\>",
            -3.7240463162635264,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -2.4374\"\>",
            -2.437382614333671,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)]}],
      SequenceForm[ 
        PaddedForm[ 3, 2], " | ", 
        PaddedForm[ -2.437382614333671, {13, 12}], 
        PaddedForm[ 0, {15, 12}], "  |", 
        PaddedForm[ 381.85076107392541, {8, 3}], 
        PaddedForm[ 1.0, {6, 4}], 
        PaddedForm[ 5756348.2182538705, {9, 4}], 
        PaddedForm[ -3.7240463162635264, {9, 4}], 
        PaddedForm[ -2.437382614333671, {9, 4}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  4\"\>",
            4,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"-2.437382614334\"\>",
            -2.4373826143336705,
            AutoDelete->True],
          (PaddedForm[ #, {13, 12}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.000000000000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {15, 12}]&)], "\[InvisibleSpace]", "\<\"  |\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   534.591\"\>",
            534.59106550349554,
            AutoDelete->True],
          (PaddedForm[ #, {8, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.0000\"\>",
            0.99999999999999978,
            AutoDelete->True],
          (PaddedForm[ #, {6, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     1.1282"\[Times]10\^"7"\),
            11282442.507777581,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -2.6600\"\>",
            -2.6600330830453771,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     2.4374\"\>",
            2.4373826143336705,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)]}],
      SequenceForm[ 
        PaddedForm[ 4, 2], " | ", 
        PaddedForm[ -2.4373826143336705, {13, 12}], 
        PaddedForm[ 0, {15, 12}], "  |", 
        PaddedForm[ 534.59106550349554, {8, 3}], 
        PaddedForm[ 0.99999999999999978, {6, 4}], 
        PaddedForm[ 11282442.507777581, {9, 4}], 
        PaddedForm[ -2.6600330830453771, {9, 4}], 
        PaddedForm[ 2.4373826143336705, {9, 4}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  5\"\>",
            5,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"-2.437382614334\"\>",
            -2.4373826143336705,
            AutoDelete->True],
          (PaddedForm[ #, {13, 12}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.000000000000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {15, 12}]&)], "\[InvisibleSpace]", "\<\"  |\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   687.331\"\>",
            687.33136993306573,
            AutoDelete->True],
          (PaddedForm[ #, {8, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.0000\"\>",
            0.99999999999999956,
            AutoDelete->True],
          (PaddedForm[ #, {6, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     1.8651"\[Times]10\^"7"\),
            18650568.227142528,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -2.0689\"\>",
            -2.068914620146403,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -2.4374\"\>",
            -2.4373826143336705,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)]}],
      SequenceForm[ 
        PaddedForm[ 5, 2], " | ", 
        PaddedForm[ -2.4373826143336705, {13, 12}], 
        PaddedForm[ 0, {15, 12}], "  |", 
        PaddedForm[ 687.33136993306573, {8, 3}], 
        PaddedForm[ 0.99999999999999956, {6, 4}], 
        PaddedForm[ 18650568.227142528, {9, 4}], 
        PaddedForm[ -2.068914620146403, {9, 4}], 
        PaddedForm[ -2.4373826143336705, {9, 4}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  6\"\>",
            6,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 2.437382614334\"\>",
            2.437382614333671,
            AutoDelete->True],
          (PaddedForm[ #, {13, 12}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.000000000000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {15, 12}]&)], "\[InvisibleSpace]", "\<\"  |\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   840.072\"\>",
            840.07167436263626,
            AutoDelete->True],
          (PaddedForm[ #, {8, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.0000\"\>",
            0.99999999999999978,
            AutoDelete->True],
          (PaddedForm[ #, {6, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     2.7861"\[Times]10\^"7"\),
            27860725.376348745,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     1.6927\"\>",
            1.6927483255743312,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -2.4374\"\>",
            -2.437382614333671,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)]}],
      SequenceForm[ 
        PaddedForm[ 6, 2], " | ", 
        PaddedForm[ 2.437382614333671, {13, 12}], 
        PaddedForm[ 0, {15, 12}], "  |", 
        PaddedForm[ 840.07167436263626, {8, 3}], 
        PaddedForm[ 0.99999999999999978, {6, 4}], 
        PaddedForm[ 27860725.376348745, {9, 4}], 
        PaddedForm[ 1.6927483255743312, {9, 4}], 
        PaddedForm[ -2.437382614333671, {9, 4}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  7\"\>",
            7,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"-2.437382614334\"\>",
            -2.437382614333671,
            AutoDelete->True],
          (PaddedForm[ #, {13, 12}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.000000000000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {15, 12}]&)], "\[InvisibleSpace]", "\<\"  |\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   992.812\"\>",
            992.81197879220611,
            AutoDelete->True],
          (PaddedForm[ #, {8, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.0000\"\>",
            1.0,
            AutoDelete->True],
          (PaddedForm[ #, {6, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     3.8913"\[Times]10\^"7"\),
            38912913.955396168,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -1.4323\"\>",
            -1.4323255062552049,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -2.4374\"\>",
            -2.437382614333671,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)]}],
      SequenceForm[ 
        PaddedForm[ 7, 2], " | ", 
        PaddedForm[ -2.437382614333671, {13, 12}], 
        PaddedForm[ 0, {15, 12}], "  |", 
        PaddedForm[ 992.81197879220611, {8, 3}], 
        PaddedForm[ 1.0, {6, 4}], 
        PaddedForm[ 38912913.955396168, {9, 4}], 
        PaddedForm[ -1.4323255062552049, {9, 4}], 
        PaddedForm[ -2.437382614333671, {9, 4}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  8\"\>",
            8,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 2.437382614334\"\>",
            2.4373826143336683,
            AutoDelete->True],
          (PaddedForm[ #, {13, 12}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.000000000000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {15, 12}]&)], "\[InvisibleSpace]", "\<\"  |\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1145.552\"\>",
            1145.5522832217739,
            AutoDelete->True],
          (PaddedForm[ #, {8, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.0000\"\>",
            0.99999999999999978,
            AutoDelete->True],
          (PaddedForm[ #, {6, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     5.1807"\[Times]10\^"7"\),
            51807133.964284614,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     1.2413\"\>",
            1.2413487720878469,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -2.4374\"\>",
            -2.4373826143336683,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)]}],
      SequenceForm[ 
        PaddedForm[ 8, 2], " | ", 
        PaddedForm[ 2.4373826143336683, {13, 12}], 
        PaddedForm[ 0, {15, 12}], "  |", 
        PaddedForm[ 1145.5522832217739, {8, 3}], 
        PaddedForm[ 0.99999999999999978, {6, 4}], 
        PaddedForm[ 51807133.964284614, {9, 4}], 
        PaddedForm[ 1.2413487720878469, {9, 4}], 
        PaddedForm[ -2.4373826143336683, {9, 4}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  9\"\>",
            9,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"-2.437382614334\"\>",
            -2.4373826143336701,
            AutoDelete->True],
          (PaddedForm[ #, {13, 12}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.000000000000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {15, 12}]&)], "\[InvisibleSpace]", "\<\"  |\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1298.293\"\>",
            1298.2925876513459,
            AutoDelete->True],
          (PaddedForm[ #, {8, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.0000\"\>",
            0.99999999999999978,
            AutoDelete->True],
          (PaddedForm[ #, {6, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     6.6543"\[Times]10\^"7"\),
            66543385.403014675,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -1.0953\"\>",
            -1.0953077400775089,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -2.4374\"\>",
            -2.4373826143336701,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)]}],
      SequenceForm[ 
        PaddedForm[ 9, 2], " | ", 
        PaddedForm[ -2.4373826143336701, {13, 12}], 
        PaddedForm[ 0, {15, 12}], "  |", 
        PaddedForm[ 1298.2925876513459, {8, 3}], 
        PaddedForm[ 0.99999999999999978, {6, 4}], 
        PaddedForm[ 66543385.403014675, {9, 4}], 
        PaddedForm[ -1.0953077400775089, {9, 4}], 
        PaddedForm[ -2.4373826143336701, {9, 4}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\" 10\"\>",
            10,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 2.437382614334\"\>",
            2.4373826143336714,
            AutoDelete->True],
          (PaddedForm[ #, {13, 12}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.000000000000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {15, 12}]&)], "\[InvisibleSpace]", "\<\"  |\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1451.033\"\>",
            1451.0328920809175,
            AutoDelete->True],
          (PaddedForm[ #, {8, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1.0000\"\>",
            0.99999999999999978,
            AutoDelete->True],
          (PaddedForm[ #, {6, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     8.3122"\[Times]10\^"7"\),
            83121668.271586001,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.9800\"\>",
            0.98001218849040406,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    -2.4374\"\>",
            -2.4373826143336714,
            AutoDelete->True],
          (PaddedForm[ #, {9, 4}]&)]}],
      SequenceForm[ 
        PaddedForm[ 10, 2], " | ", 
        PaddedForm[ 2.4373826143336714, {13, 12}], 
        PaddedForm[ 0, {15, 12}], "  |", 
        PaddedForm[ 1451.0328920809175, {8, 3}], 
        PaddedForm[ 0.99999999999999978, {6, 4}], 
        PaddedForm[ 83121668.271586001, {9, 4}], 
        PaddedForm[ 0.98001218849040406, {9, 4}], 
        PaddedForm[ -2.4373826143336714, {9, 4}]],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Print[\"  i | Wi(x)   fuer l = \",len];
Print[\"---------------------------------------\"];
Do [ 
\tPrint[ PaddedForm[i,2],\" | \", N[Wi[[i]],14] ];
,{i,1,ni}]; \
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("  i | Wi(x)   fuer l = "\[InvisibleSpace]12\),
      SequenceForm[ "  i | Wi(x)   fuer l = ", 12],
      Editable->False]], "Print"],

Cell[BoxData[
    \("---------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  1\"\>",
            1,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", \(2.437382614333671`\ Sin[
            0.1308996938995747`\ x]\)}],
      SequenceForm[ 
        PaddedForm[ 1, 2], " | ", 
        Times[ 2.437382614333671, 
          Sin[ 
            Times[ 0.1308996938995747, x]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  2\"\>",
            2,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", \(\(-2.4373826143336705`\)\ Sin[
            0.39269908169872414`\ x]\)}],
      SequenceForm[ 
        PaddedForm[ 2, 2], " | ", 
        Times[ -2.4373826143336705, 
          Sin[ 
            Times[ 0.39269908169872414, x]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  3\"\>",
            3,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", \(\(-2.437382614333671`\)\ Sin[
            0.6544984694978736`\ x]\)}],
      SequenceForm[ 
        PaddedForm[ 3, 2], " | ", 
        Times[ -2.437382614333671, 
          Sin[ 
            Times[ 0.6544984694978736, x]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  4\"\>",
            4,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", \(\(-2.4373826143336705`\)\ Sin[
            0.916297857297023`\ x]\)}],
      SequenceForm[ 
        PaddedForm[ 4, 2], " | ", 
        Times[ -2.4373826143336705, 
          Sin[ 
            Times[ 0.91629785729702296, x]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  5\"\>",
            5,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", \(\(-2.4373826143336705`\)\ Sin[
            1.1780972450961724`\ x]\)}],
      SequenceForm[ 
        PaddedForm[ 5, 2], " | ", 
        Times[ -2.4373826143336705, 
          Sin[ 
            Times[ 1.1780972450961724, x]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  6\"\>",
            6,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", \(2.437382614333671`\ Sin[
            1.4398966328953218`\ x]\)}],
      SequenceForm[ 
        PaddedForm[ 6, 2], " | ", 
        Times[ 2.437382614333671, 
          Sin[ 
            Times[ 1.4398966328953218, x]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  7\"\>",
            7,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", \(\(-2.437382614333671`\)\ Sin[
            1.7016960206944713`\ x]\)}],
      SequenceForm[ 
        PaddedForm[ 7, 2], " | ", 
        Times[ -2.437382614333671, 
          Sin[ 
            Times[ 1.7016960206944713, x]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  8\"\>",
            8,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", \(2.4373826143336683`\ Sin[
            1.9634954084936205`\ x]\)}],
      SequenceForm[ 
        PaddedForm[ 8, 2], " | ", 
        Times[ 2.4373826143336683, 
          Sin[ 
            Times[ 1.9634954084936205, x]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  9\"\>",
            9,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", \(\(-2.43738261433367`\)\ Sin[
            2.2252947962927703`\ x]\)}],
      SequenceForm[ 
        PaddedForm[ 9, 2], " | ", 
        Times[ -2.4373826143336701, 
          Sin[ 
            Times[ 2.2252947962927703, x]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\" 10\"\>",
            10,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" | \"\>", 
        "\[InvisibleSpace]", \(2.4373826143336714`\ Sin[
            2.4870941840919194`\ x]\)}],
      SequenceForm[ 
        PaddedForm[ 10, 2], " | ", 
        Times[ 2.4373826143336714, 
          Sin[ 
            Times[ 2.4870941840919194, x]]]],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wi", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({2.437382614333671`\ Sin[
          0.1308996938995747`\ x], \(-2.4373826143336705`\)\ Sin[
          0.39269908169872414`\ x], \(-2.437382614333671`\)\ Sin[
          0.6544984694978736`\ x], \(-2.4373826143336705`\)\ Sin[
          0.916297857297023`\ x], \(-2.4373826143336705`\)\ Sin[
          1.1780972450961724`\ x], 
      2.437382614333671`\ Sin[
          1.4398966328953218`\ x], \(-2.437382614333671`\)\ Sin[
          1.7016960206944713`\ x], 
      2.4373826143336683`\ Sin[
          1.9634954084936205`\ x], \(-2.43738261433367`\)\ Sin[
          2.2252947962927703`\ x], 
      2.4373826143336714`\ Sin[2.4870941840919194`\ x]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2 Zeichne die Eigenfunktionen auf.", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Rahmen = Plot[0,{x,0,len},\t
\tPlotLabel-> \"Eigenfunktionen Dehnung fuer Randbdg.\"Randbg,
\tFrame -> True,  
\tGridLines -> Automatic,
\tPlotRange -> {{0, len}, {-2.5, 2.5}} ];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-17 0.0833333 0.309017 0.123607 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0618 -12 -4.5 ]
[-0.0125 .0618 0 4.5 ]
[-0.0125 .18541 -12 -4.5 ]
[-0.0125 .18541 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .43262 -6 -4.5 ]
[-0.0125 .43262 0 4.5 ]
[-0.0125 .55623 -6 -4.5 ]
[-0.0125 .55623 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -147.312 0 ]
[.5 .63053 147.312 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .61803 L
s
.33333 0 m
.33333 .61803 L
s
.5 0 m
.5 .61803 L
s
.66667 0 m
.66667 .61803 L
s
.83333 0 m
.83333 .61803 L
s
0 .0618 m
1 .0618 L
s
0 .18541 m
1 .18541 L
s
0 .30902 m
1 .30902 L
s
0 .43262 m
1 .43262 L
s
0 .55623 m
1 .55623 L
s
0 g
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0618 m
.00625 .0618 L
s
[(-2)] -0.0125 .0618 1 0 Mshowa
0 .18541 m
.00625 .18541 L
s
[(-1)] -0.0125 .18541 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .43262 m
.00625 .43262 L
s
[(1)] -0.0125 .43262 1 0 Mshowa
0 .55623 m
.00625 .55623 L
s
[(2)] -0.0125 .55623 1 0 Mshowa
.125 Mabswid
0 .08652 m
.00375 .08652 L
s
0 .11125 m
.00375 .11125 L
s
0 .13597 m
.00375 .13597 L
s
0 .16069 m
.00375 .16069 L
s
0 .21013 m
.00375 .21013 L
s
0 .23485 m
.00375 .23485 L
s
0 .25957 m
.00375 .25957 L
s
0 .2843 m
.00375 .2843 L
s
0 .33374 m
.00375 .33374 L
s
0 .35846 m
.00375 .35846 L
s
0 .38318 m
.00375 .38318 L
s
0 .4079 m
.00375 .4079 L
s
0 .45735 m
.00375 .45735 L
s
0 .48207 m
.00375 .48207 L
s
0 .50679 m
.00375 .50679 L
s
0 .53151 m
.00375 .53151 L
s
0 .03708 m
.00375 .03708 L
s
0 .01236 m
.00375 .01236 L
s
0 .58095 m
.00375 .58095 L
s
0 .60567 m
.00375 .60567 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0618 m
1 .0618 L
s
.99375 .18541 m
1 .18541 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .43262 m
1 .43262 L
s
.99375 .55623 m
1 .55623 L
s
.125 Mabswid
.99625 .08652 m
1 .08652 L
s
.99625 .11125 m
1 .11125 L
s
.99625 .13597 m
1 .13597 L
s
.99625 .16069 m
1 .16069 L
s
.99625 .21013 m
1 .21013 L
s
.99625 .23485 m
1 .23485 L
s
.99625 .25957 m
1 .25957 L
s
.99625 .2843 m
1 .2843 L
s
.99625 .33374 m
1 .33374 L
s
.99625 .35846 m
1 .35846 L
s
.99625 .38318 m
1 .38318 L
s
.99625 .4079 m
1 .4079 L
s
.99625 .45735 m
1 .45735 L
s
.99625 .48207 m
1 .48207 L
s
.99625 .50679 m
1 .50679 L
s
.99625 .53151 m
1 .53151 L
s
.99625 .03708 m
1 .03708 L
s
.99625 .01236 m
1 .01236 L
s
.99625 .58095 m
1 .58095 L
s
.99625 .60567 m
1 .60567 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
gsave
.5 .63053 -208.312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigenfunktionen) show
159.000 13.000 moveto
(Dehnung) show
207.000 13.000 moveto
(fuer) show
237.000 13.000 moveto
(Randbdg) show
279.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
285.000 13.000 moveto
0.000 0.000 rmoveto
287.625 13.000 moveto
0.000 0.000 rmoveto
287.625 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(fest) show
317.625 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
329.625 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(frei) show
353.625 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .30902 L
.08481 .30902 L
.12636 .30902 L
.16632 .30902 L
.20885 .30902 L
.2498 .30902 L
.29331 .30902 L
.33524 .30902 L
.37557 .30902 L
.41848 .30902 L
.4598 .30902 L
.49953 .30902 L
.54183 .30902 L
.58254 .30902 L
.62583 .30902 L
.66752 .30902 L
.70762 .30902 L
.7503 .30902 L
.79139 .30902 L
.83505 .30902 L
.87712 .30902 L
.9176 .30902 L
.96065 .30902 L
1 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{153, 94.5},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002I0000GQ000`40O003h00OVGoo000SOol5000@
Ool3000?Ool3000?Ool3000=Ool30004Ool2000:Ool30002Ool5000@Ool002Aoo`04001oogoo000A
Ool00`00Oomoo`0=Ool01@00Oomoogoo00003Goo00D007ooOomoo`0000eoo`03001oogoo009oo`04
001oogoo000:Ool00`00Oomoo`02Ool01000Oomoo`0047oo000UOol00`00Oomoo`0>Ool5000>Ool0
1@00Oomoogoo00003Goo00D007ooOomoo`0000eoo`03001oogoo009oo`04001oogoo000:Ool00`00
Oomoo`03Ool00`00Oomoo`0@Ool002Ioo`03001oogoo00eoo`04001oogoo000?Ool4000?Ool3000>
Ool00`00Oomoo`02Ool01000Oomoo`002Woo00<007ooOol017oo00<007ooOol03goo000SOol01@00
Oomoogoo00003goo00<007oo00003goo00<007ooOol03goo00D007ooOomoo`0000eoo`03001oogoo
009oo`04001oogoo000:Ool01@00Oomoogoo00000goo00<007ooOol03Woo000SOol01@00Oomoogoo
000047oo0P0047oo00<007ooOol03Woo00D007ooOomoo`0000aoo`8000Aoo`04001oogoo0009Ool2
0003Ool01@00Oomoogoo000047oo000TOol3000BOol00`00Oomoo`0?Ool2000?Ool3000>Ool00`00
Oomoo`03Ool2000;Ool00`00Oomoo`02Ool3000AOol009Uoo`00VGoo000COomb000DOol001=oo`03
001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`0B
Ool001=oo`80015oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`0300moogoo011o
o`0300moogoo00moo`8001Aoo`004goo00<007ooOol047oo00<03gooOol047oo00<03gooOol047oo
00<03gooOol03goo00<03gooOol047oo00<03gooOol047oo00<007ooOol04Woo000COol00`00Oomo
o`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?Oomo
o`0@Ool00`00Oomoo`0BOol000aoo`D0009oo`80015oo`0300moogoo011oo`0300moogoo011oo`03
00moogoo00moo`0300moogoo011oo`0300moogoo00moo`8001Aoo`003Goo00@007ooOol0009oo`03
001oogoo011oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`0300moogoo011oo`03
00moogoo011oo`03001oogoo019oo`001Woo1@000goo00<007ooOol00Woo0P00KP0?0P0057oo000?
Ool01@00Oomoogoo00004Woo00<03gooOol047oo00<03gooOol047oo00<03gooOol03goo00<03goo
Ool047oo00<03gooOol047oo00<007ooOol04Woo000<Ool01@00Oomoogoo00000Woo00<007ooOol0
47oo00<03gooOol047oo00<03gooOol047oo00<03gooOol03goo00<03gooOol047oo00<03gooOol0
47oo00<007ooOol04Woo000<Ool01@00Oomoogoo00000Woo0P004Goo00<03gooOol047oo00<03goo
Ool047oo00<03gooOol03goo00<03gooOol047oo00<03gooOol03goo0P0057oo000=Ool30003Ool0
0`00Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool0
0`0?Oomoo`0@Ool00`00Oomoo`0BOol001=oo`03001oogoo011oo`0300moogoo011oo`0300moogoo
011oo`0300moogoo00moo`0300moogoo011oo`0300moogoo011oo`03001oogoo019oo`004goo0P00
4Goo00<03gooOol047oo00<03gooOol047oo00<03gooOol03goo00<03gooOol047oo00<03gooOol0
3goo0P0057oo000COol00`00Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?
Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`00Oomoo`0BOol001=oo`03001oogoo011oo`0300mo
ogoo011oo`0300moogoo011oo`0300moogoo00moo`0300moogoo011oo`0300moogoo011oo`03001o
ogoo019oo`004goo0P004Goo00<03gooOol047oo00<03gooOol047oo00<03gooOol03goo00<03goo
Ool047oo00<03gooOol03goo0P0057oo000COol00`00Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomo
o`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`00Oomoo`0BOol001=oo`03
001oogoo011oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`0300moogoo011oo`03
00moogoo011oo`03001oogoo019oo`003Goo0`000goo0P004Goo00<03gooOol047oo00<03gooOol0
47oo00<03gooOol03goo00<03gooOol047oo00<03gooOol03goo0P0057oo000>Ool00`00Oomoo`02
Ool00`00Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@
Ool00`0?Oomoo`0@Ool00`00Oomoo`0BOol000Ioo`D000=oo`03001oogoo009oo`8006h03`8001Ao
o`003Woo00<007ooOol00Woo00<007ooOol047oo00<03gooOol047oo00<03gooOol047oo00<03goo
Ool03goo00<03gooOol047oo00<03gooOol047oo00<007ooOol04Woo000>Ool00`00Oomoo`02Ool0
0`00Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool0
0`0?Oomoo`0@Ool00`00Oomoo`0BOol000eoo`8000Aoo`80015oo`0300moogoo011oo`0300moogoo
011oo`0300moogoo00moo`0300moogoo011oo`0300moogoo00moo`8001Aoo`003Woo00<007ooOol0
0Woo00<007ooOol047oo00<03gooOol047oo00<03gooOol047oo00<03gooOol03goo00<03gooOol0
47oo00<03gooOol047oo00<007ooOol04Woo000COol00`00Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?
Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`00Oomoo`0BOol001=o
o`80015oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`0300moogoo011oo`0300mo
ogoo00moo`8001Aoo`004goo00<007ooOol047oo00<03gooOol047oo00<03gooOol047oo00<03goo
Ool03goo00<03gooOol047oo00<03gooOol047oo00<007ooOol04Woo000COol00`00Oomoo`0@Ool0
0`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool0
0`00Oomoo`0BOol001=oo`80015oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`03
00moogoo011oo`0300moogoo00moo`8001Aoo`004goo00<007ooOol047oo00<03gooOol047oo00<0
3gooOol047oo00<03gooOol03goo00<03gooOol047oo00<03gooOol047oo00<007ooOol04Woo000C
Ool2000AOol00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?
Oomoo`0?Ool2000DOol000ioo`8000=oo`03001oogoo011oo`0300moogoo011oo`0300moogoo011o
o`0300moogoo00moo`0300moogoo011oo`0300moogoo011oo`03001oogoo019oo`003Goo00@007oo
Ool0009oo`03001oogoo011oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`0300mo
ogoo011oo`0300moogoo011oo`03001oogoo019oo`003Goo00@007ooOol0009oog8001Aoo`003Goo
00@007ooOol0009oo`03001oogoo011oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00mo
o`0300moogoo011oo`0300moogoo011oo`03001oogoo019oo`003Goo00@007ooOol0009oo`03001o
ogoo011oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`0300moogoo011oo`0300mo
ogoo011oo`03001oogoo019oo`003Goo00@007ooOol0009oo`80015oo`0300moogoo011oo`0300mo
ogoo011oo`0300moogoo00moo`0300moogoo011oo`0300moogoo00moo`8001Aoo`003Woo0P000goo
00<007ooOol047oo00<03gooOol047oo00<03gooOol047oo00<03gooOol03goo00<03gooOol047oo
00<03gooOol047oo00<007ooOol04Woo000COol00`00Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomo
o`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`00Oomoo`0BOol001=oo`80
015oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`0300moogoo011oo`0300moogoo
00moo`8001Aoo`004goo00<007ooOol047oo00<03gooOol047oo00<03gooOol047oo00<03gooOol0
3goo00<03gooOol047oo00<03gooOol047oo00<007ooOol04Woo000COol00`00Oomoo`0@Ool00`0?
Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`00
Oomoo`0BOol001=oo`80015oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`0300mo
ogoo011oo`0300moogoo00moo`8001Aoo`004goo00<007ooOol047oo00<03gooOol047oo00<03goo
Ool047oo00<03gooOol03goo00<03gooOol047oo00<03gooOol047oo00<007ooOol04Woo000COol2
000AOol00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?Oomo
o`0?Ool2000DOol000eoo`<000=oo`03001oogoo011oo`0300moogoo011oo`0300moogoo011oo`03
00moogoo00moo`0300moogoo011oo`0300moogoo011oo`03001oogoo019oo`003Woo00<007ooOol0
0Woo00<007ooOol047oo00<03gooOol047oo00<03gooOol047oo00<03gooOol03goo00<03gooOol0
47oo00<03gooOol047oo00<007ooOol04Woo000>Ool00`00Oomoo`02Ool2001^00l2000DOol000io
o`03001oogoo009oo`03001oogoo011oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00mo
o`0300moogoo011oo`0300moogoo011oo`03001oogoo019oo`003Woo00<007ooOol00Woo00<007oo
Ool047oo00<03gooOol047oo00<03gooOol047oo00<03gooOol03goo00<03gooOol047oo00<03goo
Ool047oo00<007ooOol04Woo000=Ool20004Ool2000AOol00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool0
0`0?Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool2000DOol000ioo`03001oogoo009oo`03
001oogoo011oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`0300moogoo011oo`03
00moogoo011oo`03001oogoo019oo`004goo00<007ooOol047oo00<03gooOol047oo00<03gooOol0
47oo00<03gooOol03goo00<03gooOol047oo00<03gooOol047oo00<007ooOol04Woo000COol2000A
Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?
Ool2000DOol001=oo`03001oogoo011oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00mo
o`0300moogoo011oo`0300moogoo011oo`03001oogoo019oo`004goo00<007ooOol047oo00<03goo
Ool047oo00<03gooOol047oo00<03gooOol03goo00<03gooOol047oo00<03gooOol047oo00<007oo
Ool04Woo000COol2000AOol00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomo
o`0@Ool00`0?Oomoo`0?Ool2000DOol001=oo`03001oogoo011oo`0300moogoo011oo`0300moogoo
011oo`0300moogoo00moo`0300moogoo011oo`0300moogoo011oo`03001oogoo019oo`004goo0P00
4Goo00<03gooOol047oo00<03gooOol047oo00<03gooOol03goo00<03gooOol047oo00<03gooOol0
3goo0P0057oo000<Ool50002Ool00`00Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?
Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`00Oomoo`0BOol000eoo`04001oogoo0002
Ool00`00Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@
Ool00`0?Oomoo`0@Ool00`00Oomoo`0BOol000ioo`03001oogoo009oo`8006h03`8001Aoo`003goo
00D007ooOomoo`00019oo`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`0300moogoo
011oo`0300moogoo011oo`03001oogoo019oo`0037oo00D007ooOomoo`00009oo`03001oogoo011o
o`0300moogoo011oo`0300moogoo011oo`0300moogoo00moo`0300moogoo011oo`0300moogoo011o
o`03001oogoo019oo`0037oo00D007ooOomoo`00009oo`80015oo`0300moogoo011oo`0300moogoo
011oo`0300moogoo00moo`0300moogoo011oo`0300moogoo00moo`8001Aoo`003Goo0`000goo00<0
07ooOol047oo00<03gooOol047oo00<03gooOol047oo00<03gooOol03goo00<03gooOol047oo00<0
3gooOol047oo00<007ooOol04Woo000COol00`00Oomoo`0@Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@
Ool00`0?Oomoo`0?Ool00`0?Oomoo`0@Ool00`0?Oomoo`0@Ool00`00Oomoo`0BOol001=oo`80015o
o`03001oogoo011oo`03001oogoo011oo`03001oogoo00moo`03001oogoo011oo`03001oogoo00mo
o`8001Aoo`004gooLP0057oo002IOol009Uoo`00?goo0`00Bgoo0`002Goo0012Ool00`00Oomoo`1;
Ool00`00Oomoo`06Ool0009oo`<00004Ool00000Ool30002Ool300000goo00000006Ool40003Ool3
0002Ool900000goo00000002Ool200000goo00000002000017oo000007oo10001goo1@000goo0P00
00=oo`00Ool00`000Woo0`002Goo0`000Woo00<007oo00000`0000Eoo`00000007oo00800003Ool0
000000800003Ool00000008000=oo`@0009oo`@000=oo`03001oogoo009oo`0000@007ooOol0009o
o`03001oo`0000Ioo`04001oogoo0008Ool01P00Oomoo`00Ool000Ioo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol0009oo`06001oogoo001oo`000goo00<007ooOol01goo00<007ooOol0
0Woo00H007ooOol007oo0006Ool00`00Oomoo`09Ool01P00Oomoo`00Ool0009oo`05001oogooOol0
0002Ool00`00Ool00002Ool01@00Oomoogoo00000Woo00<007oo00000Woo00@007ooOol000=oo`03
001oogoo00Ioo`0000@007ooOol0009oo`03001oo`0000@0009oo`04001oogoo0008Ool01@00Oomo
o`00Ool01@000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00H007ooOol0
07oo0003Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01@00Oomoo`00Ool01@000Woo00<007ooOol0
2Goo00<007oo00000goo0`000goo00H007ooOol007oo0002Ool01@00Oomoogoo00000Woo00<007oo
00000Woo00@007ooOol000=oo`03001oogoo00Ioo`0000@007ooOol0009oo`03001oo`0000=oo`04
001oogoo0002Ool00`00Oomoo`06Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Ool00003Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool01P00Oomoo`00Ool000=oo`03001oogoo008000Yoo`<0009oo`04001oogoo0003Ool0
1P00Oomoo`00Ool0009oo`05001oogooOol00002Ool00`00Ool00002Ool01000Oomoo`000goo00<0
07ooOol01Woo0002Ool40003Ool30002Ool40009Ool01000Oomoo`000Woo0`000goo0`000Woo1000
0Woo0P0000Aoo`00001oo`@000=oo`D000Moo`@00004Ool00000Ool20002Ool30002Ool200000goo
00000008Ool01000Oomoo`000Woo0P000goo10000goo0`000goo0`000goo0`000goo1@001goo000K
Ool01000Oomoo`0027oo00<007ooOol08Woo00<007ooOol06Woo00@007ooOol0011oo`05001oogoo
Ool00007Ool00`00Oomoo`0=Ool001Yoo`@000Qoo`8002Eoo`8001Uoo`@0011oo`80009oo`8000Io
o`8000moo`00VGoo002IOol00001\
\>"],
  ImageRangeCache->{{{0, 152}, {93.5, 0}} -> {-2.08896, -3.24695, 0.106434, \
0.0717554}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
EFplot = Table[0,{npi}]; 
Do [EFplot[[i]] = Plot[Wi[[i]],{x,0,len}];
,{i,1,npi}];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0793651 0.0147151 0.24149 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13546 -18 -4.5 ]
[.01131 .13546 0 4.5 ]
[.01131 .25621 -6 -4.5 ]
[.01131 .25621 0 4.5 ]
[.01131 .37695 -18 -4.5 ]
[.01131 .37695 0 4.5 ]
[.01131 .4977 -6 -4.5 ]
[.01131 .4977 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(2)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(4)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(6)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(8)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(10)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(12)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.06349 .01472 m
.06349 .01847 L
s
.10317 .01472 m
.10317 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.22222 .01472 m
.22222 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30159 .01472 m
.30159 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.42063 .01472 m
.42063 .01847 L
s
.46032 .01472 m
.46032 .01847 L
s
.53968 .01472 m
.53968 .01847 L
s
.57937 .01472 m
.57937 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.69841 .01472 m
.69841 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.77778 .01472 m
.77778 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.89683 .01472 m
.89683 .01847 L
s
.93651 .01472 m
.93651 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13546 m
.03006 .13546 L
s
[(0.5)] .01131 .13546 1 0 Mshowa
.02381 .25621 m
.03006 .25621 L
s
[(1)] .01131 .25621 1 0 Mshowa
.02381 .37695 m
.03006 .37695 L
s
[(1.5)] .01131 .37695 1 0 Mshowa
.02381 .4977 m
.03006 .4977 L
s
[(2)] .01131 .4977 1 0 Mshowa
.125 Mabswid
.02381 .03886 m
.02756 .03886 L
s
.02381 .06301 m
.02756 .06301 L
s
.02381 .08716 m
.02756 .08716 L
s
.02381 .11131 m
.02756 .11131 L
s
.02381 .15961 m
.02756 .15961 L
s
.02381 .18376 m
.02756 .18376 L
s
.02381 .20791 m
.02756 .20791 L
s
.02381 .23206 m
.02756 .23206 L
s
.02381 .28035 m
.02756 .28035 L
s
.02381 .3045 m
.02756 .3045 L
s
.02381 .32865 m
.02756 .32865 L
s
.02381 .3528 m
.02756 .3528 L
s
.02381 .4011 m
.02756 .4011 L
s
.02381 .42525 m
.02756 .42525 L
s
.02381 .4494 m
.02756 .4494 L
s
.02381 .47355 m
.02756 .47355 L
s
.02381 .52184 m
.02756 .52184 L
s
.02381 .54599 m
.02756 .54599 L
s
.02381 .57014 m
.02756 .57014 L
s
.02381 .59429 m
.02756 .59429 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .0522 L
.10458 .0929 L
.14415 .13078 L
.18221 .16675 L
.22272 .20437 L
.26171 .23979 L
.30316 .27641 L
.34309 .31054 L
.3815 .34217 L
.42237 .37437 L
.46172 .40383 L
.49955 .43061 L
.53984 .45735 L
.57861 .48124 L
.61984 .50455 L
.65954 .52486 L
.69774 .54233 L
.73838 .55862 L
.77751 .572 L
.81909 .58367 L
.85916 .59239 L
.87754 .59554 L
.89771 .59839 L
.91765 .60058 L
.92854 .6015 L
.93871 .60219 L
.94354 .60247 L
.94878 .60272 L
.95341 .6029 L
.95832 .60306 L
.96273 .60317 L
.96524 .60322 L
.9676 .60326 L
.96976 .60329 L
.97173 .6033 L
.97277 .60331 L
.97391 .60331 L
.97509 .60332 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{75.875, 46.8125},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001;0000;Q000`40O003h00OBgoo001;Ool004]o
o`0067oo1@001Goo0`0017oo0`001Woo0`000Woo0`0017oo10000Woo1@000Woo000IOol01000Oomo
o`001Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00002Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00@007ooOol0009oo`006Woo00<007ooOol00goo1@000goo00D007ooOomo
o`0000Aoo`05001oogooOol00002Ool00`00Oomoo`02Ool01000Oomoo`001Goo00<007ooOol00Woo
000KOol00`00Oomoo`02Ool01000Oomoo`0017oo10001Woo0`000goo00<007ooOol00Woo00@007oo
Ool000Ioo`03001oogoo005oo`0067oo00D007ooOomoo`0000Aoo`03001oo`0000Aoo`03001oogoo
00Ioo`05001oogooOol00002Ool00`00Oomoo`02Ool01000Oomoo`000goo00D007ooOomoo`00009o
o`0067oo00D007ooOomoo`0000Eoo`8000Eoo`03001oogoo00Eoo`06001oogooOol007oo0P0017oo
00@007oo000000=oo`05001oogooOol00002Ool001Uoo`<000Moo`03001oogoo00Aoo`8000Ioo`<0
00=oo`03001oogoo00=oo`<000Aoo`<000=oo`00Bgoo000BOol00`00Oomoo`0fOol0015oocH000Ao
o`004Woo00<007oo0000=Woo000BOol00`00Ool0000fOol0009oo`8000Aoo`03001oogoo009oo`<0
009oo`04001oogoo000eOol00005Ool007ooOol00007Ool01`00Oomoogoo001oo`0000=oo`8003=o
o`0000Eoo`00Oomoo`0000]oo`03001oo`0000Eoo`03001oogoo031oo`0000Eoo`00Oomoo`0000]o
o`03001oo`0000Ioo`03001oogoo02moo`0000Eoo`00Oomoo`0000Moo`@0009oo`03001oogoo00Eo
o`03001oogoo02ioo`0000Eoo`00Oomoo`0000Moo`03001oogoo00=oo`03001oogoo00Ioo`03001o
ogoo02eoo`000Woo0P0027oo1@0000=oo`00Ool027oo00<007ooOol0;7oo000=Ool30002Ool00`00
Oomoo`08Ool2000/Ool000ioo`05001oogooOol0000<Ool00`00Oomoo`0YOol000ioo`05001oogoo
Ool0000=Ool00`00Oomoo`0XOol000ioo`05001oogooOol0000>Ool00`00Oomoo`0WOol000ioo`05
001oogooOol0000?Ool00`00Oomoo`0VOol000eoo`8000=oo`03001oogoo00ioo`03001oogoo02Eo
o`0000Aoo`00000000Aoo`03001oogoo009oo`<0009oo`03001oogoo00moo`03001oogoo02Aoo`00
0Woo00<007ooOol01goo00L007ooOomoo`00Ool0000BOol2000TOol0009oo`03001oogoo00]oo`03
001oo`0001Aoo`03001oogoo025oo`000Woo00<007ooOol02goo00<007oo00005Goo00<007ooOol0
87oo0002Ool00`00Oomoo`07Ool40002Ool00`00Oomoo`0DOol2000POol00003Ool0000000Uoo`03
001oogoo00=oo`03001oogoo01Ioo`03001oogoo01eoo`000Woo00<007ooOol01goo1@0000=oo`00
Ool067oo00<007ooOol077oo000=Ool01P00Oomoo`00Ool001Yoo`8001aoo`003Woo00D007ooOomo
o`0001aoo`<001Uoo`003goo00@007ooOol001moo`8001Moo`0037oo00L007ooOomoo`00Ool0000Q
Ool2000EOol000aoo`07001oogooOol007oo00008goo0P004goo000=Ool30002Ool00`00Oomoo`0S
Ool2000AOol0019oo`03001oogoo02Eoo`8000moo`004Woo00<007ooOol09goo1`0027oo000BOol0
0`00Oomoo`0^Ool20006Ool004]oo`00Bgoo0000\
\>"],
  ImageRangeCache->{{{0, 74.875}, {45.8125, 0}} -> {-4.45902, -0.929123, \
0.23897, 0.078537}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0793651 0.309017 0.120745 [
[.18254 .29652 -3 -9 ]
[.18254 .29652 3 0 ]
[.34127 .29652 -3 -9 ]
[.34127 .29652 3 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -6 -9 ]
[.81746 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 .06753 -12 -4.5 ]
[.01131 .06753 0 4.5 ]
[.01131 .18827 -12 -4.5 ]
[.01131 .18827 0 4.5 ]
[.01131 .42976 -6 -4.5 ]
[.01131 .42976 0 4.5 ]
[.01131 .55051 -6 -4.5 ]
[.01131 .55051 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .30902 m
.18254 .31527 L
s
[(2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(4)] .34127 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(6)] .5 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(8)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(10)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(12)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.06349 .30902 m
.06349 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.57937 .30902 m
.57937 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.77778 .30902 m
.77778 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .06753 m
.03006 .06753 L
s
[(-2)] .01131 .06753 1 0 Mshowa
.02381 .18827 m
.03006 .18827 L
s
[(-1)] .01131 .18827 1 0 Mshowa
.02381 .42976 m
.03006 .42976 L
s
[(1)] .01131 .42976 1 0 Mshowa
.02381 .55051 m
.03006 .55051 L
s
[(2)] .01131 .55051 1 0 Mshowa
.125 Mabswid
.02381 .09168 m
.02756 .09168 L
s
.02381 .11582 m
.02756 .11582 L
s
.02381 .13997 m
.02756 .13997 L
s
.02381 .16412 m
.02756 .16412 L
s
.02381 .21242 m
.02756 .21242 L
s
.02381 .23657 m
.02756 .23657 L
s
.02381 .26072 m
.02756 .26072 L
s
.02381 .28487 m
.02756 .28487 L
s
.02381 .33317 m
.02756 .33317 L
s
.02381 .35731 m
.02756 .35731 L
s
.02381 .38146 m
.02756 .38146 L
s
.02381 .40561 m
.02756 .40561 L
s
.02381 .45391 m
.02756 .45391 L
s
.02381 .47806 m
.02756 .47806 L
s
.02381 .50221 m
.02756 .50221 L
s
.02381 .52636 m
.02756 .52636 L
s
.02381 .04338 m
.02756 .04338 L
s
.02381 .01923 m
.02756 .01923 L
s
.02381 .57466 m
.02756 .57466 L
s
.02381 .59881 m
.02756 .59881 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .2531 L
.10458 .1945 L
.14415 .14395 L
.18221 .10126 L
.22272 .06391 L
.26171 .03723 L
.28302 .02686 L
.29279 .02314 L
.30316 .01993 L
.31266 .01766 L
.31807 .01665 L
.32313 .0159 L
.32777 .01537 L
.33201 .01502 L
.33436 .01489 L
.33568 .01483 L
.33691 .01478 L
.33809 .01475 L
.33917 .01473 L
.3404 .01472 L
.34157 .01472 L
.34273 .01472 L
.34398 .01474 L
.34515 .01477 L
.34622 .0148 L
.34885 .01492 L
.35133 .01508 L
.35627 .01553 L
.36165 .01621 L
.37124 .01795 L
.38012 .02014 L
.39878 .02655 L
.41939 .03643 L
.45959 .06373 L
.49828 .09915 L
.53942 .14519 L
.57904 .19596 L
.61715 .24889 L
.65771 .30753 L
.69676 .36406 L
.73825 .42185 L
.77824 .47308 L
.8167 .51634 L
.85762 .55411 L
.87798 .56925 L
.89702 .58103 L
.91529 .59006 L
.93491 .5972 L
.94504 .59983 L
Mistroke
.95039 .60092 L
.95609 .60186 L
.95891 .60224 L
.96156 .60255 L
.96414 .6028 L
.96652 .60298 L
.96878 .60312 L
.97117 .60323 L
.9724 .60327 L
.97356 .60329 L
.97483 .60331 L
.97554 .60332 L
.97619 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{77.875, 48.0625},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001=0000<1000`40O003h00OCGoo001=Ool004eo
o`00CGoo001=Ool000aoo`03001oogoo03ioo`0037oo00<007ooOol03Woo1P00:Woo0006Ool50000
0goo001oo`0<Ool40005Ool3000WOol000Moo`06001oogoo001oo`0037oo00<007ooOol02Woo00<0
07ooOol097oo00050003Ool01000Oomoogoo0P002Woo00<007ooOol037oo00<007ooOol08goo0009
Ool01000Oomoo`002Woo00<007ooOol03Woo00<007ooOol08Woo0006Ool01`00Oomoogoo001oo`00
00Uoo`03001oogoo011oo`03001oogoo025oo`001Woo00L007ooOomoo`00Ool00009Ool00`00Oomo
o`0AOol00`00Oomoo`0POol000Moo`<0009oo`03001oogoo00Ioo`03001oogoo01=oo`03001oogoo
01moo`001goo0`000Woo00<007ooOol01Goo00<007ooOol05Goo00<007ooOol07Woo0008Ool01@00
Oomoogoo00001Woo1@001goo0`001Goo0`000Woo00<007ooOol00Woo0`0017oo0`0017oo1@000Woo
1@000Woo00050003Ool01@00Oomoogoo00001Goo00<007oo00000Woo00<007ooOol01Woo00<007oo
Ool00goo00D007ooOomoo`00009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`020004Ool01000Oomoo`000Woo0008Ool01000Oomoogoo0P000goo00D007ooOomoo`00
00Moo`D000Aoo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`020005Ool00`00Oomoo`02Ool000Qoo`05001oogooOol00004Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool01000Oomoo`001Goo100017oo00<007ooOol00`001Goo00<007ooOol00Woo
00<007ooOol00P001Woo00<007ooOol00Goo0007Ool20003Ool01@00Oomoogoo00000Woo00D007oo
Oomoo`0000Ioo`03001oo`0000Eoo`03001oogoo00Ioo`8000=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo008000=oo`05001oogooOol00002Ool000Qoo`05001oogooOol00003Ool01000
Oomoo`000goo00<007ooOol01Goo0P001Woo00<007ooOol01Woo00D007ooOomoo`0000=oo`8000Ao
o`03001oogoo008000=oo`05001oogooOol00002Ool000aoo`04001oogoo0004Ool30009Ool00`00
Oomoo`05Ool20006Ool40005Ool00`00Oomoo`03Ool200000goo001oo`03Ool30003Ool000aoo`03
001oo`00029oo`03001oogoo01Uoo`0037oo0P0097oo00<007ooOol067oo000;Ooln0004Ool000ao
o`03001oogoo02Aoo`03001oogoo01Moo`0037oo00<007ooOol09Goo00<007ooOol05Woo000<Ool0
0`00Oomoo`0VOol00`00Oomoo`0EOol000aoo`03001oogoo02Ioo`03001oogoo01Eoo`001goo0`00
0Woo00<007ooOol09goo00<007ooOol057oo0008Ool01@00Oomoogoo0000:Woo00<007ooOol04goo
0008Ool01000Oomoogoo0P00:Woo00<007ooOol04Woo0008Ool01@00Oomoogoo0000:goo00<007oo
Ool04Woo0008Ool01@00Oomoogoo0000;7oo00<007ooOol04Goo0007Ool20003Ool00`00Oomoo`0[
Ool00`00Oomoo`0@Ool000Qoo`05001oogooOol0000^Ool00`00Oomoo`0?Ool000Ioo`D00003Ool0
07oo02ioo`03001oogoo00ioo`001goo00H007ooOol007oo000`Ool00`00Oomoo`0=Ool000Qoo`05
001oogooOol0000aOol00`00Oomoo`0<Ool000Uoo`03001oogoo0080035oo`03001oogoo00]oo`00
1Woo00L007ooOomoo`00Ool0000cOol2000;Ool000Ioo`07001oogooOol007oo0000=Goo0P002Goo
0007Ool30002Ool00`00Oomoo`0eOol40005Ool000aoo`03001oogoo03ioo`00CGoo001=Ool004eo
o`00CGoo0000\
\>"],
  ImageRangeCache->{{{0, 76.875}, {47.0625, 0}} -> {-2.63554, -3.19388, \
0.206499, 0.135731}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0793651 0.309018 0.120745 [
[.18254 .29652 -3 -9 ]
[.18254 .29652 3 0 ]
[.34127 .29652 -3 -9 ]
[.34127 .29652 3 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -6 -9 ]
[.81746 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 .06753 -12 -4.5 ]
[.01131 .06753 0 4.5 ]
[.01131 .18827 -12 -4.5 ]
[.01131 .18827 0 4.5 ]
[.01131 .42976 -6 -4.5 ]
[.01131 .42976 0 4.5 ]
[.01131 .55051 -6 -4.5 ]
[.01131 .55051 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .30902 m
.18254 .31527 L
s
[(2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(4)] .34127 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(6)] .5 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(8)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(10)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(12)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.06349 .30902 m
.06349 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.57937 .30902 m
.57937 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.77778 .30902 m
.77778 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .06753 m
.03006 .06753 L
s
[(-2)] .01131 .06753 1 0 Mshowa
.02381 .18827 m
.03006 .18827 L
s
[(-1)] .01131 .18827 1 0 Mshowa
.02381 .42976 m
.03006 .42976 L
s
[(1)] .01131 .42976 1 0 Mshowa
.02381 .55051 m
.03006 .55051 L
s
[(2)] .01131 .55051 1 0 Mshowa
.125 Mabswid
.02381 .09168 m
.02756 .09168 L
s
.02381 .11583 m
.02756 .11583 L
s
.02381 .13997 m
.02756 .13997 L
s
.02381 .16412 m
.02756 .16412 L
s
.02381 .21242 m
.02756 .21242 L
s
.02381 .23657 m
.02756 .23657 L
s
.02381 .26072 m
.02756 .26072 L
s
.02381 .28487 m
.02756 .28487 L
s
.02381 .33317 m
.02756 .33317 L
s
.02381 .35732 m
.02756 .35732 L
s
.02381 .38146 m
.02756 .38146 L
s
.02381 .40561 m
.02756 .40561 L
s
.02381 .45391 m
.02756 .45391 L
s
.02381 .47806 m
.02756 .47806 L
s
.02381 .50221 m
.02756 .50221 L
s
.02381 .52636 m
.02756 .52636 L
s
.02381 .04338 m
.02756 .04338 L
s
.02381 .01923 m
.02756 .01923 L
s
.02381 .57466 m
.02756 .57466 L
s
.02381 .59881 m
.02756 .59881 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .21683 L
.10458 .12716 L
.12507 .09085 L
.14415 .06258 L
.16254 .04111 L
.17284 .03174 L
.18221 .02495 L
.18704 .02211 L
.19216 .0196 L
.19659 .01784 L
.20135 .01639 L
.20402 .01577 L
.20646 .01533 L
.20763 .01516 L
.20891 .015 L
.21012 .01489 L
.21124 .01481 L
.21193 .01477 L
.21267 .01474 L
.21337 .01472 L
.21401 .01472 L
.21523 .01472 L
.21652 .01476 L
.21719 .0148 L
.2179 .01485 L
.2192 .01496 L
.22074 .01513 L
.22214 .01533 L
.22442 .01574 L
.22694 .01632 L
.23205 .01787 L
.23678 .01977 L
.24122 .02195 L
.25121 .02826 L
.26198 .03719 L
.28202 .05945 L
.30312 .09022 L
.34123 .16179 L
.38179 .2536 L
.42084 .34792 L
.46234 .44356 L
.50232 .52106 L
.52063 .54936 L
.54078 .57414 L
.55037 .5834 L
.56066 .59144 L
.56634 .595 L
.57153 .59771 L
.57646 .5998 L
Mistroke
.57916 .60074 L
.5817 .60149 L
.58419 .6021 L
.58688 .60262 L
.58807 .60281 L
.58933 .60297 L
.5905 .6031 L
.59157 .60319 L
.59266 .60325 L
.59383 .6033 L
.59492 .60332 L
.59594 .60332 L
.59713 .60328 L
.59823 .60323 L
.59944 .60314 L
.60073 .60302 L
.60318 .60269 L
.60582 .6022 L
.61059 .60096 L
.61627 .59891 L
.62146 .59646 L
.63129 .59041 L
.64043 .58312 L
.66114 .56092 L
.68164 .53172 L
.70024 .49971 L
.74027 .41675 L
.77879 .32581 L
.81976 .22747 L
.85922 .14135 L
.89716 .07505 L
.91664 .04949 L
.92665 .03894 L
.93755 .02953 L
.94785 .02272 L
.95238 .02037 L
.95738 .01825 L
.96208 .0167 L
.9665 .01565 L
.96893 .01524 L
.97116 .01497 L
.97233 .01486 L
.97361 .01478 L
.97426 .01475 L
.97495 .01473 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{79.875, 49.3125},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001?0000<A000`40O003h00OCgoo001?Ool004mo
o`00Cgoo001?Ool000aoo`03001oogoo041oo`0037oo0P0027oo1@00;7oo0`001Goo0006Ool50000
0goo001oo`07Ool20004Ool00`00Oomoo`0WOol20008Ool000Moo`05001oogoo001oo`020007Ool0
0`00Oomoo`04Ool00`00Oomoo`0VOol00`00Oomoo`07Ool000D000=oo`04001oogooOol20006Ool0
0`00Oomoo`06Ool00`00Oomoo`0TOol00`00Oomoo`08Ool000Uoo`04001oogoo0007Ool00`00Oomo
o`06Ool00`00Oomoo`0SOol00`00Oomoo`09Ool000Ioo`06001oogooOol007oo0P001Goo00<007oo
Ool027oo00<007ooOol08Woo00<007ooOol02Goo0006Ool01P00Oomoogoo001oo`8000Aoo`03001o
ogoo00Uoo`03001oogoo025oo`03001oogoo00Yoo`001goo0`000Woo00<007ooOol00Woo00<007oo
Ool02goo00<007ooOol087oo00<007ooOol02Woo0007Ool30002Ool20003Ool00`00Oomoo`0;Ool0
0`00Oomoo`0OOol00`00Oomoo`0;Ool000Qoo`04001oogooOol20002Ool00`00Oomoo`0=Ool00`00
Oomoo`0NOol00`00Oomoo`0;Ool000D000=oo`05001oogooOol00003Ool00`00Oomoo`050007Ool3
0006Ool30007Ool30004Ool30004Ool2000017oo000000000Woo1@000Woo0008Ool01000Oomoogoo
0P000Woo00D007ooOomoo`00009oo`03001oogoo00Ioo`8000Eoo`05001oogooOol00005Ool01@00
Oomoogoo000017oo00<007ooOol00Woo0P0000Aoo`00Ool000Aoo`04001oogoo0002Ool000Qoo`04
001oogooOol200000goo001oo`04Ool00`00Oomoo`05Ool50005Ool01@00Oomoogoo00001Goo00D0
07ooOomoo`0000Aoo`03001oogoo009oo`800004Ool007oo0005Ool00`00Oomoo`02Ool000Moo`80
00=oo`04001oogoo0006Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000Aoo`@000Moo`<000Eoo`03
001oogoo009oo`06001oogoo001oo`001Woo00<007ooOol00Goo0008Ool01000Oomoogoo0P0000=o
o`00Ool00Woo00D007ooOomoo`0000Ioo`05001oo`00Ool00004Ool00`00Oomoo`07Ool01@00Oomo
ogoo000017oo00<007ooOol00Woo00H007ooOol007oo0003Ool01@00Oomoogoo00000Woo000<Ool3
0004Ool01@00Oomoogoo00001goo0P000Woo00<007ooOol00Woo00<007ooOol01Woo00D007ooOomo
o`0000=oo`8000=oo`80009oo`<000=oo`05001oogooOol00002Ool000aoo`8000Ioo`<000Uoo`04
001oogoo0005Ool20007Ool30005Ool01P00Oomoogoo001oo`80009oo`03001oogoo009oo`<000=o
o`0037oo0P005Woo00<007ooOol05Woo00<007ooOol03goo000;Oom00004Ool000aoo`06001oogoo
001oo`000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo0`000Woo00<007oo0000
0Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo0000
0Woo00<007oo00001Woo000<Ool2000GOol00`00Oomoo`0DOol00`00Oomoo`0@Ool000aoo`8001Mo
o`03001oogoo01=oo`03001oogoo015oo`0037oo00<007ooOol05Woo00<007ooOol04goo00<007oo
Ool04Goo0007Ool30002Ool2000HOol00`00Oomoo`0AOol00`00Oomoo`0BOol000Qoo`04001oogoo
Ool2000HOol00`00Oomoo`0AOol00`00Oomoo`0BOol000Qoo`05001oogooOol0000JOol00`00Oomo
o`0?Ool00`00Oomoo`0COol000Qoo`04001oogooOol2000IOol00`00Oomoo`0?Ool00`00Oomoo`0C
Ool000Qoo`04001oogooOol2000JOol00`00Oomoo`0=Ool00`00Oomoo`0DOol000Moo`8000=oo`03
001oogoo01Uoo`03001oogoo00eoo`03001oogoo01Aoo`0027oo00@007ooOomoo`8001]oo`03001o
ogoo00aoo`03001oogoo01Aoo`0037oo00<007ooOol06Woo00<007ooOol02goo00<007ooOol05Goo
0006Ool500000goo0000000KOol00`00Oomoo`0;Ool00`00Oomoo`0EOol000Moo`05001oogoo001o
o`02000LOol00`00Oomoo`09Ool00`00Oomoo`0FOol000Qoo`05001oogooOol0000NOol00`00Oomo
o`08Ool00`00Oomoo`0FOol000Uoo`03001oogoo008001ioo`03001oogoo00Ioo`03001oogoo01Mo
o`001Woo00H007ooOomoo`00Ool2000OOol00`00Oomoo`04Ool00`00Oomoo`0HOol000Ioo`07001o
ogooOol007oo00008Goo0P000Woo0P006goo0007Ool30002Ool2000QOol4000LOol000aoo`03001o
ogoo041oo`00Cgoo001?Ool004moo`00Cgoo0000\
\>"],
  ImageRangeCache->{{{0, 78.875}, {48.3125, 0}} -> {-2.55413, -3.171, \
0.199714, 0.131271}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0793651 0.309015 0.120746 [
[.18254 .29651 -3 -9 ]
[.18254 .29651 3 0 ]
[.34127 .29651 -3 -9 ]
[.34127 .29651 3 0 ]
[.5 .29651 -3 -9 ]
[.5 .29651 3 0 ]
[.65873 .29651 -3 -9 ]
[.65873 .29651 3 0 ]
[.81746 .29651 -6 -9 ]
[.81746 .29651 6 0 ]
[.97619 .29651 -6 -9 ]
[.97619 .29651 6 0 ]
[.01131 .06752 -12 -4.5 ]
[.01131 .06752 0 4.5 ]
[.01131 .18827 -12 -4.5 ]
[.01131 .18827 0 4.5 ]
[.01131 .42976 -6 -4.5 ]
[.01131 .42976 0 4.5 ]
[.01131 .55051 -6 -4.5 ]
[.01131 .55051 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .30901 m
.18254 .31526 L
s
[(2)] .18254 .29651 0 1 Mshowa
.34127 .30901 m
.34127 .31526 L
s
[(4)] .34127 .29651 0 1 Mshowa
.5 .30901 m
.5 .31526 L
s
[(6)] .5 .29651 0 1 Mshowa
.65873 .30901 m
.65873 .31526 L
s
[(8)] .65873 .29651 0 1 Mshowa
.81746 .30901 m
.81746 .31526 L
s
[(10)] .81746 .29651 0 1 Mshowa
.97619 .30901 m
.97619 .31526 L
s
[(12)] .97619 .29651 0 1 Mshowa
.125 Mabswid
.06349 .30901 m
.06349 .31276 L
s
.10317 .30901 m
.10317 .31276 L
s
.14286 .30901 m
.14286 .31276 L
s
.22222 .30901 m
.22222 .31276 L
s
.2619 .30901 m
.2619 .31276 L
s
.30159 .30901 m
.30159 .31276 L
s
.38095 .30901 m
.38095 .31276 L
s
.42063 .30901 m
.42063 .31276 L
s
.46032 .30901 m
.46032 .31276 L
s
.53968 .30901 m
.53968 .31276 L
s
.57937 .30901 m
.57937 .31276 L
s
.61905 .30901 m
.61905 .31276 L
s
.69841 .30901 m
.69841 .31276 L
s
.7381 .30901 m
.7381 .31276 L
s
.77778 .30901 m
.77778 .31276 L
s
.85714 .30901 m
.85714 .31276 L
s
.89683 .30901 m
.89683 .31276 L
s
.93651 .30901 m
.93651 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
.02381 .06752 m
.03006 .06752 L
s
[(-2)] .01131 .06752 1 0 Mshowa
.02381 .18827 m
.03006 .18827 L
s
[(-1)] .01131 .18827 1 0 Mshowa
.02381 .42976 m
.03006 .42976 L
s
[(1)] .01131 .42976 1 0 Mshowa
.02381 .55051 m
.03006 .55051 L
s
[(2)] .01131 .55051 1 0 Mshowa
.125 Mabswid
.02381 .09167 m
.02756 .09167 L
s
.02381 .11582 m
.02756 .11582 L
s
.02381 .13997 m
.02756 .13997 L
s
.02381 .16412 m
.02756 .16412 L
s
.02381 .21242 m
.02756 .21242 L
s
.02381 .23657 m
.02756 .23657 L
s
.02381 .26072 m
.02756 .26072 L
s
.02381 .28487 m
.02756 .28487 L
s
.02381 .33316 m
.02756 .33316 L
s
.02381 .35731 m
.02756 .35731 L
s
.02381 .38146 m
.02756 .38146 L
s
.02381 .40561 m
.02756 .40561 L
s
.02381 .45391 m
.02756 .45391 L
s
.02381 .47806 m
.02756 .47806 L
s
.02381 .50221 m
.02756 .50221 L
s
.02381 .52636 m
.02756 .52636 L
s
.02381 .04337 m
.02756 .04337 L
s
.02381 .01922 m
.02756 .01922 L
s
.02381 .57466 m
.02756 .57466 L
s
.02381 .59881 m
.02756 .59881 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30901 m
.06244 .18205 L
.08255 .12437 L
.10458 .07265 L
.11448 .0542 L
.12507 .03814 L
.1302 .0318 L
.13506 .0267 L
.13975 .02261 L
.14415 .01954 L
.14877 .01712 L
.15121 .01618 L
.15385 .01542 L
.15516 .01514 L
.15586 .01503 L
.1566 .01492 L
.15731 .01484 L
.15796 .01478 L
.15921 .01472 L
.16043 .01472 L
.16174 .01478 L
.16298 .0149 L
.16413 .01507 L
.16519 .01527 L
.16634 .01553 L
.1684 .01614 L
.17085 .01708 L
.17309 .01814 L
.17796 .02111 L
.18257 .02476 L
.19222 .03501 L
.20248 .04961 L
.2209 .0848 L
.25865 .18624 L
.29885 .31897 L
.33754 .44505 L
.35718 .50026 L
.37868 .54934 L
.3886 .56719 L
.3992 .58251 L
.40435 .58848 L
.40921 .59321 L
.41391 .59694 L
.4183 .59966 L
.42072 .60084 L
.42293 .60172 L
.42538 .60247 L
.42674 .60278 L
.42802 .60301 L
.42926 .60317 L
Mistroke
.43058 .60328 L
.43182 .60332 L
.43295 .6033 L
.43364 .60326 L
.43428 .60321 L
.43497 .60314 L
.43571 .60304 L
.43695 .60283 L
.43831 .60253 L
.44073 .60182 L
.44293 .60097 L
.44786 .59838 L
.45244 .59514 L
.45677 .59134 L
.46645 .58031 L
.47672 .56492 L
.49515 .52844 L
.53295 .42497 L
.57321 .29143 L
.61195 .1661 L
.63163 .1118 L
.64204 .08704 L
.65314 .06416 L
.66392 .04578 L
.67371 .03262 L
.67843 .02753 L
.68354 .02295 L
.68837 .01954 L
.69281 .0172 L
.69527 .01623 L
.6975 .01556 L
.69874 .01527 L
.70009 .01502 L
.70136 .01486 L
.70253 .01476 L
.70361 .01472 L
.70463 .01472 L
.70574 .01476 L
.70694 .01487 L
.70812 .01503 L
.70938 .01526 L
.71162 .01582 L
.71408 .01667 L
.71672 .01784 L
.72148 .02063 L
.72713 .02507 L
.73227 .03016 L
.74224 .04281 L
.75143 .0576 L
.77222 .10118 L
Mistroke
.81159 .21377 L
.84945 .34059 L
.88975 .46854 L
.90831 .51746 L
.92855 .5599 L
.93952 .57733 L
.94486 .58427 L
.94969 .58966 L
.95437 .59403 L
.95942 .59782 L
.9622 .59949 L
.96476 .60076 L
.96721 .60174 L
.96979 .60252 L
.97139 .60287 L
.97227 .60302 L
.9731 .60313 L
.97388 .60321 L
.97472 .60328 L
.97548 .60331 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{77.875, 48.0625},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001=0000<1000`40O003h00OCGoo001=Ool004eo
o`00CGoo001=Ool000aoo`03001oogoo03ioo`0037oo00<007ooOol017oo10007Woo0`005Goo0006
Ool500000goo001oo`04Ool20002Ool2000LOol200000goo001oo`0DOol000Moo`06001oogoo001o
o`001Goo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol04Woo00050003
Ool01000Oomoogoo0P0017oo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol00goo00<007oo
Ool04Goo0009Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol05goo00<007ooOol017oo
00<007ooOol04Goo0006Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo00Aoo`03001oogoo01Mo
o`03001oogoo00Eoo`03001oogoo011oo`001Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`06
Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0@Ool000Moo`<0009oo`05001oogooOol0
0008Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0@Ool000Moo`<0009oo`05001oogoo
Ool00009Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`0?Ool000Qoo`05001oogooOol0
0002Ool01000Oomoogoo1@000Woo00<007ooOol00Woo0`001Goo0`001Woo100017oo10000goo1@00
0Woo1@000Woo00050003Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00@007ooOol000=oo`03
001oogoo009oo`03001oogoo00=oo`05001oogooOol00005Ool01@00Oomoogoo000017oo00<007oo
00000Woo00<007ooOol00P0017oo00@007ooOol0009oo`0027oo00@007ooOomoo`800003Ool007oo
00Aoo`03001oogoo00=oo`03001oo`0000@000Aoo`05001oogooOol00005Ool01@00Oomoogoo0000
17oo00H007ooOol007oo0002Ool20005Ool00`00Oomoo`02Ool000Qoo`07001oogooOol007oo0000
1goo00<007ooOol00Woo00<007oo00000Woo00<007ooOol00goo10001Goo00<007oo00000P001Goo
00H007ooOol007oo0002Ool20006Ool00`00Oomoo`01Ool000Moo`8000=oo`03001oo`0000Aoo`05
001oogooOol00004Ool01@00Ool007oo00001Goo00<007ooOol01Woo0P000goo00<007ooOol00Woo
00H007ooOol007oo0002Ool20003Ool01@00Oomoogoo00000Woo0008Ool01`00Oomoogoo001oo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`020006Ool00`00Oomoo`05Ool20003Ool01000Oomo
ogoo0P000goo0P000Woo0P000goo00D007ooOomoo`00009oo`0037oo0P001Woo0`001Goo00D007oo
Oomoo`0000Moo`8000Eoo`03001oo`00008000Eoo`06001oogooOol007oo0P0000=oo`00Ool00goo
0`000goo000<Ool2000>Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool000aoo`80
00ioo`03001oogoo00moo`03001oogoo00eoo`03001oogoo00aoo`002goo?P0017oo000<Ool00`00
Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool000aoo`03001oogoo00io
o`03001oogoo00eoo`03001oogoo00moo`03001oogoo00]oo`0037oo00<007ooOol03Woo00<007oo
Ool03Goo00<007ooOol03goo00<007ooOol02goo000<Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool0
0`00Oomoo`0@Ool00`00Oomoo`0;Ool000Moo`<0009oo`03001oogoo00moo`03001oogoo00]oo`03
001oogoo015oo`03001oogoo00Yoo`0027oo00D007ooOomoo`00015oo`03001oogoo00]oo`03001o
ogoo015oo`03001oogoo00Yoo`0027oo00@007ooOomoo`80015oo`03001oogoo00Uoo`03001oogoo
019oo`03001oogoo00Yoo`0027oo00D007ooOomoo`00019oo`03001oogoo00Uoo`03001oogoo019o
o`03001oogoo00Yoo`0027oo00D007ooOomoo`00019oo`03001oogoo00Qoo`03001oogoo01Aoo`03
001oogoo00Uoo`001goo0P000goo00<007ooOol04Goo00<007ooOol01goo00<007ooOol057oo00<0
07ooOol02Goo0008Ool01@00Oomoogoo00004goo00<007ooOol01goo00<007ooOol057oo00<007oo
Ool02Goo0006Ool500000goo001oo`0COol00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`08
Ool000Moo`06001oogoo001oo`0057oo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol027oo
0008Ool01@00Oomoogoo00005Goo00<007ooOol017oo00<007ooOol05Woo00<007ooOol027oo0009
Ool00`00Oomoo`02000DOol00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`07Ool000Ioo`07
001oogooOol007oo00005Woo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol01Woo0006Ool0
1`00Oomoogoo001oo`0001Ioo`800003Ool0000001aoo`8000Moo`001goo0`000Woo00<007ooOol0
5Goo0`007Woo0P001Woo000<Ool00`00Oomoo`0nOol004eoo`00CGoo001=Ool004eoo`00\
\>"],
  ImageRangeCache->{{{0, 76.875}, {47.0625, 0}} -> {-2.63554, -3.19388, \
0.206499, 0.135729}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Show[Rahmen,EFplot];  \t ", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-17 0.0833333 0.309017 0.123607 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0618 -12 -4.5 ]
[-0.0125 .0618 0 4.5 ]
[-0.0125 .18541 -12 -4.5 ]
[-0.0125 .18541 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .43262 -6 -4.5 ]
[-0.0125 .43262 0 4.5 ]
[-0.0125 .55623 -6 -4.5 ]
[-0.0125 .55623 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -147.312 0 ]
[.5 .63053 147.312 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .61803 L
s
.33333 0 m
.33333 .61803 L
s
.5 0 m
.5 .61803 L
s
.66667 0 m
.66667 .61803 L
s
.83333 0 m
.83333 .61803 L
s
0 .0618 m
1 .0618 L
s
0 .18541 m
1 .18541 L
s
0 .30902 m
1 .30902 L
s
0 .43262 m
1 .43262 L
s
0 .55623 m
1 .55623 L
s
0 g
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0618 m
.00625 .0618 L
s
[(-2)] -0.0125 .0618 1 0 Mshowa
0 .18541 m
.00625 .18541 L
s
[(-1)] -0.0125 .18541 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .43262 m
.00625 .43262 L
s
[(1)] -0.0125 .43262 1 0 Mshowa
0 .55623 m
.00625 .55623 L
s
[(2)] -0.0125 .55623 1 0 Mshowa
.125 Mabswid
0 .08652 m
.00375 .08652 L
s
0 .11125 m
.00375 .11125 L
s
0 .13597 m
.00375 .13597 L
s
0 .16069 m
.00375 .16069 L
s
0 .21013 m
.00375 .21013 L
s
0 .23485 m
.00375 .23485 L
s
0 .25957 m
.00375 .25957 L
s
0 .2843 m
.00375 .2843 L
s
0 .33374 m
.00375 .33374 L
s
0 .35846 m
.00375 .35846 L
s
0 .38318 m
.00375 .38318 L
s
0 .4079 m
.00375 .4079 L
s
0 .45735 m
.00375 .45735 L
s
0 .48207 m
.00375 .48207 L
s
0 .50679 m
.00375 .50679 L
s
0 .53151 m
.00375 .53151 L
s
0 .03708 m
.00375 .03708 L
s
0 .01236 m
.00375 .01236 L
s
0 .58095 m
.00375 .58095 L
s
0 .60567 m
.00375 .60567 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0618 m
1 .0618 L
s
.99375 .18541 m
1 .18541 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .43262 m
1 .43262 L
s
.99375 .55623 m
1 .55623 L
s
.125 Mabswid
.99625 .08652 m
1 .08652 L
s
.99625 .11125 m
1 .11125 L
s
.99625 .13597 m
1 .13597 L
s
.99625 .16069 m
1 .16069 L
s
.99625 .21013 m
1 .21013 L
s
.99625 .23485 m
1 .23485 L
s
.99625 .25957 m
1 .25957 L
s
.99625 .2843 m
1 .2843 L
s
.99625 .33374 m
1 .33374 L
s
.99625 .35846 m
1 .35846 L
s
.99625 .38318 m
1 .38318 L
s
.99625 .4079 m
1 .4079 L
s
.99625 .45735 m
1 .45735 L
s
.99625 .48207 m
1 .48207 L
s
.99625 .50679 m
1 .50679 L
s
.99625 .53151 m
1 .53151 L
s
.99625 .03708 m
1 .03708 L
s
.99625 .01236 m
1 .01236 L
s
.99625 .58095 m
1 .58095 L
s
.99625 .60567 m
1 .60567 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
gsave
.5 .63053 -208.312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigenfunktionen) show
159.000 13.000 moveto
(Dehnung) show
207.000 13.000 moveto
(fuer) show
237.000 13.000 moveto
(Randbdg) show
279.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
285.000 13.000 moveto
0.000 0.000 rmoveto
287.625 13.000 moveto
0.000 0.000 rmoveto
287.625 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(fest) show
317.625 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
329.625 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(frei) show
353.625 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .30902 L
.08481 .30902 L
.12636 .30902 L
.16632 .30902 L
.20885 .30902 L
.2498 .30902 L
.29331 .30902 L
.33524 .30902 L
.37557 .30902 L
.41848 .30902 L
.4598 .30902 L
.49953 .30902 L
.54183 .30902 L
.58254 .30902 L
.62583 .30902 L
.66752 .30902 L
.70762 .30902 L
.7503 .30902 L
.79139 .30902 L
.83505 .30902 L
.87712 .30902 L
.9176 .30902 L
.96065 .30902 L
1 .30902 L
s
0 .30902 m
.04057 .3282 L
.08481 .34903 L
.12636 .36842 L
.16632 .38683 L
.20885 .40609 L
.2498 .42422 L
.29331 .44297 L
.33524 .46044 L
.37557 .47662 L
.41848 .4931 L
.4598 .50818 L
.49953 .52189 L
.54183 .53558 L
.58254 .54781 L
.62583 .55974 L
.66752 .57013 L
.70762 .57908 L
.7503 .58742 L
.79139 .59426 L
.83505 .60024 L
.87712 .6047 L
.89642 .60631 L
.9176 .60777 L
.93853 .60889 L
.94997 .60936 L
.96065 .60972 L
.96571 .60986 L
.97122 .60999 L
.97608 .61008 L
.98123 .61016 L
.98587 .61022 L
.9885 .61024 L
.99098 .61026 L
.99325 .61028 L
.99532 .61029 L
.99641 .61029 L
.9976 .61029 L
.99884 .61029 L
1 .61029 L
s
0 .30902 m
.04057 .25177 L
.08481 .19179 L
.12636 .14004 L
.16632 .09633 L
.20885 .05811 L
.2498 .03078 L
.27217 .02017 L
.28243 .01637 L
.29331 .01308 L
.30329 .01075 L
.30897 .00972 L
.31429 .00895 L
.31916 .00841 L
.32361 .00806 L
.32607 .00792 L
.32747 .00786 L
.32876 .00781 L
.33 .00778 L
.33112 .00776 L
.33242 .00774 L
.33365 .00774 L
.33487 .00775 L
.33618 .00777 L
.33741 .0078 L
.33853 .00783 L
.34129 .00795 L
.3439 .00811 L
.34909 .00857 L
.35473 .00927 L
.3648 .01105 L
.37413 .01329 L
.39372 .01986 L
.41536 .02997 L
.45757 .05791 L
.49819 .09417 L
.54139 .14131 L
.58299 .19328 L
.62301 .24747 L
.6656 .3075 L
.70659 .36537 L
.75017 .42453 L
.79215 .47696 L
.83254 .52125 L
.8755 .55991 L
.89688 .57541 L
.91687 .58747 L
.93605 .59672 L
.95666 .60403 L
.96729 .60672 L
Mistroke
.97291 .60784 L
.97889 .6088 L
.98185 .60919 L
.98464 .6095 L
.98735 .60976 L
.98984 .60995 L
.99222 .61009 L
.99472 .6102 L
.99603 .61024 L
.99724 .61027 L
.99857 .61029 L
.99932 .61029 L
1 .61029 L
1 .61029 L
Mfstroke
0 .30902 m
.04057 .21464 L
.08481 .12285 L
.10632 .08567 L
.12636 .05674 L
.14567 .03476 L
.15648 .02517 L
.16632 .01822 L
.17139 .01531 L
.17677 .01274 L
.18142 .01094 L
.18642 .00945 L
.18922 .00882 L
.19178 .00837 L
.19302 .00819 L
.19436 .00804 L
.19563 .00792 L
.19681 .00783 L
.19752 .0078 L
.1983 .00777 L
.19904 .00775 L
.19971 .00774 L
.20099 .00775 L
.20234 .00779 L
.20305 .00783 L
.2038 .00787 L
.20516 .00799 L
.20677 .00817 L
.20824 .00837 L
.21064 .00879 L
.21329 .00938 L
.21865 .01097 L
.22362 .01291 L
.22828 .01514 L
.23877 .0216 L
.25008 .03075 L
.27112 .05354 L
.29328 .08504 L
.33329 .1583 L
.37588 .25229 L
.41688 .34884 L
.46045 .44675 L
.50243 .52608 L
.52167 .55505 L
.54282 .58042 L
.55288 .5899 L
.56369 .59813 L
.56966 .60178 L
.57511 .60455 L
.58028 .60669 L
Mistroke
.58312 .60765 L
.58579 .60842 L
.5884 .60905 L
.59123 .60958 L
.59248 .60977 L
.59379 .60994 L
.59503 .61006 L
.59615 .61016 L
.5973 .61023 L
.59852 .61027 L
.59966 .61029 L
.60074 .61029 L
.60199 .61026 L
.60315 .6102 L
.60441 .61011 L
.60576 .60999 L
.60834 .60965 L
.61111 .60915 L
.61612 .60788 L
.62208 .60578 L
.62754 .60328 L
.63786 .59707 L
.64745 .58962 L
.6692 .56689 L
.69072 .537 L
.71025 .50423 L
.75228 .4193 L
.79273 .32621 L
.83575 .22553 L
.87718 .13738 L
.91701 .0695 L
.93747 .04334 L
.94798 .03253 L
.95942 .02291 L
.97024 .01593 L
.975 .01353 L
.98025 .01136 L
.98519 .00978 L
.98982 .0087 L
.99238 .00828 L
.99472 .008 L
.99595 .00789 L
.99729 .00781 L
.99797 .00778 L
.99869 .00776 L
1 .00774 L
Mfstroke
0 .30902 m
.04057 .17904 L
.06168 .11999 L
.08481 .06705 L
.0952 .04816 L
.10632 .03173 L
.11171 .02523 L
.11681 .02001 L
.12174 .01582 L
.12636 .01268 L
.1312 .01021 L
.13377 .00924 L
.13654 .00847 L
.13792 .00818 L
.13865 .00806 L
.13943 .00795 L
.14018 .00787 L
.14085 .00781 L
.14218 .00775 L
.14345 .00775 L
.14483 .00781 L
.14613 .00794 L
.14733 .0081 L
.14845 .00831 L
.14965 .00858 L
.15182 .0092 L
.1544 .01016 L
.15675 .01125 L
.16186 .01429 L
.16669 .01803 L
.17683 .02852 L
.1876 .04347 L
.20694 .07949 L
.24658 .18334 L
.28879 .31921 L
.32941 .44827 L
.35004 .50479 L
.37261 .55504 L
.38303 .5733 L
.39416 .58899 L
.39957 .5951 L
.40467 .59995 L
.4096 .60376 L
.41422 .60655 L
.41676 .60775 L
.41908 .60865 L
.42165 .60942 L
.42307 .60974 L
.42442 .60998 L
.42572 .61015 L
Mistroke
.42711 .61025 L
.42841 .61029 L
.42959 .61028 L
.43032 .61024 L
.43099 .61019 L
.43172 .61011 L
.4325 .61001 L
.4338 .6098 L
.43523 .60949 L
.43776 .60876 L
.44007 .60789 L
.44526 .60524 L
.45006 .60192 L
.45461 .59803 L
.46477 .58674 L
.47555 .57098 L
.49491 .53364 L
.5346 .42772 L
.57687 .29101 L
.61754 .16271 L
.63821 .10713 L
.64914 .08179 L
.6608 .05836 L
.67212 .03955 L
.68239 .02608 L
.68735 .02086 L
.69272 .01617 L
.69779 .01268 L
.70246 .01029 L
.70503 .0093 L
.70738 .00861 L
.70868 .00831 L
.71009 .00806 L
.71143 .00789 L
.71266 .00779 L
.71379 .00774 L
.71486 .00775 L
.71602 .00779 L
.71728 .0079 L
.71853 .00807 L
.71985 .0083 L
.7222 .00888 L
.72479 .00975 L
.72756 .01094 L
.73255 .01379 L
.73849 .01834 L
.74388 .02355 L
.75435 .0365 L
.764 .05165 L
.78583 .09626 L
Mistroke
.82717 .21151 L
.86692 .34134 L
.90924 .47232 L
.92872 .5224 L
.94997 .56585 L
.96149 .58369 L
.9671 .59079 L
.97218 .59631 L
.97709 .60078 L
.98239 .60467 L
.98531 .60637 L
.988 .60768 L
.99057 .60868 L
.99328 .60947 L
.99496 .60983 L
.99588 .60999 L
.99676 .6101 L
.99757 .61019 L
.99845 .61025 L
.99926 .61028 L
1 .61029 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  AspectRatioFixed->False,
  ImageSize->{332.375, 205.438},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005<0000cA000`40O003h00OogooCGoo0010Ool5
000aOol3000_Ool3000aOol3000]Ool30004Ool2000[Ool30002Ool50002Ool0045oo`04001oogoo
000bOol00`00Oomoo`0]Ool01@00Oomoogoo0000;goo00D007ooOomoo`0002eoo`03001oogoo009o
o`04001oogoo000[Ool00`00Oomoo`02Ool01000Oomoo`000Woo0012Ool00`00Oomoo`0_Ool5000^
Ool01@00Oomoogoo0000;goo00D007ooOomoo`0002eoo`03001oogoo009oo`04001oogoo000[Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool004=oo`03001oogoo02ioo`04001oogoo000_Ool4000aOol3
000^Ool00`00Oomoo`02Ool01000Oomoo`00:goo00<007ooOol017oo00<007ooOol00Goo0010Ool0
1@00Oomoogoo0000<7oo00<007oo0000;goo00<007ooOol0<Goo00D007ooOomoo`0002eoo`03001o
ogoo009oo`04001oogoo000[Ool01@00Oomoogoo00000goo0@000Goo0Goo0010Ool01@00Oomoogoo
0000<Goo0P00<7oo00<007ooOol0<7oo00D007ooOomoo`0002aoo`8000Aoo`04001oogoo000ZOol2
0003Ool01@00Oomoogoo00000Woo0011Ool3000cOol00`00Oomoo`0_Ool2000aOol3000^Ool00`00
Oomoo`03Ool2000/Ool00`00Oomoo`02Ool30003Ool00?moodeoo`00ogooCGoo003oOom=Ool00?mo
odeoo`00ogooCGoo000?Oooo000h0006Ool000moo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Aoo`003goo00<007ooOol09goo1P0017oo00<03goo
Ool00goo2P006goo4P00:Woo00<03gooOol0<Goo00<03gooOol02Goo1`0087oo00<03gooOol0;7oo
1P001Woo000?Ool3000TOol30006Ool20002Ool00`0?Ool00003000:Ool3000COol50009Ool00`0?
Oomoo`06Ool6000TOol00`0?Oomoo`0aOol00`0?Oomoo`06Ool30007Ool00`00Oomoo`0MOol00`0?
Oomoo`0YOol30004Ool20006Ool000moo`03001oogoo02=oo`03001oogoo00Uoo`80000300l007oo
011oo`8000ioo`<000ioo`0300moogoo00aoo`<0025oo`0300moogoo035oo`0300moogoo00Eoo`03
001oogoo00Uoo`8001eoo`0300moogoo02Moo`8000Qoo`03001oogoo00Aoo`003goo00<007ooOol0
8Woo00<007ooOol02goo0P0057oo00<007ooOol027oo0`004Goo00<03gooOol03goo0P007goo00<0
3gooOol0<Goo00<03gooOol017oo00<007ooOol037oo0P006goo00<03gooOol09Goo0P002Woo00<0
07ooOol017oo000?Ool00`00Oomoo`0QOol00`00Oomoo`0;Ool01000Ool03`0057oo0P001Goo0`00
57oo00<03gooOol04Goo0`0077oo00<03gooOol0<Goo00<03gooOol00goo00<007ooOol03goo00<0
07ooOol067oo00<03gooOol097oo00<007ooOol02Woo00<007ooOol017oo000?Ool00`00Oomoo`0P
Ool00`00Oomoo`0:Ool20002Ool00`0?Ool0000EOol200000goo0000000GOol00`0?Oomoo`0DOol2
000JOol00`0?Oomoo`0aOol00`0?Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`0HOol00`0?Oomo
o`0SOol00`00Oomoo`0;Ool00`00Oomoo`04Ool000moo`03001oogoo01moo`03001oogoo00Yoo`03
001oogoo009oo`0400moogoo000EOol2000IOol00`0?Oomoo`0FOol2000HOol00`0?Oomoo`0aOol0
1@0?Oomoogoo000057oo00<007ooOol05goo00<03gooOol08Woo00<007ooOol037oo00<007ooOol0
17oo000?Ool00`00Oomoo`0NOol00`00Oomoo`0:Ool00`00Oomoo`03Ool0100?Oomoo`0057oo00<0
07oo00006Goo00<03gooOol067oo00<007ooOol05Goo00<03gooOol0<Goo00@03gooOol001Ioo`03
001oogoo01Ioo`0300moogoo025oo`03001oogoo00eoo`03001oogoo00Aoo`003goo0`007Woo00<0
07ooOol02Goo00<007ooOol017oo00D03gooOomoo`00015oo`8000=oo`03001oogoo01Ioo`0300mo
ogoo01Uoo`8001Eoo`0300moogoo035oo`0300moo`0001Qoo`03001oogoo01Eoo`0300moogoo021o
o`03001oogoo00eoo`8000Ioo`003goo00<007ooOol07Goo00<007ooOol02Goo00<007ooOol01Goo
00<03gooOol00Woo00<007ooOol037oo0P001Woo00<007ooOol05Goo00<03gooOol06goo0P004goo
00<03gooOol0<Goo00<03`00Ool067oo00<007ooOol05Goo00<03gooOol07goo00<007ooOol03goo
00<007ooOol017oo000?Ool00`00Oomoo`0LOol00`00Oomoo`09Ool00`00Oomoo`06Ool00`0?Oomo
o`03Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`0?Oomoo`0MOol00`00Oomo
o`0@Ool00`0?Oomoo`0aOol00`0?001oo`0IOol00`00Oomoo`0DOol00`0?Oomoo`0NOol00`00Oomo
o`0@Ool00`00Oomoo`04Ool000moo`03001oogoo01]oo`03001oogoo00Uoo`03001oogoo00Moo`03
00moogoo00=oo`03001oogoo00Qoo`8000]oo`03001oogoo01=oo`0300moogoo01ioo`80011oo`03
00moogoo035oo`03001oogoo01Yoo`03001oogoo01=oo`0300moogoo01eoo`03001oogoo015oo`03
001oogoo00Aoo`003goo00<007ooOol06goo00<007ooOol027oo00<007ooOol027oo00<03gooOol0
17oo00<007ooOol01Goo0P003Woo00<007ooOol04Woo00<03gooOol087oo0P003Woo00<03gooOol0
<7oo00<0000?Ool077oo00<007ooOol04Woo00<03gooOol077oo00<007ooOol04Woo00<007ooOol0
17oo0006Ool50004Ool00`00Oomoo`0JOol00`00Oomoo`08Ool00`00Oomoo`09Ool00`0?Oomoo`05
Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`0AOol00`0?Oomoo`0ROol00`00Oomoo`0;
Ool00`0?Oomoo`0`Ool00`0000moo`0LOol00`00Oomoo`0BOol00`0?Oomoo`0KOol00`00Oomoo`0C
Ool00`00Oomoo`04Ool000Moo`04001oogoo0004Ool00`00Oomoo`0JOol00`00Oomoo`07Ool00`00
Oomoo`0:Ool00`0?Oomoo`05Ool01000Oomoogoo0P004Woo00<007ooOol04Goo00<03gooOol08goo
0P002goo00<03gooOol0;goo00<007oo00l07Woo00<007ooOol04Goo00<03gooOol06Woo00<007oo
Ool057oo00<007ooOol017oo00050003Ool00`00Oomoo`04Ool3000I00l00`0000l03`0800l00`00
00l03`0C00l00`0000l0000E00l00`0000l03`0h00l00`0000l03`0j00l00`0000l03`0N00l00`00
00l03`0]00l00`0000l03`0C00l30006Ool000Uoo`03001oogoo00=oo`03001oogoo01Uoo`03001o
ogoo00Moo`03001oogoo00]oo`0300moogoo00Ioo`8001Moo`03001oogoo00moo`0300moogoo02Io
o`03001oogoo00Moo`0300moogoo02ioo`04001oogoo00lOOol00`00Oomoo`0@Ool00`0?Oomoo`0H
Ool00`00Oomoo`0FOol00`00Oomoo`04Ool000Ioo`05001oogooOol00004Ool00`00Oomoo`0HOol0
0`00Oomoo`07Ool00`00Oomoo`0<Ool00`0?Oomoo`06Ool2000HOol00`00Oomoo`0>Ool00`0?Oomo
o`0WOol20007Ool00`0?Oomoo`0^Ool01000Oomoo`0?7goo00<007ooOol047oo00<03gooOol05goo
00<007ooOol05goo00<007ooOol017oo0006Ool01@00Oomoogoo000017oo00<007ooOol067oo00<0
07ooOol01Woo00<007ooOol03Goo00<03gooOol01Goo00@007ooOol001Qoo`03001oogoo00eoo`03
00moogoo02Uoo`03001oogoo00Aoo`0300moogoo02eoo`05001oogooOol03`0POol00`00Oomoo`0?
Ool00`0?Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`04Ool000Moo`<000Eoo`03001oogoo01Mo
o`03001oogoo00Moo`03001oogoo00eoo`0300moogoo00=oo`8000=oo`03001oogoo01Ioo`03001o
ogoo00eoo`0300moogoo02Yoo`03001oogoo00=oo`0300moogoo02aoo`03001oogoo009oo`0300mo
ogoo01moo`03001oogoo00ioo`0300moogoo01Ioo`03001oogoo01Qoo`03001oogoo00Aoo`003goo
00<007ooOol05goo00<007ooOol01Woo00<007ooOol03Woo00<03gooOol00Woo00<007ooOol017oo
00<007ooOol05Woo00<007ooOol037oo00<03gooOol0:goo00<007ooOol00Woo00<03gooOol0;7oo
00<007ooOol00Woo00<03gooOol07goo00<007ooOol03Woo00<03gooOol05Goo00<007ooOol06Goo
00<007ooOol017oo000?Ool00`00Oomoo`0FOol00`00Oomoo`06Ool00`00Oomoo`0?Ool01@0?Oomo
ogoo00001goo00<007ooOol05goo00<007ooOol02goo00<03gooOol0;7oo0P000Woo00<03gooOol0
:goo00<007ooOol00goo00<03gooOol087oo00<007ooOol03Goo00<03gooOol05Goo00<007ooOol0
6Goo00<007ooOol017oo000?Ool3000FOol00`00Oomoo`05Ool00`00Oomoo`0@Ool0100?Oomoo`00
2Goo00<007ooOol05goo00<007ooOol02Woo00<03gooOol0;Woo00<007oo00l0;Goo00<007ooOol0
0goo00<03gooOol087oo00<007ooOol03Goo00<03gooOol057oo00<007ooOol06Goo0P001Woo000?
Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0@Ool00`0?Ool0000:Ool00`00Oomoo`0G
Ool00`00Oomoo`0:Ool00`0?Oomoo`0_Ool00`0000moo`0[Ool00`00Oomoo`04Ool00`0?Oomoo`0Q
Ool00`00Oomoo`0<Ool00`0?Oomoo`0DOol00`00Oomoo`0JOol00`00Oomoo`04Ool000moo`03001o
ogoo01Eoo`03001oogoo00Eoo`03001oogoo015oo`0300l007oo00]oo`03001oogoo01Moo`03001o
ogoo00Uoo`0300moogoo031oo`03001oogoo02Yoo`03001oogoo00Aoo`0300moogoo025oo`03001o
ogoo00aoo`0300moogoo01=oo`03001oogoo01]oo`03001oogoo00Aoo`003goo00<007ooOol057oo
00<007ooOol01Woo00<007ooOol04Goo00<007ooOol02goo00<007ooOol067oo00<007ooOol027oo
00<03gooOol0<7oo00<007ooOol0:Goo00<007ooOol01Goo00<03gooOol08Woo00<007ooOol02goo
00<03gooOol04Woo00<007ooOol077oo00<007ooOol017oo000?Ool00`00Oomoo`0COol00`00Oomo
o`06Ool00`00Oomoo`0AOol00`0000moo`0<Ool00`00Oomoo`0HOol00`00Oomoo`08Ool00`0?Oomo
o`0`Ool00`0?001oo`0YOol00`00Oomoo`05Ool00`0?Oomoo`0ROol00`00Oomoo`0;Ool00`0?Oomo
o`0BOol00`00Oomoo`0LOol00`00Oomoo`04Ool000moo`03001oogoo01=oo`03001oogoo00Ioo`03
001oogoo011oo`03001oo`0?00ioo`03001oogoo01Qoo`03001oogoo00Moo`0300moogoo031oo`03
00moo`0002Uoo`03001oogoo00Eoo`0300moogoo02=oo`03001oogoo00Yoo`0300moogoo015oo`03
001oogoo01eoo`03001oogoo00Aoo`003goo00<007ooOol04Woo00<007ooOol01Woo00<007ooOol0
47oo00@007ooOol03`ioo`03001oogoo01Qoo`03001oogoo00Moo`0300moogoo031oo`0400moogoo
000WOol00`00Oomoo`06Ool00`0?Oomoo`0SOol00`00Oomoo`0:Ool00`0?Oomoo`0AOol00`00Oomo
o`0MOol00`00Oomoo`04Ool000moo`<0019oo`03001oogoo00Eoo`03001oogoo011oo`05001oogoo
Ool03`0?Ool00`00Oomoo`0HOol00`00Oomoo`06Ool00`0?Oomoo`0`Ool01@0?Oomoogoo00009Woo
00<007ooOol01Woo00<03gooOol08goo00<007ooOol02Woo00<03gooOol047oo00<007ooOol07Goo
0P001Woo000?Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`0?Oomoo`0=Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00`0?Oomoo`0`Ool00`0?Oomoo`02Ool0
0`00Oomoo`0ROol00`00Oomoo`07Ool00`0?Oomoo`0TOol00`00Oomoo`09Ool00`0?Oomoo`0?Ool0
0`00Oomoo`0OOol00`00Oomoo`04Ool000moo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo
00moo`03001oogoo00=oo`0300moogoo00ioo`03001oogoo01Qoo`03001oogoo00Eoo`0300moogoo
031oo`0300moogoo00=oo`03001oogoo025oo`03001oogoo00Moo`0300moogoo02Aoo`03001oogoo
00Uoo`0300moogoo00moo`03001oogoo01moo`03001oogoo00Aoo`003goo00<007ooOol047oo00<0
07ooOol01Woo00<007ooOol03Woo00<007ooOol017oo00<03gooOol03Woo00<007ooOol06Goo00<0
07ooOol017oo00<03gooOol0<7oo00<03gooOol017oo00<007ooOol087oo00<007ooOol01goo00<0
3gooOol097oo00<007ooOol02Goo00<03gooOol03Woo00<007ooOol087oo00<007ooOol017oo000?
Ool00`00Oomoo`0@Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool00`0?Oomoo`0>
Ool00`00Oomoo`0JOol00`00Oomoo`03Ool00`0?Oomoo`0`Ool00`0?Oomoo`05Ool00`00Oomoo`0N
Ool00`00Oomoo`08Ool00`0?Oomoo`0UOol00`00Oomoo`08Ool00`0?Oomoo`0>Ool00`00Oomoo`0P
Ool00`00Oomoo`04Ool000moo`03001oogoo00moo`03001oogoo00Ioo`03001oogoo00eoo`03001o
ogoo00Ioo`0300moogoo00moo`03001oogoo01Uoo`03001oogoo00=oo`0300moogoo031oo`0300mo
ogoo00Ioo`03001oogoo01eoo`03001oogoo00Qoo`0300moogoo02Eoo`03001oogoo00Qoo`0300mo
ogoo00eoo`03001oogoo025oo`03001oogoo00Aoo`003goo00<007ooOol03goo00<007ooOol01Goo
00<007ooOol03Goo00<007ooOol01goo00<03gooOol03goo00<007ooOol06Woo00<007ooOol00Woo
00<03gooOol0<7oo00<03gooOol01goo00<007ooOol077oo00<007ooOol027oo00<03gooOol09Goo
00<007ooOol027oo00<03gooOol037oo00<007ooOol08Woo00<007ooOol017oo000?Ool3000?Ool0
0`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`0?Oomoo`0@Ool00`00Oomoo`0IOol0
0`00Oomoo`02Ool00`0?Oomoo`0`Ool00`0?Oomoo`08Ool00`00Oomoo`0JOol00`00Oomoo`09Ool0
0`0?Oomoo`0VOol00`00Oomoo`07Ool00`0?Oomoo`0<Ool00`00Oomoo`0QOol20006Ool000moo`03
001oogoo00ioo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Uoo`0300moogoo011oo`03
001oogoo01Yoo`05001oogooOol03`0bOol00`0?Oomoo`09Ool00`00Oomoo`0IOol00`00Oomoo`09
Ool00`0?Oomoo`0VOol00`00Oomoo`07Ool00`0?Oomoo`0;Ool00`00Oomoo`0SOol00`00Oomoo`04
Ool000moo`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Yoo`0300mo
ogoo015oo`03001oogoo01Yoo`04001oogoo00lbOol00`0?Oomoo`0:Ool00`00Oomoo`0GOol00`00
Oomoo`0:Ool00`0?Oomoo`0WOol00`00Oomoo`06Ool00`0?Oomoo`0;Ool00`00Oomoo`0SOol00`00
Oomoo`04Ool000moo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00Yo
o`0300moogoo015oo`03001oogoo01Yoo`04001oogoo00lbOol00`0?Oomoo`0:Ool00`00Oomoo`0G
Ool00`00Oomoo`0:Ool00`0?Oomoo`0WOol00`00Oomoo`06Ool00`0?Oomoo`0:Ool00`00Oomoo`0T
Ool00`00Oomoo`04Ool000moo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00aoo`03001o
ogoo00]oo`0300moogoo015oo`03001oogoo01]oo`03001oo`0?039oo`0300moogoo00]oo`03001o
ogoo01Ioo`03001oogoo00Yoo`0300moogoo02Moo`03001oogoo00Ioo`0300moogoo00Yoo`03001o
ogoo02Aoo`03001oogoo00Aoo`003goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol02goo
00<007ooOol037oo00<03gooOol04Woo00<007ooOol06Woo00<007oo00l0<Woo00<03gooOol037oo
00<007ooOol057oo00<007ooOol02goo00<03gooOol0:7oo00<007ooOol01Goo00<03gooOol02Goo
00<007ooOol09Goo00<007ooOol017oo000?Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomo
o`0;Ool00`00Oomoo`0=Ool00`0?Oomoo`0BOol00`00Oomoo`0KOol00`0000moo`0aOol00`0?Oomo
o`0=Ool00`00Oomoo`0COol00`00Oomoo`0;Ool00`0?Oomoo`0XOol00`00Oomoo`05Ool00`0?Oomo
o`09Ool00`00Oomoo`0UOol00`00Oomoo`04Ool000moo`<000aoo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo00ioo`0300moogoo01=oo`03001oogoo01]oo`03001oogoo031oo`0300moogoo
00ioo`03001oogoo019oo`03001oogoo00]oo`0300moogoo02Qoo`03001oogoo00Eoo`0300moogoo
00Qoo`03001oogoo02Eoo`8000Ioo`003goo00<007ooOol037oo00<007ooOol00goo00<007ooOol0
2Woo00<007ooOol03goo00<03gooOol04goo00<007ooOol06goo00<007ooOol0<7oo00<03gooOol0
3goo00<007ooOol047oo00<007ooOol037oo00<03gooOol0:Goo00<007ooOol017oo00<03gooOol0
27oo00<007ooOol09Woo00<007ooOol017oo000?Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00
Oomoo`09Ool00`00Oomoo`0@Ool00`0?Oomoo`0DOol00`00Oomoo`0JOol00`0?001oo`0`Ool00`0?
Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`0?Oomoo`0YOol00`00Oomoo`04Ool00`0?
Oomoo`07Ool00`00Oomoo`0WOol00`00Oomoo`04Ool000moo`03001oogoo00]oo`03001oogoo00=o
o`03001oogoo00Yoo`03001oogoo011oo`0300moogoo01Aoo`03001oogoo01Yoo`0300l007oo031o
o`0300moogoo015oo`03001oogoo00eoo`03001oogoo00eoo`0300moogoo02Uoo`03001oogoo00Ao
o`0300moogoo00Moo`03001oogoo02Moo`03001oogoo00Aoo`003goo00<007ooOol02goo00<007oo
Ool00goo00<007ooOol02Goo00<007ooOol04Goo00<03gooOol057oo00<007ooOol06Woo00<03goo
0000<7oo00<03gooOol04Goo00<007ooOol03Goo00<007ooOol03Goo00<03gooOol0:Woo00<007oo
Ool00goo00<03gooOol01Woo00<007ooOol0:7oo00<007ooOol017oo0007Ool30005Ool00`00Oomo
o`0;Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`0?Oomoo`0EOol00`00Oomo
o`0IOol00`0?Ool0000`Ool00`0?Oomoo`0BOol00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`0?Oomo
o`0ZOol00`00Oomoo`03Ool00`0?Oomoo`06Ool00`00Oomoo`0XOol00`00Oomoo`04Ool000Qoo`03
001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo01=oo`03
00moogoo01Eoo`03001oogoo01Uoo`0400moogoo000_Ool00`0?Oomoo`0COol00`00Oomoo`0:Ool0
0`00Oomoo`0>Ool00`0?Oomoo`0[Ool00`00Oomoo`02Ool00`0?Oomoo`05Ool00`00Oomoo`0YOol0
0`00Oomoo`04Ool000D000=oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo01Aoo`0300moogoo01Ioo`03001oogoo01Qoo`0400moogoo000_Ool00`0?
Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0>Ool00`0?Oomoo`0[Ool00`00Oomoo`02Ool00`0?
Oomoo`04Ool00`00Oomoo`0ZOol00`00Oomoo`04Ool000Qoo`03001oogoo00Aoo`<000T03`030000
3`0?00<03`0300003`0?00L03`0300003`0?02h03`0300003`0?01`03`0300003`0?04@03`030000
3`0?00P03`0300003`0?03`03`0300003`0?00T03`0300003`0?02P03`<000Ioo`0027oo00<007oo
Ool017oo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol05Woo00<03goo
Ool05goo00<007ooOol05goo00D03gooOomoo`0002ioo`0300moogoo01Ioo`03001oogoo00Ioo`03
001oogoo00moo`0300moogoo02aoo`05001oogooOol03`05Ool00`00Oomoo`0[Ool00`00Oomoo`04
Ool000Moo`8000Ioo`03001oogoo00Uoo`05001oogooOol0000:Ool00`00Oomoo`0FOol00`0?Oomo
o`0GOol00`00Oomoo`0GOol00`0?Oomoo`02Ool00`00Oomoo`0[Ool00`0?Oomoo`0GOol00`00Oomo
o`05Ool00`00Oomoo`0?Ool00`0?Oomoo`0/Ool01@00Oomoogoo00l01Goo00<007ooOol0:goo00<0
07ooOol017oo0008Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`0GOol00`0?Oomoo`0GOol00`00Oomoo`0GOol00`0?Oomoo`02Ool00`00Oomoo`0[
Ool00`0?Oomoo`0GOol00`00Oomoo`05Ool00`00Oomoo`0?Ool00`0?Oomoo`0/Ool01@00Oomoogoo
00l017oo00<007ooOol0;7oo00<007ooOol017oo000?Ool00`00Oomoo`08Ool01@00Oomoogoo0000
2Goo00<007ooOol067oo00<03gooOol067oo00<007ooOol05Woo00<03gooOol00goo00<007ooOol0
:Woo00<03gooOol067oo00<007ooOol00goo00<007ooOol047oo00<03gooOol0;Goo00@007ooOol0
3`Aoo`03001oogoo02aoo`03001oogoo00Aoo`003goo00<007ooOol027oo00D007ooOomoo`0000Qo
o`03001oogoo01Uoo`0300moogoo01Qoo`03001oogoo01Ioo`0300moogoo00=oo`03001oogoo02Yo
o`0300moogoo01Uoo`03001oogoo009oo`03001oogoo011oo`0300moogoo02eoo`04001oogoo00l3
Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool000moo`03001oogoo00Moo`05001oogooOol00008Ool0
0`00Oomoo`0JOol00`0?Oomoo`0HOol00`00Oomoo`0FOol00`0?Oomoo`04Ool00`00Oomoo`0YOol0
0`0?Oomoo`0JOol01@00Oomoogoo00004Woo00<03gooOol0;Goo00@007ooOol03`=oo`03001oogoo
02eoo`03001oogoo00Aoo`003goo0`001goo00D007ooOomoo`0000Moo`03001oogoo01]oo`0300mo
ogoo01Uoo`03001oogoo01Eoo`0300moogoo00Aoo`03001oogoo02Uoo`0300moogoo01]oo`03001o
o`0001=oo`0300moogoo02ioo`03001oo`0?009oo`03001oogoo02eoo`8000Ioo`003goo00<007oo
Ool01goo00@007ooOol000Qoo`03001oogoo01]oo`0300moogoo01Uoo`03001oogoo01Eoo`0300mo
ogoo00Aoo`03001oogoo02Uoo`0300moogoo01]oo`03001oo`0001=oo`0300moogoo02ioo`03001o
o`0?009oo`03001oogoo02ioo`03001oogoo00Aoo`003goo00<007ooOol01Woo00D007ooOomoo`00
00Moo`03001oogoo01aoo`0300moogoo01Uoo`03001oogoo01Eoo`0300moogoo00Eoo`03001oogoo
02Qoo`0300moogoo01aoo`8001=oo`0300moogoo02moo`0400003goo000aOol00`00Oomoo`04Ool0
00moo`03001oogoo00Ioo`04001oogoo0007Ool00`00Oomoo`0MOol00`0?Oomoo`0JOol00`00Oomo
o`0DOol00`0?Oomoo`05Ool00`00Oomoo`0XOol00`0?Oomoo`0LOol2000COol00`0?Oomoo`0_Ool0
100000moo`00<Goo00<007ooOol017oo000?Ool00`00Oomoo`06Ool01000Oomoo`001Woo00<007oo
Ool07Woo00<03gooOol06Woo00<007ooOol057oo00<03gooOol01Woo00<007ooOol09goo00<03goo
Ool077oo00<007oo00004Woo00<03gooOol0;goo00<0000?0000<Woo00<007ooOol017oo000?Ool0
0`00Oomoo`05Ool01000Oomoo`001Woo00<007ooOol07goo00<03gooOol06Woo00<007ooOol057oo
00<03gooOol01Woo00<007ooOol09goo00<03gooOol06goo00D007ooOomoo`00015oo`0300moogoo
031oo`80039oo`03001oogoo00Aoo`003goo00<007ooOol01Goo00@007ooOol000Ioo`03001oogoo
01moo`0300moogoo01]oo`03001oogoo01=oo`0300moogoo00Moo`03001oogoo02Ioo`0300moogoo
01]oo`05001oogooOol0000AOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`00Oomoo`04Ool000mo
o`<000Eoo`03001oo`0000Ioo`03001oogoo021oo`0300moogoo01]oo`03001oogoo01=oo`0300mo
ogoo00Moo`03001oogoo02Ioo`0300moogoo01]oo`03001oogoo009oo`03001oogoo00ioo`0300mo
ogoo031oo`03001oogoo031oo`8000Ioo`003goo00<007ooOol017oo00@007ooOol000Eoo`03001o
ogoo025oo`0300moogoo01]oo`03001oogoo01=oo`0300moogoo00Qoo`03001oogoo02Eoo`0300mo
ogoo01Yoo`03001oogoo00Aoo`03001oogoo00eoo`0300moogoo02moo`0300003`00039oo`03001o
ogoo00Aoo`003goo00<007ooOol017oo00<007oo00001Goo00<007ooOol08Woo00<03gooOol077oo
00<007ooOol04Woo00<03gooOol027oo00<007ooOol09Goo00<03gooOol06Woo00<007ooOol01Goo
00<007ooOol037oo00<03gooOol0;goo00<0000?0000<Woo00<007ooOol017oo000?Ool00`00Oomo
o`03Ool01000Oomoo`0017oo00<007ooOol08goo00<03gooOol077oo00<007ooOol04Woo00<03goo
Ool02Goo00<007ooOol097oo00<03gooOol06Woo00<007ooOol01Woo00<007ooOol02goo00<03goo
Ool0;goo00<0000?0000<Woo00<007ooOol017oo000?Ool00`00Oomoo`03Ool00`00Ool00004Ool0
0`00Oomoo`0TOol00`0?Oomoo`0LOol00`00Oomoo`0BOol00`0?Oomoo`09Ool00`00Oomoo`0TOol0
0`0?Oomoo`0IOol00`00Oomoo`07Ool00`00Oomoo`0;Ool00`0?Oomoo`0^Ool01@00Ool03goo0000
<Goo00<007ooOol017oo000?Ool00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`0TOol00`0?
Oomoo`0MOol00`00Oomoo`0AOol00`0?Oomoo`0:Ool00`00Oomoo`0SOol00`0?Oomoo`0IOol00`00
Oomoo`08Ool00`00Oomoo`0:Ool00`0?Oomoo`0^Ool01@00Ool03goo0000<Goo00<007ooOol017oo
000?Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`0UOol00`0?Oomoo`0MOol00`00Oomo
o`0AOol00`0?Oomoo`0:Ool00`00Oomoo`0SOol00`0?Oomoo`0IOol00`00Oomoo`09Ool00`00Oomo
o`09Ool00`0?Oomoo`0]Ool01P00Oomoo`0?Ool0035oo`03001oogoo00Aoo`003goo0`000Woo00<0
07oo00000goo00<007ooOol09Woo00<03gooOol07Goo00<007ooOol04Goo00<03gooOol02goo00<0
07ooOol08Woo00<03gooOol067oo00<007ooOol02goo00<007ooOol027oo00<03gooOol0;Goo00@0
07ooOol03`9oo`03001oogoo02eoo`8000Ioo`003goo00<007ooOol00Woo0P000goo00<007ooOol0
9goo00<03gooOol07Woo00<007ooOol047oo00<03gooOol02goo00<007ooOol08Woo00<03gooOol0
67oo00<007ooOol02goo00<007ooOol027oo00<03gooOol0;7oo00D007ooOomoo`0?009oo`03001o
ogoo02ioo`03001oogoo00Aoo`003goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0WOol00`0?
Oomoo`0NOol00`00Oomoo`0@Ool00`0?Oomoo`0<Ool00`00Oomoo`0QOol00`0?Oomoo`0HOol00`00
Oomoo`0<Ool00`00Oomoo`07Ool00`0?Oomoo`0/Ool01@00Oomoogoo00l00Woo00<007ooOol0;Woo
00<007ooOol017oo000?Ool01`00Oomoogoo001oo`00009oo`03001oogoo02Qoo`0300moogoo01io
o`03001oogoo011oo`0300moogoo00aoo`03001oogoo025oo`0300moogoo01Moo`03001oogoo00io
o`03001oogoo00Ioo`0300moogoo02]oo`03001oogoo009oo`0500moogooOol0000_Ool00`00Oomo
o`04Ool000moo`04001oogooOol20002Ool00`00Oomoo`0YOol00`0?Oomoo`0OOol00`00Oomoo`0?
Ool00`0?Oomoo`0<Ool00`00Oomoo`0QOol00`0?Oomoo`0GOol00`00Oomoo`0?Ool00`00Oomoo`05
Ool00`0?Oomoo`0[Ool00`00Oomoo`02Ool01@0?Oomoogoo0000;goo00<007ooOol017oo000?Ool0
2000Oomoo`00Ool007oo000/Ool00`0?Oomoo`0OOol00`00Oomoo`0?Ool00`0?Oomoo`0=Ool00`00
Oomoo`0POol00`0?Oomoo`0GOol00`00Oomoo`0@Ool00`00Oomoo`04Ool00`0?Oomoo`0ZOol00`00
Oomoo`03Ool00`0?Oomoo`02Ool00`00Oomoo`0/Ool00`00Oomoo`04Ool000moo`03001oogoo0080
0003Ool007oo02aoo`0300moogoo01moo`03001oogoo00moo`0300moogoo00eoo`03001oogoo021o
o`0300moogoo01Ioo`03001oogoo015oo`03001oogoo00Aoo`0300moogoo02Yoo`03001oogoo00=o
o`0300moogoo009oo`03001oogoo02aoo`03001oogoo00Aoo`003goo1@0000=oo`00Ool0;7oo00<0
3gooOol087oo00<007ooOol03Woo00<03gooOol03Woo00<007ooOol07goo00<03gooOol05Woo00<0
07ooOol04Woo00<007ooOol00goo00<03gooOol0:Woo00<007ooOol00goo00<03gooOol00Woo00<0
07ooOol0:goo0P001Woo000?Ool01P00Ool00000Ool002ioo`0300moogoo021oo`03001oogoo00io
o`0300moogoo00ioo`03001oogoo01moo`0300moogoo01Ioo`03001oogoo01=oo`03001oogoo009o
o`0300moogoo02Uoo`03001oogoo00Aoo`0300moogoo00=oo`03001oogoo02]oo`03001oogoo00Ao
o`003goo00<007oo00000P00;goo00<03gooOol087oo00<007ooOol03Woo00<03gooOol03goo00<0
07ooOol07Woo00<03gooOol05Goo00<007ooOol05Goo00D007ooOomoo`0?02]oo`03001oogoo00Ao
o`0300moogoo00=oo`03001oogoo02]oo`03001oogoo00Aoo`003goo00@007oo0000031oo`0300mo
ogoo025oo`03001oogoo00eoo`0300moogoo00moo`03001oogoo01ioo`0300moogoo01Eoo`03001o
ogoo01Eoo`05001oogooOol03`0ZOol00`00Oomoo`05Ool00`0?Oomoo`03Ool00`00Oomoo`0[Ool0
0`00Oomoo`04Ool000Qoo`8000Eoo`@0031oo`0300moogoo025oo`03001oogoo00eoo`0300moogoo
011oo`03001oogoo01eoo`0300moogoo01Aoo`03001oogoo01Moo`04001oogoo00lZOol00`00Oomo
o`05Ool00`0?Oomoo`04Ool00`00Oomoo`0ZOol00`00Oomoo`04Ool000Moo`04001oogoo0004Ool3
000aOol00`0?Oomoo`0QOol00`00Oomoo`0=Ool00`0?Oomoo`0@Ool00`00Oomoo`0MOol00`0?Oomo
o`0DOol00`00Oomoo`0HOol00`00Ool03`0YOol00`00Oomoo`06Ool00`0?Oomoo`04Ool00`00Oomo
o`0ZOol00`00Oomoo`04Ool000Moo`04001oogoo0004Ool2000bOol00`0?Oomoo`0ROol00`00Oomo
o`0<Ool00`0?Oomoo`0@Ool00`00Oomoo`0MOol00`0?Oomoo`0DOol00`00Oomoo`0IOol00`0000mo
o`0XOol00`00Oomoo`06Ool00`0?Oomoo`04Ool00`00Oomoo`0ZOol00`00Oomoo`04Ool000Moo`04
001oogoo0004Oooo000h0006Ool000Moo`04001oogoo0004Ool00`00Ool00002000_Ool00`0?Oomo
o`0ROol00`00Oomoo`0<Ool00`0?Oomoo`0AOol00`00Oomoo`0LOol00`0?Oomoo`0COol00`00Oomo
o`0KOol00`00Oomoo`0VOol00`00Oomoo`07Ool00`0?Oomoo`05Ool00`00Oomoo`0YOol00`00Oomo
o`04Ool000Moo`04001oogoo0004Ool00`00Oomoo`02Ool3000/Ool00`0?Oomoo`0SOol00`00Oomo
o`0;Ool00`0?Oomoo`0BOol00`00Oomoo`0KOol00`0?Oomoo`0COol00`00Oomoo`0KOol00`0?001o
o`0VOol00`00Oomoo`07Ool00`0?Oomoo`05Ool00`00Oomoo`0YOol00`00Oomoo`04Ool000Qoo`80
00Eoo`03001oogoo00Eoo`8002Yoo`0300moogoo02=oo`03001oogoo00]oo`0300moogoo019oo`03
001oogoo01]oo`0300moogoo019oo`03001oogoo01aoo`0300moo`0002Eoo`03001oogoo00Qoo`03
00moogoo00Ioo`03001oogoo02Qoo`03001oogoo00Aoo`003goo00<007ooOol01goo0`009goo00<0
3gooOol08goo00<007ooOol02goo00<03gooOol04goo00<007ooOol06Woo00<03gooOol04Woo00<0
07ooOol077oo00<03goo00009Goo00<007ooOol027oo00<03gooOol01Woo00<007ooOol0:7oo00<0
07ooOol017oo000?Ool00`00Oomoo`0:Ool2000UOol00`0?Oomoo`0SOol00`00Oomoo`0;Ool00`0?
Oomoo`0COol00`00Oomoo`0JOol00`0?Oomoo`0BOol00`00Oomoo`0LOol0100?Oomoo`008goo00<0
07ooOol02Goo00<03gooOol01Woo00<007ooOol0:7oo00<007ooOol017oo000?Ool00`00Oomoo`0<
Ool3000ROol00`0?Oomoo`0TOol00`00Oomoo`0:Ool00`0?Oomoo`0DOol00`00Oomoo`0IOol00`0?
Oomoo`0AOol00`00Oomoo`0MOol01@0?Oomoogoo00008Woo00<007ooOol02Goo00<03gooOol01goo
00<007ooOol09goo00<007ooOol017oo000?Ool3000?Ool2000POol00`0?Oomoo`0TOol00`00Oomo
o`0:Ool00`0?Oomoo`0DOol00`00Oomoo`0IOol00`0?Oomoo`0AOol00`00Oomoo`0MOol00`0?Oomo
o`02Ool00`00Oomoo`0NOol00`00Oomoo`0:Ool00`0?Oomoo`07Ool00`00Oomoo`0VOol20006Ool0
00moo`03001oogoo015oo`8001ioo`0300moogoo02Aoo`03001oogoo00Yoo`0300moogoo01Aoo`03
001oogoo01Uoo`0300moogoo015oo`03001oogoo01eoo`0300moogoo00=oo`03001oogoo01eoo`03
001oogoo00Yoo`0300moogoo00Moo`03001oogoo02Moo`03001oogoo00Aoo`003goo00<007ooOol0
4goo0`006goo00<03gooOol09Goo00<007ooOol02Goo00<03gooOol05Goo00<007ooOol067oo00<0
3gooOol047oo00<007ooOol07Woo00<03gooOol00goo00<007ooOol077oo00<007ooOol02goo00<0
3gooOol027oo00<007ooOol09Woo00<007ooOol017oo000?Ool00`00Oomoo`0FOol2000IOol00`0?
Oomoo`0UOol00`00Oomoo`09Ool00`0?Oomoo`0EOol00`00Oomoo`0HOol00`0?Oomoo`0@Ool00`00
Oomoo`0NOol00`0?Oomoo`04Ool00`00Oomoo`0KOol00`00Oomoo`0;Ool00`0?Oomoo`08Ool00`00
Oomoo`0VOol00`00Oomoo`04Ool000moo`03001oogoo01Qoo`8001Moo`0300moogoo02Eoo`03001o
ogoo00Uoo`0300moogoo01Ioo`03001oogoo01Moo`0300moogoo011oo`03001oogoo01ioo`0300mo
ogoo00Eoo`03001oogoo01Uoo`03001oogoo00aoo`0300moogoo00Uoo`03001oogoo02Eoo`03001o
ogoo00Aoo`003goo00<007ooOol06Woo0P005Goo00<03gooOol09Woo00<007ooOol027oo00<03goo
Ool05Woo00<007ooOol05goo00<03gooOol03goo00<007ooOol07goo00<03gooOol01Woo00<007oo
Ool067oo00<007ooOol037oo00<03gooOol02Goo00<007ooOol09Goo00<007ooOol017oo000?Ool0
0`00Oomoo`0LOol2000COol00`0?Oomoo`0VOol00`00Oomoo`08Ool00`0?Oomoo`0GOol00`00Oomo
o`0FOol00`0?Oomoo`0?Ool00`00Oomoo`0OOol00`0?Oomoo`06Ool00`00Oomoo`0GOol00`00Oomo
o`0=Ool00`0?Oomoo`09Ool00`00Oomoo`0UOol00`00Oomoo`04Ool000moo`<001ioo`80015oo`03
00moogoo02Ioo`03001oogoo00Qoo`0300moogoo01Moo`03001oogoo01Ioo`0300moogoo00moo`03
001oogoo01moo`0300moogoo00Moo`03001oogoo01Ioo`03001oogoo00eoo`0300moogoo00Yoo`03
001oogoo02=oo`8000Ioo`003goo00<007ooOol087oo0P003goo00<03gooOol09goo00<007ooOol0
1goo00<03gooOol067oo00<007ooOol05Goo00<03gooOol03Woo00<007ooOol087oo00<03gooOol0
27oo00<007ooOol057oo00<007ooOol03Woo00<03gooOol02Woo00<007ooOol097oo00<007ooOol0
17oo000?Ool00`00Oomoo`0ROol2000=Ool00`0?Oomoo`0WOol00`00Oomoo`07Ool00`0?Oomoo`0H
Ool00`00Oomoo`0EOol00`0?Oomoo`0>Ool00`00Oomoo`0POol00`0?Oomoo`09Ool00`00Oomoo`0C
Ool00`00Oomoo`0>Ool00`0?Oomoo`0:Ool00`00Oomoo`0TOol00`00Oomoo`04Ool000moo`03001o
ogoo02Aoo`8000]oo`0300moogoo02Moo`03001oogoo00Moo`0300moogoo01Uoo`03001oogoo01Ao
o`0300moogoo00ioo`03001oogoo021oo`0300moogoo00Uoo`03001oogoo019oo`03001oogoo00mo
o`0300moogoo00]oo`03001oogoo02=oo`03001oogoo00Aoo`003goo00<007ooOol09Woo0`0027oo
00<03gooOol0:7oo00<007ooOol01Woo00<03gooOol06Goo00<007ooOol057oo00<03gooOol03Goo
00<007ooOol08Goo00<03gooOol02Woo00<007ooOol04Goo00<007ooOol03goo00<03gooOol02goo
00<007ooOol08goo00<007ooOol017oo000?Ool00`00Oomoo`0YOol30005Ool00`0?Oomoo`0XOol0
0`00Oomoo`06Ool00`0?Oomoo`0JOol00`00Oomoo`0COol00`0?Oomoo`0=Ool00`00Oomoo`0QOol0
0`0?Oomoo`0;Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`0?Oomoo`0;Ool00`00Oomoo`0SOol0
0`00Oomoo`04Ool000moo`03001oogoo02aoo`8000=oo`0300moogoo02Qoo`03001oogoo00Ioo`03
00moogoo01Yoo`03001oogoo01=oo`0300moogoo00eoo`03001oogoo025oo`0300moogoo00aoo`03
001oogoo00ioo`03001oogoo011oo`0300moogoo00aoo`03001oogoo029oo`03001oogoo00Aoo`00
3goo0`00;Woo0`0000<03gooOol0:Goo00<007ooOol01Goo00<03gooOol06goo00<007ooOol04Woo
00<03gooOol037oo00<007ooOol08Woo00<03gooOol03Goo00<007ooOol037oo00<007ooOol04Goo
00<03gooOol037oo00<007ooOol08Goo0P001Woo000?Ool00`00Oomoo`0aOol2000ZOol00`00Oomo
o`05Ool00`0?Oomoo`0KOol00`00Oomoo`0BOol00`0?Oomoo`0<Ool00`00Oomoo`0ROol00`0?Oomo
o`0>Ool00`00Oomoo`0;Ool00`00Oomoo`0AOol00`0?Oomoo`0<Ool00`00Oomoo`0ROol00`00Oomo
o`04Ool000moo`03001oogoo035oo`0300moo`00008002Moo`03001oogoo00Eoo`0300moogoo01ao
o`03001oogoo015oo`0300moogoo00aoo`03001oogoo029oo`0300moogoo00ioo`03001oogoo00Yo
o`03001oogoo019oo`0300moogoo00eoo`03001oogoo025oo`03001oogoo00Aoo`003goo00<007oo
Ool0<Goo00<03gooOol00Woo0`009Goo00<007ooOol017oo00<03gooOol077oo00<007ooOol04Goo
00<03gooOol02goo00<007ooOol08goo00<03gooOol03goo00<007ooOol02Goo00<007ooOol04Woo
00<03gooOol03Goo00<007ooOol08Goo00<007ooOol017oo000?Ool00`00Oomoo`0aOol00`0?Oomo
o`05Ool2000SOol00`00Oomoo`04Ool00`0?Oomoo`0MOol00`00Oomoo`0@Ool00`0?Oomoo`0;Ool0
0`00Oomoo`0SOol00`0?Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`0COol00`0?Oomoo`0=Ool0
0`00Oomoo`0QOol00`00Oomoo`04Ool000moo`03001oogoo035oo`0300moogoo00Moo`<0021oo`03
001oogoo00Aoo`0300moogoo01eoo`03001oogoo011oo`0300moogoo00]oo`03001oogoo02=oo`03
00moogoo015oo`03001oogoo00Ioo`03001oogoo01=oo`0300moogoo00ioo`03001oogoo021oo`03
001oogoo00Aoo`003goo00<007ooOol0<Goo00<03gooOol02Woo0P007goo00<007ooOol00goo00<0
3gooOol07Woo00<007ooOol03goo00<03gooOol02Woo00<007ooOol097oo00<03gooOol04Woo00<0
07ooOol017oo00<007ooOol057oo00<03gooOol03Woo00<007ooOol087oo00<007ooOol017oo000?
Ool3000aOol00`0?Oomoo`0<Ool2000MOol00`00Oomoo`03Ool00`0?Oomoo`0NOol00`00Oomoo`0?
Ool00`0?Oomoo`0:Ool00`00Oomoo`0TOol00`0?Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0D
Ool00`0?Oomoo`0?Ool00`00Oomoo`0NOol20006Ool000moo`03001oogoo035oo`0300moogoo00io
o`8001]oo`03001oogoo00=oo`0300moogoo01moo`03001oogoo00ioo`0300moogoo00Yoo`03001o
ogoo02Aoo`0300moogoo01=oo`03001oogoo009oo`03001oogoo01Eoo`0300moogoo00moo`03001o
ogoo01moo`03001oogoo00Aoo`003goo00<007ooOol0<Goo00<03gooOol047oo0`006Goo00<007oo
Ool00Woo00<03gooOol07goo00<007ooOol03Woo00<03gooOol02Goo00<007ooOol09Goo00<03goo
Ool057oo00D007ooOomoo`0001Moo`0300moogoo00moo`03001oogoo01moo`03001oogoo00Aoo`00
3goo00<007ooOol0<Goo00<03gooOol04goo0P005goo00<007ooOol00Woo00<03gooOol087oo00<0
07ooOol03Goo00<03gooOol02Goo00<007ooOol09Goo00<03gooOol05Goo00<007oo000067oo00<0
3gooOol047oo00<007ooOol07Woo00<007ooOol017oo000?Ool00`00Oomoo`0aOol00`0?Oomoo`0E
Ool2000EOol00`00Oomoo`02Ool00`0?Oomoo`0POol00`00Oomoo`0=Ool00`0?Oomoo`09Ool00`00
Oomoo`0UOol00`0?Oomoo`0FOol2000HOol00`0?Oomoo`0@Ool00`00Oomoo`0NOol00`00Oomoo`04
Ool000Moo`<000Eoo`03001oogoo035oo`0300moogoo01Moo`8001Aoo`05001oogooOol03`0SOol0
0`00Oomoo`0<Ool00`0?Oomoo`08Ool00`00Oomoo`0VOol00`0?Oomoo`0FOol2000HOol00`0?Oomo
o`0@Ool00`00Oomoo`0NOol00`00Oomoo`04Ool000Qoo`03001oogoo00Aoo`03001oogoo035oo`03
00moogoo01Uoo`<0015oo`05001oogooOol03`0SOol00`00Oomoo`0<Ool00`0?Oomoo`08Ool00`00
Oomoo`0VOol00`0?Oomoo`0FOol2000HOol00`0?Oomoo`0AOol00`00Oomoo`0MOol00`00Oomoo`04
Ool000Qoo`03001oogoo00Aoo`<005003`<000h03`0300003`0?02H03`0300003`0?01H03`030000
3`0?03h03`0400003`0?000[00l00`0000l03`0K00l30006Ool000Qoo`03001oogoo00Aoo`03001o
ogoo035oo`0300moogoo01moo`8000eoo`04001oogoo00lTOol00`00Oomoo`0;Ool00`0?Oomoo`07
Ool00`00Oomoo`0WOol00`0?Oomoo`0EOol01@00Oomoogoo00005Woo00<03gooOol04Goo00<007oo
Ool07Goo00<007ooOol017oo0008Ool00`00Oomoo`04Ool00`00Oomoo`0aOol00`0?Oomoo`0QOol3
000:Ool01000Oomoo`0?9Goo00<007ooOol02Woo00<03gooOol01goo00<007ooOol09goo00<03goo
Ool057oo00<007ooOol00goo00<007ooOol04goo00<03gooOol04Woo00<007ooOol077oo00<007oo
Ool017oo0007Ool20006Ool00`00Oomoo`0aOol00`0?Oomoo`0TOol20008Ool01000Oomoo`0?9Goo
00<007ooOol02Woo00<03gooOol01goo00<007ooOol09goo00<03gooOol04goo00<007ooOol01Goo
00<007ooOol04Woo00<03gooOol04Woo00<007ooOol077oo00<007ooOol017oo0008Ool00`00Oomo
o`04Ool00`00Oomoo`0aOol00`0?Oomoo`0VOol30006Ool00`00Ool03`0VOol00`00Oomoo`09Ool0
0`0?Oomoo`06Ool00`00Oomoo`0XOol00`0?Oomoo`0COol00`00Oomoo`06Ool00`00Oomoo`0AOol0
0`0?Oomoo`0BOol00`00Oomoo`0LOol00`00Oomoo`04Ool000moo`03001oogoo035oo`0300moogoo
02Uoo`<000=oo`03001oo`0?02Ioo`03001oogoo00Uoo`0300moogoo00Ioo`03001oogoo02Qoo`03
00moogoo019oo`03001oogoo00Qoo`03001oogoo011oo`0300moogoo01=oo`03001oogoo01]oo`03
001oogoo00Aoo`003goo00<007ooOol0<Goo00<03gooOol0;7oo0P0000Aoo`00Ool03bMoo`03001o
ogoo00Qoo`0300moogoo00Eoo`03001oogoo02Uoo`0300moogoo019oo`03001oogoo00Uoo`03001o
ogoo00moo`0300moogoo01=oo`03001oogoo01]oo`03001oogoo00Aoo`003goo0`00<Goo00<03goo
Ool0;Woo0`0000<03gooOol09Goo00<007ooOol027oo00<03gooOol01Goo00<007ooOol0:Goo00<0
3gooOol04Goo00<007ooOol02Woo00<007ooOol03goo00<03gooOol04goo00<007ooOol06Woo0P00
1Woo000?Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool3000WOol00`00Oomoo`07Ool00`0?Oomoo`05
Ool00`00Oomoo`0YOol00`0?Oomoo`0AOol00`00Oomoo`0;Ool00`00Oomoo`0>Ool00`0?Oomoo`0D
Ool00`00Oomoo`0JOol00`00Oomoo`04Ool000moo`03001oogoo035oo`0300moogoo035oo`03001o
o`00008002Eoo`03001oogoo00Ioo`0300moogoo00Aoo`03001oogoo02Yoo`0300moogoo011oo`03
001oogoo00eoo`03001oogoo00eoo`0300moogoo01Aoo`03001oogoo01Yoo`03001oogoo00Aoo`00
3goo00<007ooOol0<Goo00<03gooOol0<Goo00<007ooOol00Woo0`008Woo00<007ooOol01Woo00<0
3gooOol017oo00<007ooOol0:Woo00<03gooOol047oo00<007ooOol03Woo00<007ooOol037oo00<0
3gooOol057oo00<007ooOol06Woo00<007ooOol017oo000?Ool00`00Oomoo`0aOol00`0?Oomoo`0a
Ool00`00Oomoo`05Ool2000QOol00`00Oomoo`05Ool00`0?Oomoo`03Ool00`00Oomoo`0[Ool00`0?
Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`0?Oomoo`0EOol00`00Oomoo`0IOol00`00
Oomoo`04Ool000moo`03001oogoo035oo`0300moogoo035oo`0300l007oo00Moo`<001ioo`03001o
ogoo00Eoo`0300moogoo00=oo`03001oogoo02]oo`0300moogoo00moo`03001oogoo015oo`03001o
ogoo00Yoo`0300moogoo01Eoo`03001oogoo01Uoo`03001oogoo00Aoo`003goo00<007ooOol0<Goo
00<03gooOol0<Goo00<03`00Ool02Woo0`0077oo00<007ooOol017oo00<03gooOol00goo00<007oo
Ool0:goo00<03gooOol03Woo00<007ooOol04goo00<007ooOol02Goo00<03gooOol05Woo00<007oo
Ool067oo00<007ooOol017oo000?Ool3000aOol00`0?Oomoo`0aOol00`0?Ool0000=Ool3000IOol0
0`00Oomoo`04Ool00`0?Oomoo`02Ool00`00Oomoo`0/Ool00`0?Oomoo`0>Ool00`00Oomoo`0DOol0
0`00Oomoo`08Ool00`0?Oomoo`0FOol00`00Oomoo`0GOol20006Ool000moo`03001oogoo035oo`03
00moogoo035oo`0300moo`00011oo`<001Moo`03001oogoo00=oo`0300moogoo009oo`03001oogoo
02aoo`0300moogoo00eoo`03001oogoo01Ioo`03001oogoo00Moo`0300moogoo01Ioo`03001oogoo
01Qoo`03001oogoo00Aoo`003goo00<007ooOol0<Goo00<03gooOol0<Goo00@03gooOol0019oo`<0
01Eoo`03001oogoo009oo`0500moogooOol0000_Ool00`0?Oomoo`0<Ool00`00Oomoo`0HOol00`00
Oomoo`06Ool00`0?Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`04Ool000moo`03001oogoo035o
o`0300moogoo035oo`0400moogoo000EOol3000BOol00`00Oomoo`02Ool01@0?Oomoogoo0000;goo
00<03gooOol037oo00<007ooOol06Goo00<007ooOol01Goo00<03gooOol05goo00<007ooOol05goo
00<007ooOol017oo000?Ool00`00Oomoo`0aOol00`0?Oomoo`0aOol0100?Oomoo`0067oo0`0047oo
00D007ooOomoo`0?00=oo`03001oogoo02eoo`0300moogoo00]oo`03001oogoo01]oo`03001oogoo
00Aoo`0300moogoo01Qoo`03001oogoo01Ioo`03001oogoo00Aoo`003goo00<007ooOol0<Goo00<0
3gooOol0<Goo00D03gooOomoo`0001Yoo`<000eoo`05001oogooOol03`02Ool00`00Oomoo`0^Ool0
0`0?Oomoo`0;Ool00`00Oomoo`0LOol00`00Oomoo`03Ool00`0?Oomoo`0HOol00`00Oomoo`0FOol0
0`00Oomoo`04Ool000moo`03001oogoo035oo`0300moogoo035oo`0500moogooOol0000MOol2000<
Ool01000Oomoo`0?0Woo00<007ooOol0;Woo00<03gooOol02Woo00<007ooOol07Woo00<007ooOol0
0Woo00<03gooOol067oo00<007ooOol05Woo00<007ooOol017oo000?Ool3000aOol00`0?Oomoo`0a
Ool00`0?Oomoo`02Ool00`00Oomoo`0LOol30009Ool01P00Oomoo`0?Ool0035oo`0300moogoo00Yo
o`03001oogoo01moo`05001oogooOol03`0KOol00`00Oomoo`0DOol20006Ool000moo`03001oogoo
035oo`0300moogoo035oo`0300moogoo009oo`03001oogoo01moo`<000Moo`05001oo`0?Ool0000a
Ool00`0?Oomoo`09Ool00`00Oomoo`0QOol01000Oomoo`0?6goo00<007ooOol05Goo00<007ooOol0
17oo000?Ool00`00Oomoo`0aOol00`0?Oomoo`0aOol00`0?Oomoo`03Ool00`00Oomoo`0QOol30004
Ool01@00Ool03goo0000<Goo00<03gooOol027oo00<007ooOol08goo00<007oo00l077oo00<007oo
Ool057oo00<007ooOol017oo000?Ool00`00Oomoo`0aOol00`0?Oomoo`0aOol00`0?Oomoo`03Ool0
0`00Oomoo`0TOol30002Ool00`0000l0000bOol00`0?Oomoo`08Ool00`00Oomoo`0TOol00`0000mo
o`0KOol00`00Oomoo`0DOol00`00Oomoo`04Ool000moo`03001oogoo035oo`0300moogoo035oo`03
00moogoo00Aoo`03001oogoo02Ioo`D0039oo`0300moogoo00Moo`03001oogoo02Ioo`8001]oo`03
001oogoo01Aoo`03001oogoo00Aoo`003goo00<007ooOol0<Goo00<03gooOol0<Goo00<03gooOol0
17oo00<007ooOol0:Goo0`00<Goo00<03gooOol01goo00<007ooOol09Woo00<03goo00006goo00<0
07ooOol04goo00<007ooOol017oo000?Ool00`00Oomoo`0aOol00`0?Oomoo`0aOol00`0?Oomoo`05
Ool00`00Oomoo`0XOol200000goo00000003000/Ool00`0?Oomoo`06Ool00`00Oomoo`0WOol0100?
Oomoo`006Woo00<007ooOol04goo00<007ooOol017oo000?Ool3000aOol00`0?Oomoo`0aOol00`0?
Oomoo`05Ool00`00Oomoo`0XOol20006Ool4000XOol00`0?Oomoo`05Ool00`00Oomoo`0XOol01@0?
Oomoogoo00006Woo00<007ooOol04Goo0P001Woo000?Ool00`00Oomoo`0aOol00`0?Oomoo`0aOol0
0`0?Oomoo`06Ool00`00Oomoo`0VOol0100000moo`002Goo100097oo00<03gooOol01Goo00<007oo
Ool0:7oo00<03gooOol00Woo00<007ooOol05goo00<007ooOol04Woo00<007ooOol017oo000?Ool0
0`00Oomoo`0aOol00`0?Oomoo`0aOol00`0?Oomoo`06Ool00`00Oomoo`0VOol01@0000moogoo0000
37oo0`008Goo00<03gooOol017oo00<007ooOol0:Goo00<03gooOol00goo0P0067oo00<007ooOol0
4Goo00<007ooOol017oo000?Ool00`00Oomoo`0aOol00`0?Oomoo`0aOol00`0?Oomoo`07Ool00`00
Oomoo`0TOol00`00Ool03`03Ool00`00Oomoo`0<Ool3000NOol00`0?Oomoo`04Ool00`00Oomoo`0Y
Ool00`0?Oomoo`05Ool00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`04Ool000moo`03001o
ogoo035oo`0300moogoo035oo`0300moogoo00Moo`03001oogoo02Aoo`03001oo`0?00=oo`03001o
ogoo00moo`<001]oo`0300moogoo00=oo`03001oogoo02Yoo`0300moogoo00Ioo`03001oogoo01Eo
o`03001oogoo011oo`03001oogoo00Aoo`001Woo1@0017oo00<007ooOol0<Goo00<03gooOol0<Goo
00<03gooOol027oo00<007ooOol08Woo00@007ooOol03`Aoo`03001oogoo015oo`@001Moo`0300mo
ogoo009oo`03001oogoo02]oo`0300moogoo00Moo`03001oogoo01Aoo`03001oogoo011oo`03001o
ogoo00Aoo`001goo00@007ooOol000Aoo`03001oogoo035oo`0300moogoo035oo`0300moogoo00Qo
o`03001oogoo029oo`04001oogoo00l5Ool00`00Oomoo`0DOol5000BOol01@0?Oomoogoo0000;Woo
00<03gooOol027oo00<007ooOol057oo00<007ooOol03goo00<007ooOol017oo0008Ool00`00Oomo
o`04Ool3001a00l00`0000l03`0P00l00`0000l03`0800l00`0000l03`0H00l4000A00l00`0000l0
3`0i00l00`0000l03`0C00l00`0000l03`0=00l30006Ool000Uoo`03001oogoo00=oo`03001oogoo
035oo`0300moogoo035oo`0300moogoo00Uoo`03001oogoo01moo`03001oogoo009oo`0300moogoo
00Aoo`03001oogoo01aoo`@000Yoo`0300moo`00031oo`0300moogoo00Yoo`8001Aoo`03001oogoo
00ioo`03001oogoo00Aoo`001Woo00D007ooOomoo`0000Aoo`03001oogoo035oo`0300moogoo035o
o`0300moogoo00Yoo`03001oogoo01ioo`03001oogoo009oo`0300moogoo00Eoo`03001oogoo01mo
o`D000Eoo`0300l007oo031oo`0300moogoo00aoo`03001oogoo015oo`03001oogoo00ioo`03001o
ogoo00Aoo`001Woo00D007ooOomoo`0000Aoo`03001oogoo035oo`0300moogoo035oo`0300moogoo
00]oo`03001oogoo01aoo`03001oogoo00=oo`0300moogoo00Ioo`03001oogoo02=oo`@00003Ool0
07oo035oo`0300moogoo00eoo`80019oo`03001oogoo00eoo`03001oogoo00Aoo`001goo0`001Goo
00<007ooOol0<Goo00<03gooOol0<Goo00<03gooOol02goo00<007ooOol077oo00<007ooOol00goo
00<03gooOol01goo00<007ooOol09Woo1000<7oo00<03gooOol03goo00<007ooOol03goo00<007oo
Ool03Goo00<007ooOol017oo000?Ool00`00Oomoo`0aOol00`0?Oomoo`0aOol00`0?Oomoo`0<Ool0
0`00Oomoo`0JOol00`00Oomoo`04Ool00`0?Oomoo`08Ool00`00Oomoo`0UOol0100000moogoo1000
;7oo00<03gooOol047oo00<007ooOol03goo00<007ooOol037oo00<007ooOol017oo000?Ool00`00
Oomoo`0aOol00`0?Oomoo`0aOol00`0?Oomoo`0<Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00`0?
Oomoo`09Ool00`00Oomoo`0SOol00`00Ool03`06Ool4000XOol00`0?Oomoo`0AOol2000@Ool00`00
Oomoo`0;Ool00`00Oomoo`04Ool000moo`<0035oo`0300moogoo035oo`0300moogoo00eoo`03001o
ogoo01Moo`03001oogoo00Ioo`0300moogoo00Yoo`03001oogoo025oo`04001oogoo00l:Ool6000R
Ool00`0?Oomoo`0COol2000?Ool00`00Oomoo`09Ool20006Ool000moo`03001oogoo035oo`0300mo
ogoo035oo`0300moogoo00ioo`03001oogoo01Eoo`03001oogoo00Moo`0300moogoo00]oo`03001o
ogoo01moo`05001oogooOol03`0@Ool7000KOol00`0?Oomoo`0EOol2000>Ool00`00Oomoo`09Ool0
0`00Oomoo`04Ool000moo`03001oogoo035oo`0300moogoo035oo`0300moogoo00ioo`03001oogoo
01Aoo`03001oogoo00Qoo`0300moogoo00aoo`03001oogoo01eoo`03001oogoo009oo`0300moogoo
01Eoo`H001Eoo`0300moogoo01Moo`8000eoo`03001oogoo00Qoo`03001oogoo00Aoo`003goo00<0
07ooOol0<Goo00<03gooOol0<Goo00<03gooOol03goo0P004goo00<007ooOol02Goo00<03gooOol0
3Goo0P006goo0P001Goo00<03gooOol06goo1P003goo00<03gooOol06Goo0P0037oo00<007ooOol0
1goo00<007ooOol017oo000?Ool00`00Oomoo`0aOol00`0?Oomoo`0aOol00`0?Oomoo`0AOol00`00
Oomoo`0?Ool00`00Oomoo`0:Ool00`0?Oomoo`0?Ool2000HOol00`00Oomoo`05Ool00`0?Oomoo`0Q
Ool70008Ool00`0?Oomoo`0KOol2000:Ool00`00Oomoo`07Ool00`00Oomoo`04Ool000moo`03001o
ogoo035oo`0300moogoo035oo`0300moogoo019oo`03001oogoo00eoo`03001oogoo00]oo`0300mo
ogoo015oo`8001Aoo`8000Qoo`0300moogoo02Qoo`L00003Ool03goo01ioo`<000Qoo`8000Moo`03
001oogoo00Aoo`003goo00<007ooOol0<Goo00<03gooOol0<Goo00<03gooOol04goo00<007ooOol0
2Woo0P003Woo00<03gooOol04goo00<007ooOol047oo00<007ooOol027oo00<03gooOol0;goo2P00
6Woo0`001goo00<007ooOol017oo00<007ooOol017oo000?Ool3000aOol00`0?Oomoo`0aOol00`0?
Oomoo`0DOol20009Ool00`00Oomoo`0>Ool00`0?Oomoo`0DOol2000<Ool4000;Ool00`0?Oomoo`0`
Ool00`0?Oomoo`06Ool9000DOol30005Ool00`00Oomoo`02Ool20006Ool000moo`03001oogoo035o
o`0300moogoo035oo`0300moogoo01Ioo`<000=oo`<0015oo`0300moogoo01Ioo`<000Moo`8000mo
o`0300moogoo031oo`0300moogoo00mooaD0009oo`X00003Ool007oo00Eoo`003goo00<007ooOol0
<Goo00<007ooOol0<Goo00<007ooOol067oo1@004goo00<007ooOol06Goo1`004Goo00<007ooOol0
<7oo00<007ooOol097oo3P001Woo000?Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool000moool003P000Ioo`00ogooCGoo003oOom=Ool00?mo
odeoo`00ogooCGoo000VOol3001eOol3001;Ool3001MOol002Uoo`03001oogoo07Eoo`03001oogoo
04]oo`03001oogoo05Yoo`006Goo1@0000=oo`0000000`000Woo10000Woo0`000Woo0`0000=oo`00
00001@000goo0P0000=oo`0000000P0000=oo`0000000P0000=oo`0000000goo0P000Woo1@000Woo
0`000Woo0`0000Aoo`00001oo`<0009oo`<00003Ool0000000Ioo`@000=oo`<0009oo`T00003Ool0
0000009oo`800003Ool0000000800004Ool00000Ool40007Ool50003Ool200000goo001oo`030002
Ool30009Ool30002Ool00`00Ool0000300001Goo00000000Ool00P0000=oo`0000000P0000=oo`00
00000P000goo10000Woo10000goo00<007ooOol00goo1@000Woo0`000Woo100017oo0P0057oo1@00
00Aoo`00000000Aoo`<0009oo`D0019oo`006Woo00@007ooOol000=oo`05001oogooOol00003Ool0
0`00Ool00006Ool01000Oomoo`000goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002
Ool00`00Ool00003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00
Ool00006Ool01000Oomoo`0027oo00H007ooOol007oo0006Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`03001oogoo00Moo`03001oogoo009oo`06
001oogoo001oo`001Woo00<007ooOol02Goo00H007ooOol007oo0002Ool01@00Oomoogoo00000Woo
00<007oo00000Woo00D007ooOomoo`00009oo`03001oo`00009oo`04001oogoo0003Ool00`00Oomo
o`09Ool01@00Oomoogoo00002Goo00@007ooOol0009oo`03001oogoo01=oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00Eoo`03001oogoo019oo`006Woo00<007ooOol017oo00D007ooOomo
o`0000=oo`03001oo`0000@0009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol0009oo`8000Aoo`03001oogoo00Aoo`05001oogooOol00003Ool01000Oomoo`000Woo
00<007oo000010000Woo00@007ooOol000Qoo`05001oogoo001oo`050002Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`03001oogoo00Moo`03001o
ogoo009oo`05001oogoo001oo`050002Ool00`00Oomoo`09Ool00`00Ool00003Ool30003Ool01P00
Oomoo`00Ool0009oo`05001oogooOol00002Ool00`00Ool00002Ool01000Oomoo`000goo00<007oo
Ool02Goo00@007ooOomoo`D0009oo`<000=oo`03001oogoo00Uoo`@000Uoo`03001oogoo009oo`03
001oogoo009oo`D000=oo`03001oogoo019oo`006Woo0`0017oo00D007ooOomoo`0000=oo`03001o
o`0000=oo`04001oogoo0002Ool01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0002
Ool00`00Ool00003Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001o
o`0000=oo`04001oogoo0002Ool00`00Oomoo`06Ool01P00Oomoo`00Ool000=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Ool00003Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`03001oogoo008000Yoo`<0009oo`04001o
ogoo0003Ool01P00Oomoo`00Ool0009oo`05001oogooOol00002Ool00`00Ool00002Ool01000Oomo
o`000goo00<007ooOol02Goo00D007ooOomoo`0000=oo`03001oo`0000Ioo`03001oogoo01Ioo`03
001oogoo009oo`8000=oo`05001oogooOol00003Ool00`00Oomoo`0BOol001Yoo`03001oogoo009o
o`<000Aoo`D00004Ool000000002Ool40003Ool4000017oo000007oo0P0000=oo`0000000P000goo
00D007oo000007oo00@0009oo`<000Aoo`<0009oo`@000=oo`<0009oo`@000Uoo`04001oogoo0002
Ool30003Ool30002Ool40002Ool2000017oo000007oo10000goo1@001goo100000Aoo`00001oo`80
009oo`<0009oo`800003Ool0000000Qoo`04001oogoo0002Ool20003Ool40003Ool30003Ool30003
Ool30003Ool50009Ool40002Ool30003Ool400000goo00000002000EOol4000017oo000007oo0P00
0Woo0`000Woo0`0057oo000JOol01000Oomoo`006goo00<007ooOol03Woo00<007ooOol00goo00<0
07ooOol09goo00@007ooOol000Qoo`03001oogoo029oo`03001oogoo01Yoo`04001oogoo000@Ool0
1@00Oomoogoo00001goo00<007ooOol047oo00<007ooOol03Woo00<007ooOol05Woo00<007ooOol0
97oo000IOol50003Ool00`00Oomoo`0FOol2000=Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`0O
Ool40008Ool2000UOol2000IOol4000@Ool20002Ool20006Ool2000COol2000>Ool00`00Oomoo`0G
Ool2000?Ool00`00Oomoo`0BOol00?moodeoo`00ogooCGoo0000\
\>"],
  ImageRangeCache->{{{0, 331.375}, {204.438, 0}} -> {-0.615323, -2.85639, \
0.0387718, 0.0283599}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
WindowSize->{1049, 748},
WindowMargins->{{44, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000004:<;T?o0okX@hP_E0fL5N`?P0080004/0B`000000]X2:001
0000D00000400@410?l00BL?00400@00000000000000000801T1T0000000H000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 95, 1, 108, "Title"],
Cell[1874, 56, 138, 4, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2037, 64, 115, 2, 78, "Subtitle"],
Cell[2155, 68, 1019, 20, 202, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3211, 93, 120, 2, 78, "Subtitle"],

Cell[CellGroupData[{
Cell[3356, 99, 1069, 23, 178, "Input"],
Cell[4428, 124, 56, 1, 28, "Output"],
Cell[4487, 127, 55, 1, 26, "Output"]
}, Open  ]],
Cell[4557, 131, 281, 7, 58, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4875, 143, 61, 1, 62, "Subtitle"],

Cell[CellGroupData[{
Cell[4961, 148, 182, 4, 46, "Subsection"],

Cell[CellGroupData[{
Cell[5168, 156, 109, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[5302, 161, 85, 1, 27, "Input"],
Cell[5390, 164, 69, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5496, 170, 63, 1, 27, "Input"],
Cell[5562, 173, 81, 1, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5692, 180, 113, 1, 42, "Subsubsection"],
Cell[5808, 183, 88, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[5921, 188, 72, 1, 27, "Input"],
Cell[5996, 191, 36, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6069, 197, 72, 1, 27, "Input"],
Cell[6144, 200, 69, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6250, 206, 74, 1, 27, "Input"],
Cell[6327, 209, 42, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6406, 215, 74, 1, 27, "Input"],
Cell[6483, 218, 81, 1, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6613, 225, 235, 6, 58, "Subsubsection"],
Cell[6851, 233, 95, 1, 30, "Text"],
Cell[6949, 236, 113, 5, 57, "Input"],

Cell[CellGroupData[{
Cell[7087, 245, 295, 10, 132, "Input"],
Cell[7385, 257, 270, 7, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7692, 269, 124, 4, 27, "Input"],
Cell[7819, 275, 46, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7902, 281, 126, 2, 43, "Input"],
Cell[8031, 285, 68, 1, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8148, 292, 116, 2, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[8289, 298, 187, 5, 57, "Input"],
Cell[8479, 305, 39148, 1071, 205, 11193, 721, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[47688, 1383, 163, 4, 46, "Subsection"],

Cell[CellGroupData[{
Cell[47876, 1391, 454, 13, 177, "Input"],
Cell[48333, 1406, 215, 4, 22, "Print"],
Cell[48551, 1412, 83, 1, 22, "Print"],
Cell[48637, 1415, 881, 24, 22, "Print"],
Cell[49521, 1441, 883, 24, 22, "Print"],
Cell[50407, 1467, 881, 24, 22, "Print"],
Cell[51291, 1493, 883, 24, 22, "Print"],
Cell[52177, 1519, 881, 24, 22, "Print"],
Cell[53061, 1545, 879, 24, 22, "Print"],
Cell[53943, 1571, 881, 24, 22, "Print"],
Cell[54827, 1597, 881, 24, 22, "Print"],
Cell[55711, 1623, 881, 24, 22, "Print"],
Cell[56595, 1649, 883, 24, 22, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[57527, 1679, 146, 4, 46, "Subsection"],

Cell[CellGroupData[{
Cell[57698, 1687, 256, 6, 58, "Subsubsection"],

Cell[CellGroupData[{
Cell[57979, 1697, 1380, 33, 447, "Input"],
Cell[59362, 1732, 342, 7, 22, "Print"],
Cell[59707, 1741, 131, 2, 22, "Print"],
Cell[59841, 1745, 2003, 54, 22, "Print"],
Cell[61847, 1801, 2053, 54, 24, "Print"],
Cell[63903, 1857, 2019, 54, 24, "Print"],
Cell[65925, 1913, 2053, 54, 24, "Print"],
Cell[67981, 1969, 2053, 54, 24, "Print"],
Cell[70037, 2025, 2047, 54, 24, "Print"],
Cell[72087, 2081, 2019, 54, 24, "Print"],
Cell[74109, 2137, 2051, 54, 24, "Print"],
Cell[76163, 2193, 2055, 54, 24, "Print"],
Cell[78221, 2249, 2055, 54, 24, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[80313, 2308, 220, 7, 87, "Input"],
Cell[80536, 2317, 171, 3, 22, "Print"],
Cell[80710, 2322, 74, 1, 22, "Print"],
Cell[80787, 2325, 509, 15, 22, "Print"],
Cell[81299, 2342, 519, 15, 22, "Print"],
Cell[81821, 2359, 515, 15, 22, "Print"],
Cell[82339, 2376, 517, 15, 22, "Print"],
Cell[82859, 2393, 517, 15, 22, "Print"],
Cell[83379, 2410, 509, 15, 22, "Print"],
Cell[83891, 2427, 515, 15, 22, "Print"],
Cell[84409, 2444, 511, 15, 22, "Print"],
Cell[84923, 2461, 515, 15, 22, "Print"],
Cell[85441, 2478, 513, 15, 22, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85991, 2498, 53, 1, 27, "Input"],
Cell[86047, 2501, 678, 13, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[86774, 2520, 95, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[86894, 2525, 237, 7, 87, "Input"],
Cell[87134, 2534, 18871, 683, 103, 7591, 539, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106042, 3222, 140, 5, 57, "Input"],

Cell[CellGroupData[{
Cell[106207, 3231, 6380, 302, 55, 3744, 265, "GraphicsData", "PostScript", \
"Graphics"],
Cell[112590, 3535, 7006, 330, 57, 4155, 290, "GraphicsData", "PostScript", \
"Graphics"],
Cell[119599, 3867, 8101, 369, 58, 4657, 322, "GraphicsData", "PostScript", \
"Graphics"],
Cell[127703, 4238, 8785, 398, 57, 5064, 348, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[136537, 4642, 77, 1, 27, "Input"],
Cell[136617, 4645, 55827, 1406, 214, 12680, 868, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

